-- sql
-- $Source: fd2gm_drugs_cs.sql
-- $Revision: 1.2 
-- $Author: Jim Busser, GNUmed and FreeDiams projects
-- ---------------------------
-- Description:
-- script for importing FreeDiams-sourced drug 'molecule' data
-- … for import into GNUmed ref.consumable.substances
-- … renamed as 'install-data-pack.sql' within GNUmed data packs
-- … configurational name = variants of 'Drugs, non-brand, <Country> 2011'
-- … zip archive name = variants of 'drugs_cs_LA_COUNTRY.zip
-- ---------------------------
-- References / links:
-- GNUmed git repository, data packs and project
--	git://gitorious.org/gnumed/gnumed.git
--	http://wiki.gnumed.de/bin/view/Gnumed/GmManualReferenceData
-- 	http://www.gnumed.de/downloads/data/data-packs.conf
-- 	http://wiki.gnumed.de
-- FreeDiams
-- 	http://www.freemedforms.com/en/manuals/freediams/start
-- ----------------------


-----------------------------------------------------------------------------
-- ************************************************************
-- set ON_ERROR_STOP 1
-- ************************************************************
-- ---------------------------------------------------------------------------
\set ON_ERROR_STOP 1


-----------------------------------------------------------------------------
-- ************************************************************
-- create staging table
-- ************************************************************
-- -----------------------------------------------------------------------------
-- ---------------------------------------------
\unset ON_ERROR_STOP
drop table staging.consumable_substance;
\set ON_ERROR_STOP 1

begin;

create table staging.consumable_substance
(
  description text,
  atc_code text,
  amount numeric,
  unit text
);


-- -----------------------------------------------------------------------------
-- *********************
-- import staging data
-- *********************
-- -----------------------------------------------------------------------------
--
-- PostgreSQL database dump
--

SET statement_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = off;
SET check_function_bodies = false;
SET client_min_messages = warning;
SET escape_string_warning = off;

SET search_path = staging, pg_catalog;

--
-- Data for Name: consumable_substance; Type: TABLE DATA; Schema: staging; Owner: gm-dbo
--

INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('abatacept', 'L04AA24', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('disodium edetate', NULL, 0.025, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fimbriae', NULL, 5.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hyprolose', 'S01XA20', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('permethrin', 'P03AC04', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('praziquantel', 'P02BA01', 600.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('starch', NULL, 49.95, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('(morpholinothio)benzothiazole', NULL, 0.02, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('3-(trimethoxysilyl)propyl dimethyl octadecyl ammonium chloride', NULL, 0.11, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('abacavir (abacavir sulfate)', 'J05AF06', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('abacavir (abacavir sulfate)', 'J05AF06', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('abacavir (abacavir sulfate)', 'J05AF06', 600.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('abciximab', 'B01AC13', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acamprosate calcium', 'N07BB03', 333.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acarbose', 'A10BF01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acarbose', 'A10BF01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acebutolol (acebutolol hydrochloride)', 'C07AB04', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acebutolol (acebutolol hydrochloride)', 'C07AB04', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acebutolol (acebutolol hydrochloride)', 'C07AB04', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acebutolol hydrochloride', 'C07AB04', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acebutolol hydrochloride', 'C07AB04', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acebutolol hydrochloride', 'C07AB04', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acenocoumarol', 'B01AA07', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acenocoumarol', 'B01AA07', 4.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetaminophen', 'N02BE01', 1.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetaminophen', 'N02BE01', 1.0, 'g/30ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetaminophen', 'N02BE01', 16.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetaminophen', 'N02BE01', 32.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetaminophen', 'N02BE01', 80.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetaminophen', 'N02BE01', 80.0, 'mg/1ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetaminophen', 'N02BE01', 80.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetaminophen', 'N02BE01', 120.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetaminophen', 'N02BE01', 160.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetaminophen', 'N02BE01', 160.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetaminophen', 'N02BE01', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetaminophen', 'N02BE01', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetaminophen', 'N02BE01', 325.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetaminophen', 'N02BE01', 325.0, 'mg/15ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetaminophen', 'N02BE01', 325.0, 'mg/22g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetaminophen', 'N02BE01', 325.0, 'mg/23g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetaminophen', 'N02BE01', 325.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetaminophen', 'N02BE01', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetaminophen', 'N02BE01', 500.0, 'mg/15ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetaminophen', 'N02BE01', 650.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetaminophen', 'N02BE01', 650.0, 'mg/15ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetaminophen', 'N02BE01', 650.0, 'mg/20ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetaminophen', 'N02BE01', 650.0, 'mg/22mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetaminophen', 'N02BE01', 650.0, 'mg/23g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetaminophen', 'N02BE01', 650.0, 'mg/24g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetaminophen', 'N02BE01', 650.0, 'mg/30ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetaminophen', 'N02BE01', 1000.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetaminophen', 'N02BE01', 1000.0, 'mg/30ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetazolamide', 'S01EC01', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetic acid', 'G01AD02', 4.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetic acid', 'G01AD02', 5.4, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetic acid', 'G01AD02', 5.41, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetic acid', 'G01AD02', 8.1, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetic acid', 'G01AD02', 8.11, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetic acid', 'G01AD02', 9.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetic acid', 'G01AD02', 10.8, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetic acid', 'G01AD02', 10.81, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetyl-l-tyrosine', NULL, 94.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetyl-l-tyrosine', NULL, 115.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetylcholine chloride', 'S01EB09', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetylcholine chloride', 'S01EB09', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetylcysteine', 'R05CB01', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetylsalicylic acid', 'N02BA01', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetylsalicylic acid', 'N02BA01', 30.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetylsalicylic acid', 'N02BA01', 31.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetylsalicylic acid', 'N02BA01', 80.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetylsalicylic acid', 'N02BA01', 81.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetylsalicylic acid', 'N02BA01', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetylsalicylic acid', 'N02BA01', 162.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetylsalicylic acid', 'N02BA01', 325.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetylsalicylic acid', 'N02BA01', 330.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetylsalicylic acid', 'N02BA01', 350.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetylsalicylic acid', 'N02BA01', 375.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetylsalicylic acid', 'N02BA01', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetylsalicylic acid', 'N02BA01', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetylsalicylic acid', 'N02BA01', 650.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acetylsalicylic acid', 'N02BA01', 975.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acitretin', 'D05BB02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acitretin', 'D05BB02', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acyclovir', 'J05AB01', 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acyclovir', 'J05AB01', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acyclovir', 'J05AB01', 200.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acyclovir', 'J05AB01', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acyclovir', 'J05AB01', 800.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acyclovir (acyclovir sodium)', 'J05AB01', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acyclovir (acyclovir sodium)', 'J05AB01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('acyclovir (acyclovir sodium)', 'J05AB01', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('adalimumab', 'L04AB04', 40.0, 'mg/0.8ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('adapalene', 'D10AD03', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('adapalene', 'D10AD03', 0.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('adefovir dipivoxil', 'J05AF08', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('adenine', NULL, 17.3, 'mg/63ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('adenosine', 'C01EB10', 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('agalsidase alfa', 'A16AB03', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('agalsidase beta', 'A16AB04', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('agalsidase beta', 'A16AB04', 35.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('air', 'V03AN05', 50.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('air', 'V03AN05', 70.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('air', 'V03AN05', 85.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('air', 'V03AN05', 99.7, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('air', 'V03AN05', 100.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alanine', NULL, 2.08, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alanine', NULL, 2.76, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alanine', NULL, 95.1, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alanine', NULL, 600.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('albumin', 'B05AA01', 1.8, 'ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('albumin', 'B05AA01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('albumin', 'B05AA01', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('albumin (human)', 'V07AB', 0.03, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('albumin (human)', 'V07AB', 0.3, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('albumin (human)', 'V07AB', 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('albumin (human)', 'V07AB', 25.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('albumin (human)', 'V07AB', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('albumin (human)', 'V07AB', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alcohol anhydrous', 'V03AZ01', 0.05, 'ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alcohol anhydrous', 'V03AZ01', 0.2, 'ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alcohol anhydrous', 'V03AZ01', 0.995, 'ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alcohol anhydrous', 'V03AZ01', 2.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alcohol anhydrous', 'V03AZ01', 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alcohol anhydrous', 'V03AZ01', 5.0, 'ml/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alcohol anhydrous', 'V03AZ01', 12.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alcohol anhydrous', 'V03AZ01', 18.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alcohol anhydrous', 'V03AZ01', 20.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alcohol anhydrous', 'V03AZ01', 26.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alcohol anhydrous', 'V03AZ01', 40.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alcohol anhydrous', 'V03AZ01', 49.95, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alcohol anhydrous', 'V03AZ01', 50.16, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alcohol anhydrous', 'V03AZ01', 53.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alcohol anhydrous', 'V03AZ01', 53.72, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alcohol anhydrous', 'V03AZ01', 54.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alcohol anhydrous', 'V03AZ01', 57.02, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alcohol anhydrous', 'V03AZ01', 58.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alcohol anhydrous', 'V03AZ01', 61.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alcohol anhydrous', 'V03AZ01', 65.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alcohol anhydrous', 'V03AZ01', 65.87, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alcohol anhydrous', 'V03AZ01', 70.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alcohol anhydrous', 'V03AZ01', 70.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alcohol anhydrous', 'V03AZ01', 72.38, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alcohol anhydrous', 'V03AZ01', 75.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alcohol anhydrous', 'V03AZ01', 79.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alcohol anhydrous', 'V03AZ01', 82.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alcohol anhydrous', 'V03AZ01', 100.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alcohol denatured', NULL, 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alcohol denatured', NULL, 71.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aldesleukin', 'L03AC01', 22000000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aldioxa', NULL, 0.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alefacept', 'L04AA15', 15.0, 'mg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alemtuzumab', 'L01XC04', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alendronic acid (alendronate sodium trihydrate)', 'M05BA04', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alendronic acid (alendronate sodium trihydrate)', 'M05BA04', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alendronic acid (alendronate sodium trihydrate)', 'M05BA04', 70.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alendronic acid (alendronate sodium trihydrate)', 'M05BA04', 70.0, 'mg/75ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alendronic acid (alendronate sodium)', 'M05BA04', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alendronic acid (alendronate sodium)', 'M05BA04', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alendronic acid (alendronate sodium)', 'M05BA04', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alendronic acid (alendronate sodium)', 'M05BA04', 70.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alfacalcidol', 'A11CC03', 0.25, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alfacalcidol', 'A11CC03', 1.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alfacalcidol', 'A11CC03', 2.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alfentanil (alfentanil hydrochloride)', 'N01AH02', 500.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alfuzosin hydrochloride', 'G04CA01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alglucosidase alfa', 'A16AB07', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aliskiren (aliskiren fumarate)', 'C09XA02', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aliskiren (aliskiren fumarate)', 'C09XA02', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl benzyl ammonium saccharinate', NULL, 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.024, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.025, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.08, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.09, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.105, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.106, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.11, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.115, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.125, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.1375, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.14, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.145, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.15, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.154, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.175, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.59, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.74, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.84, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 0.86, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 1.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 1.28, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 1.29, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 1.43, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 1.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 1.6, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 1.75, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.35, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.37, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.44, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 2.85, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 3.12, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 3.15, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 3.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 4.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 6.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkyl dimethyl ethylbenzyl ammonium chloride', 'V07AV', 7.95, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alkylc9-c15 tolyl methyl trimethyl ammonium chlori', NULL, 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('allantoin', NULL, 0.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('allantoin', NULL, 1.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('allergen extract - alum precipitated', 'V01AA02', 100.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('allergen extract - alum precipitated', 'V01AA02', 1000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('allergen extract - alum precipitated', 'V01AA02', 10000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('allergen extract - diagnostic', 'V04CL', 0.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('allergenic extract non-pollen', 'V01AA20', 40000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('allergenic extracts', 'V01AA20', 0.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('allergenic extracts pollens', 'V01AA20', 40000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('allopurinol', 'M04AA01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('allopurinol', 'M04AA01', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('allopurinol', 'M04AA01', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('almotriptan (almotriptan malate)', 'N02CC05', 6.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('almotriptan (almotriptan malate)', 'N02CC05', 12.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aloe', NULL, 2.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aloe (aloe ferox)', NULL, 83.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alpha1-proteinase inhibitor (human)', 'B02AB02', 1000.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alprazolam', 'N05BA12', 0.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alprazolam', 'N05BA12', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alprazolam', 'N05BA12', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alprazolam', 'N05BA12', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alprostadil', 'G04BE01', 23.2, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alprostadil', 'G04BE01', 250.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alprostadil', 'G04BE01', 500.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alprostadil', 'G04BE01', 1000.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alteplase', 'B01AD02', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alteplase', 'B01AD02', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('alteplase', 'B01AD02', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('altretamine', 'L01XX03', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aluminum acetate', NULL, 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aluminum chloride', NULL, 25.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aluminum chlorohydrate', NULL, 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aluminum diacetate', NULL, 0.35, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aluminum hydroxide', NULL, 200.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aluminum hydroxide', NULL, 228.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aluminum hydroxide', NULL, 300.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aluminum hydroxide', NULL, 400.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aluminum hydroxide (dried aluminum hydroxide gel)', NULL, 165.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aluminum hydroxide-magnesium carbonate-co dried gel', NULL, 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aluminum hydroxide-magnesium carbonate-co dried gel', NULL, 400.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amantadine hydrochloride', 'N04BB01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amantadine hydrochloride', 'N04BB01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ambrisentan', 'C02KX02', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ambrisentan', 'C02KX02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amcinonide', 'D07AC11', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amikacin (amikacin sulfate)', 'J01GB06', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amiloride hydrochloride', 'C03DB01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aminolevulinic acid hydrochloride', 'L01XD04', 20.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aminophylline', 'R03DA05', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aminophylline', 'R03DA05', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aminophylline', 'R03DA05', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aminophylline', 'R03DA05', 225.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aminophylline', 'R03DA05', 350.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amiodarone hydrochloride', 'C01BD01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amiodarone hydrochloride', 'C01BD01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amiodarone hydrochloride', 'C01BD01', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amitriptyline hydrochloride', 'N06AA09', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amitriptyline hydrochloride', 'N06AA09', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amitriptyline hydrochloride', 'N06AA09', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amitriptyline hydrochloride', 'N06AA09', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amitriptyline hydrochloride', 'N06AA09', 75.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amlodipine (amlodipine besylate)', 'C08CA01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ammonium chloride', 'B05XA04', 12.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ammonium chloride', 'B05XA04', 125.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ammonium hydroxide', NULL, 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amoxicillin', 'J01CA04', 125.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amoxicillin', 'J01CA04', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amoxicillin', 'J01CA04', 250.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amoxicillin', 'J01CA04', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04', 125.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04', 125.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04', 200.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04', 250.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04', 400.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amoxicillin (amoxicillin trihydrate)', 'J01CA04', 875.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amoxicillin (amoxicillin)', 'J01CA04', 125.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amoxicillin (amoxicillin)', 'J01CA04', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amoxicillin (amoxicillin)', 'J01CA04', 250.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amoxicillin (amoxicillin)', 'J01CA04', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amphetamine aspartate monohydrate', NULL, 1.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amphetamine aspartate monohydrate', NULL, 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amphetamine aspartate monohydrate', NULL, 3.75, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amphetamine aspartate monohydrate', NULL, 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amphetamine aspartate monohydrate', NULL, 6.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amphetamine aspartate monohydrate', NULL, 7.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amphetamine sulfate', NULL, 1.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amphetamine sulfate', NULL, 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amphetamine sulfate', NULL, 3.75, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amphetamine sulfate', NULL, 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amphetamine sulfate', NULL, 6.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amphetamine sulfate', NULL, 7.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amphotericin b', 'J02AA01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amphotericin b', 'J02AA01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amphotericin b', 'J02AA01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ampicillin', 'J01CA01', 125.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ampicillin', 'J01CA01', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ampicillin', 'J01CA01', 250.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ampicillin', 'J01CA01', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ampicillin', 'J01CA01', 500.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ampicillin (ampicillin sodium)', 'J01CA01', 1.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ampicillin (ampicillin sodium)', 'J01CA01', 2.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ampicillin (ampicillin sodium)', 'J01CA01', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ampicillin (ampicillin sodium)', 'J01CA01', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amsacrine', 'L01XX01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amyl cinnamal', NULL, 0.015, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amylase', NULL, 11000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amylase', NULL, 16600.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amylase', NULL, 20000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amylase', NULL, 30000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amylase', NULL, 33200.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amylase', NULL, 39000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amylase', NULL, 55000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amylase', NULL, 60000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amylase', NULL, 65000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amylase', NULL, 66400.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amylase', NULL, 74000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amylase', NULL, 140000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('amylmetacresol', NULL, 0.6, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('anagrelide (anagrelide hydrochloride monohydrate)', 'L01XX35', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('anagrelide (anagrelide hydrochloride)', 'L01XX35', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('anakinra', 'QA03AB16', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('anastrozole', 'L02BG03', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ancestim', 'L03AA12', 1875.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('anethole trithione', 'A16AX02', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('anidulafungin', 'J02AX06', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('antazoline phosphate', NULL, 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('antazoline phosphate', NULL, 0.51, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('anti-inhibitor coagulant complex', NULL, 1200.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('anti-thymocyte globulin (rabbit)', 'L04AA04', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('antihemophilic factor (human)', NULL, 300.0, 'unit/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('antihemophilic factor (human)', NULL, 450.0, 'unit/5.0ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('antihemophilic factor (human)', NULL, 600.0, 'unit/10ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('antihemophilic factor (human)', NULL, 900.0, 'unit/10.0ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('antihemophilic factor (human)', NULL, 1200.0, 'unit/15ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('antihemophilic factor (recombinant)', 'B02BD02', 250.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('antihemophilic factor (recombinant)', 'B02BD02', 500.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('antihemophilic factor (recombinant)', 'B02BD02', 1000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('antihemophilic factor (recombinant)', 'B02BD02', 1500.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('antihemophilic factor (recombinant)', 'B02BD02', 2000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('antihemophilic factor (recombinant)', 'B02BD02', 3000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('antipyrine', NULL, 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('antipyrine', NULL, 54.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('antithrombin iii (human)', 'B01AB02', 550.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('antithrombin iii (human)', 'B01AB02', 1000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('antithrombin iii (human)', 'B01AB02', 1100.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('antithrombin iii (human)', 'B01AB02', 1650.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('apis mellifera venom protein extract', 'V01AA07', 1.1, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('apis mellifera venom protein extract', 'V01AA07', 120.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('apis mellifera venom protein extract', 'V01AA07', 1300.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('apraclonidine (apraclonidine hydrochloride)', 'S01EA03', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('apraclonidine (apraclonidine hydrochloride)', 'S01EA03', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aprepitant', 'A04AD12', 80.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aprepitant', 'A04AD12', 125.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aprotinin (bovine)', 'B02AB01', 3000.0, 'kiu/1ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aprotinin (bovine)', 'B02AB01', 6000.0, 'kiu/2ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aprotinin (bovine)', 'B02AB01', 10000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aprotinin (bovine)', 'B02AB01', 15000.0, 'kiu/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('argatroban', 'B01AE03', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('arginine', NULL, 1.04, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('arginine', NULL, 1.15, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('arginine', NULL, 1.96, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('arginine', NULL, 107.1, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('arginine', NULL, 600.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('arginine', NULL, 810.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('arginine', NULL, 850.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('arginine hydrochloride', 'V04CD', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aripiprazole', 'N05AX12', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aripiprazole', 'N05AX12', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aripiprazole', 'N05AX12', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aripiprazole', 'N05AX12', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aripiprazole', 'N05AX12', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aripiprazole', 'N05AX12', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('articaine hydrochloride', NULL, 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('asparaginase', 'L01XX02', 10000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('atazanavir (atazanavir sulfate)', 'J05AE08', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('atazanavir (atazanavir sulfate)', 'J05AE08', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('atazanavir (atazanavir sulfate)', 'J05AE08', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('atenolol', 'C07AB03', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('atenolol', 'C07AB03', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('atenolol', 'C07AB03', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('atomoxetine (atomoxetine hydrochloride)', 'N06BA09', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('atomoxetine (atomoxetine hydrochloride)', 'N06BA09', 18.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('atomoxetine (atomoxetine hydrochloride)', 'N06BA09', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('atomoxetine (atomoxetine hydrochloride)', 'N06BA09', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('atomoxetine (atomoxetine hydrochloride)', 'N06BA09', 60.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('atomoxetine (atomoxetine hydrochloride)', 'N06BA09', 80.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('atomoxetine (atomoxetine hydrochloride)', 'N06BA09', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('atorvastatin (atorvastatin calcium propylene glycol solvate)', 'C10AA05', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('atorvastatin (atorvastatin calcium propylene glycol solvate)', 'C10AA05', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('atorvastatin (atorvastatin calcium propylene glycol solvate)', 'C10AA05', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('atorvastatin (atorvastatin calcium propylene glycol solvate)', 'C10AA05', 80.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('atorvastatin (atorvastatin calcium)', 'C10AA05', 80.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('atovaquone', 'P01AX06', 62.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('atovaquone', 'P01AX06', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('atovaquone', 'P01AX06', 750.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('atracurium besylate', 'M03AC04', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('atropine sulfate', 'S01FA01', 0.025, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('atropine sulfate', 'S01FA01', 0.1, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('atropine sulfate', 'S01FA01', 0.3, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('atropine sulfate', 'S01FA01', 0.4, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('atropine sulfate', 'S01FA01', 0.6, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('atropine sulfate', 'S01FA01', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('atropine sulfate', 'S01FA01', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('auranofin', 'M01CB03', 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('avobenzone', NULL, 0.028, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('avobenzone', NULL, 0.03, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('avobenzone', NULL, 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('avobenzone', NULL, 0.7, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('avobenzone', NULL, 0.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('avobenzone', NULL, 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('avobenzone', NULL, 1.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('avobenzone', NULL, 1.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('avobenzone', NULL, 1.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('avobenzone', NULL, 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('avobenzone', NULL, 2.0, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('avobenzone', NULL, 2.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('avobenzone', NULL, 2.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('avobenzone', NULL, 2.44, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('avobenzone', NULL, 2.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('avobenzone', NULL, 2.5, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('avobenzone', NULL, 2.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('avobenzone', NULL, 2.85, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('avobenzone', NULL, 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('avobenzone', NULL, 3.0, '%/50ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('avobenzone', NULL, 3.0, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('avobenzone', NULL, 3.06, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('avobenzone', NULL, 3.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('avobenzone', NULL, 3.5, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('avobenzone', NULL, 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('avobenzone', NULL, 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('avobenzone', NULL, 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('azacitidine', 'L01BC07', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('azathioprine', 'L04AX01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('azathioprine (azathioprine sodium)', 'L04AX01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('azelaic acid', 'D10AX03', 15.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('azithromycin', 'J01FA10', 100.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('azithromycin', 'J01FA10', 200.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('azithromycin', 'J01FA10', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('azithromycin', 'J01FA10', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('azithromycin', 'J01FA10', 600.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('azithromycin (azithromycin hydrogen citrate)', 'J01FA10', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('azithromycin (azithromycin isopropanolate monohydrate)', 'J01FA10', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('azithromycin (azithromycin monohydrate hemiethanolate)', 'J01FA10', 100.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('azithromycin (azithromycin monohydrate hemiethanolate)', 'J01FA10', 200.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('azithromycin (azithromycin monohydrate hemiethanolate)', 'J01FA10', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('azithromycin (azithromycin monohydrate hemiethanolate)', 'J01FA10', 600.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('azithromycin (azithromycin monohydrate)', 'J01FA10', 100.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('azithromycin (azithromycin monohydrate)', 'J01FA10', 200.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('azithromycin (azithromycin monohydrate)', 'J01FA10', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('azithromycin (azithromycin monohydrate)', 'J01FA10', 600.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('aztreonam', 'J01DF01', 75.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bacillus calmette-guerin (bcg) strain tice', 'L03AX03', 800000000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bacillus calmette-guerin (bcg) substrain connaught', 'J07AN01', 0.1, 'mg/0.1ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bacillus calmette-guerin (bcg) substrain connaught', 'J07AN01', 81.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bacitracin', 'J01XX10', 500.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bacitracin', 'J01XX10', 50000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bacitracin', 'J01XX10', 50000.0, 'unit/10ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bacitracin (bacitracin zinc)', NULL, 400.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bacitracin (bacitracin zinc)', NULL, 500.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bacitracin zinc', NULL, 400.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bacitracin zinc', NULL, 500.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('baclofen', 'M03BX01', 0.05, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('baclofen', 'M03BX01', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('baclofen', 'M03BX01', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('baclofen', 'M03BX01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('baclofen', 'M03BX01', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('basiliximab', 'L04AC02', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('becaplermin (rhpdgf-bb)', 'D03AX06', 100.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('beclomethasone dipropionate', 'R03BA01', 0.025, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('beclomethasone dipropionate', 'R03BA01', 50.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('beclomethasone dipropionate', 'R03BA01', 100.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('belladonna', NULL, 0.2, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('belladonna', NULL, 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bemotrizinol', NULL, 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bemotrizinol', NULL, 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bemotrizinol', NULL, 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benazepril hydrochloride', 'C09AA07', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benazepril hydrochloride', 'C09AA07', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benazepril hydrochloride', 'C09AA07', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benoxinate hydrochloride', NULL, 0.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benserazide (benserazide hydrochloride)', NULL, 12.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benserazide (benserazide hydrochloride)', NULL, 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benserazide (benserazide hydrochloride)', NULL, 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.01, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.02, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.024, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.025, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.032, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.034, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.035, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.04, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.0532, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.08, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.085, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.09, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.105, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.106, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.11, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.115, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.11625, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.12, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.125, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.13, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.13, 'mg/100mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.1375, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.14, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.145, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.15, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.154, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.175, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.252, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.27, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.28, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.33, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.347, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.36, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.384, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.59, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.64, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.72, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.74, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.84, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.86, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 0.96, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 1.085, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 1.186, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 1.248, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 1.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 1.28, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 1.29, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 1.43, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 1.44, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 1.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 1.52, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 1.52, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 1.54, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 1.55, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 1.6, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 1.69, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 1.7, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 1.75, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 1.89, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 1.92, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 2.17, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 2.17, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 2.173, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 2.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 2.2, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 2.2, '00%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 2.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 2.29, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 2.35, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 2.37, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 2.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 2.44, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 2.48, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 2.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 2.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 2.8, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 2.85, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 2.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 3.01, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 3.06, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 3.07, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 3.09, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 3.12, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 3.15, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 3.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 3.35, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 3.38, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 3.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 3.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 3.89, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 3.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 4.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 4.09, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 4.1, '000%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 4.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 4.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 4.339, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 4.34, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 4.34, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 4.38, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 4.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 4.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 4.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 5.12, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 5.625, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 5.63, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 5.632, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 6.14, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 6.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 6.24, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 6.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 6.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 6.6, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 6.76, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 7.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 7.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 7.6, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 7.675, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 7.68, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 7.95, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 8.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 8.19, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 8.68, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 8.68, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 8.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 9.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 9.216, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 9.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 11.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 11.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 13.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 14.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 17.06, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 20.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzalkonium chloride', 'V07AV', 26.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzethonium chloride', 'D08AJ08', 0.023, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzethonium chloride', 'D08AJ08', 0.03, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzethonium chloride', 'D08AJ08', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzethonium chloride', 'D08AJ08', 0.13, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzethonium chloride', 'D08AJ08', 0.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzethonium chloride', 'D08AJ08', 0.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzethonium chloride', 'D08AJ08', 0.28, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzethonium chloride', 'D08AJ08', 0.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzethonium chloride', 'D08AJ08', 0.35, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzocaine', 'C05AD03', 0.364, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzocaine', 'C05AD03', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzocaine', 'C05AD03', 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzocaine', 'C05AD03', 7.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzocaine', 'C05AD03', 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzocaine', 'C05AD03', 14.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzocaine', 'C05AD03', 14.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzocaine', 'C05AD03', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzocaine', 'C05AD03', 18.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzocaine', 'C05AD03', 20.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzocaine', 'C05AD03', 23.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzocaine', 'C05AD03', 180.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzoin', 'D08AX', 1.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzoin', 'D08AX', 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzoin', 'D08AX', 10.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzoin', 'D08AX', 25.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzophenone', NULL, 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzoyl peroxide', 'D10AE01', 2.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzoyl peroxide', 'D10AE01', 2.5, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzoyl peroxide', 'D10AE01', 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzoyl peroxide', 'D10AE01', 3.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzoyl peroxide', 'D10AE01', 3.7, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzoyl peroxide', 'D10AE01', 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzoyl peroxide', 'D10AE01', 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzoyl peroxide', 'D10AE01', 8.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzoyl peroxide', 'D10AE01', 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzoyl peroxide', 'D10AE01', 20.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzoyl peroxide', 'D10AE01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benztropine mesylate', 'N04AC01', 0.4, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benztropine mesylate', 'N04AC01', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benztropine mesylate', 'N04AC01', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benztropine mesylate', 'N04AC01', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzydamine hydrochloride', 'A01AD02', 0.15, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzydamine hydrochloride', 'A01AD02', 1.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzyl di-hydroxyethyl-cocoalkyl-ammonium chl', NULL, 0.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('benzyl paraben', NULL, 0.16, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('beractant', 'R07AA30', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bermuda grass', 'V01AA02', 10000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('besifloxacin', 'S01AX23', 0.6, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('beta-carotene', NULL, 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('beta-carotene', NULL, 2700.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('betahistine hydrochloride', 'N07CA01', 16.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('betahistine hydrochloride', 'N07CA01', 24.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('betaine', 'A16AA06', 1.0, 'g/1.7cc');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('betamethasone', 'A07EA04', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('betamethasone (betamethasone 21-disodium phosphate)', NULL, 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('betamethasone (betamethasone dipropionate)', 'D07AC01', 0.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('betamethasone (betamethasone dipropionate)', 'D07AC01', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('betamethasone (betamethasone sodium phosphate)', 'A07EA04', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('betamethasone (betamethasone sodium phosphate)', 'A07EA04', 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('betamethasone (betamethasone sodium phosphate)', 'A07EA04', 5.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('betamethasone (betamethasone valerate)', 'D07AC01', 0.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('betamethasone (betamethasone valerate)', 'D07AC01', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('betamethasone (betamethasone valerate)', 'D07AC01', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('betamethasone (betamethasone valerate)', 'D07AC01', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('betamethasone acetate', NULL, 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('betamethasone dipropionate', 'D07AC01', 0.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('betamethasone dipropionate', 'D07AC01', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('betamethasone dipropionate', 'D07AC01', 0.64, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('betamethasone valerate', 'D07AC01', 0.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('betamethasone valerate', 'D07AC01', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('betamethasone valerate', 'D07AC01', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('betamethasone valerate', 'D07AC01', 1.22, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('betaxolol (betaxolol hydrochloride)', 'S01ED02', 0.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('betaxolol (betaxolol hydrochloride)', 'S01ED02', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bethanechol chloride', 'N07AB02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bethanechol chloride', 'N07AB02', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bethanechol chloride', 'N07AB02', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bevacizumab', 'L01XC07', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bezafibrate', 'C10AB02', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bezafibrate', 'C10AB02', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bicalutamide', 'L02BB03', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bile salts', NULL, 65.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bile salts', NULL, 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bimatoprost', 'S01EE03', 0.01, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bimatoprost', 'S01EE03', 0.03, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('biotin', 'A11HA05', 10.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('biotin', 'A11HA05', 12.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('biotin', 'A11HA05', 20.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('biotin', 'A11HA05', 50.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bis(1-piperidylthiocarbonyl)disulfide', NULL, 0.005, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bisacodyl', 'A06AB02', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bisacodyl', 'A06AB02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bismuth camphocarbonate', NULL, 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bismuth dipropylacetate', 'R07AX', 135.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bismuth subgallate', 'A07BB', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bismuth subsalicylate', 'A07BB', 17.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bismuth subsalicylate', 'A07BB', 17.6, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bismuth subsalicylate', 'A07BB', 35.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bismuth subsalicylate', 'A07BB', 35.2, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bismuth subsalicylate', 'A07BB', 236.0, 'mg/28.4ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bismuth subsalicylate', 'A07BB', 262.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bismuth tribromophenate', 'D09AX', 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bisoctrizole', NULL, 1.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bisoctrizole', NULL, 2.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bisoctrizole', NULL, 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bisoprolol fumarate', 'C07AB07', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bisoprolol fumarate', 'C07AB07', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bivalirudin', 'B01AE06', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bleomycin (bleomycin sulfate)', 'L01DC01', 15.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bleomycin sulfate', 'L01DC01', 15.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bortezomib (bortezomib mannitol boronic ester)', 'L01XX32', 3.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bosentan (bosentan monohydrate)', 'C02KX01', 62.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bosentan (bosentan monohydrate)', 'C02KX01', 125.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('botulinum antitoxin', 'J06AA04', 5000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('botulinum toxin type a', 'M03AX01', 100.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bretylium tosylate', 'C01BD02', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('brimonidine tartrate', 'S01EA05', 0.15, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('brimonidine tartrate', 'S01EA05', 0.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('brinzolamide', 'S01EC04', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bromazepam', 'N05BA08', 1.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bromazepam', 'N05BA08', 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bromazepam', 'N05BA08', 6.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bromine-phenol-benzethonium chloride complex', NULL, 0.852, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bromocriptine (bromocriptine mesylate)', 'G02CB01', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bromocriptine (bromocriptine mesylate)', 'G02CB01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bromocriptine mesylate', 'G02CB01', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('brompheniramine maleate', NULL, 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('brompheniramine maleate', NULL, 1.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('brompheniramine maleate', NULL, 2.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('brompheniramine maleate', NULL, 4.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bronopol', NULL, 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('budesonide', 'R03BA02', 0.125, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('budesonide', 'R03BA02', 0.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('budesonide', 'R03BA02', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('budesonide', 'R03BA02', 2.3, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('budesonide', 'R03BA02', 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('budesonide', 'R03BA02', 64.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('budesonide', 'R03BA02', 100.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('budesonide', 'R03BA02', 200.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('budesonide', 'R03BA02', 400.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('buffer solution', NULL, 10.0, 'ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bumetanide', 'C03CA02', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bumetanide', 'C03CA02', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bupivacaine hydrochloride', 'N01BB01', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bupivacaine hydrochloride', 'N01BB01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bupivacaine hydrochloride', 'N01BB01', 7.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('buprenorphine', 'N02AE01', 5.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('buprenorphine', 'N02AE01', 10.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('buprenorphine', 'N02AE01', 20.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('buprenorphine (buprenorphine hydrochloride)', NULL, 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('buprenorphine (buprenorphine hydrochloride)', NULL, 8.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bupropion hydrochloride', 'N06AX12', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bupropion hydrochloride', 'N06AX12', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('bupropion hydrochloride', 'N06AX12', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('buserelin (buserelin acetate)', 'L02AE01', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('buserelin (buserelin acetate)', 'L02AE01', 6.3, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('buserelin (buserelin acetate)', 'L02AE01', 9.45, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('buspirone hydrochloride', 'N05BE01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('buspirone hydrochloride', 'N05BE01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('busulfan', 'L01AB01', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('busulfan', 'L01AB01', 6.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('butalbital', 'Z01AA12', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('butamben', NULL, 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('butamben', NULL, 25.7, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('butanediol', NULL, 5.7, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('butoconazole nitrate', 'G01AF15', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('butorphanol tartrate', 'N02AF01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('butoxy polyoxypropylene polyoxyethylene gly.iodine', 'D08AG', 10.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('butoxy polyoxypropylene polyoxyethylene gly.iodine', 'D08AG', 15.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('butylparaben', NULL, 0.16, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cabergoline', 'G02CB03', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('caffeine', 'N06BC01', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('caffeine', 'N06BC01', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('caffeine', 'N06BC01', 32.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('caffeine', 'N06BC01', 33.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('caffeine', 'N06BC01', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('caffeine', 'N06BC01', 60.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('caffeine', 'N06BC01', 65.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('caffeine', 'N06BC01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('caffeine (caffeine citrate)', NULL, 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('caffeine citrate', NULL, 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('caffeine citrate', NULL, 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calamine', NULL, 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calamine', NULL, 8.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calamine', NULL, 8.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcipotriol', 'D05AX02', 50.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcipotriol (calcipotriol monohydrate)', NULL, 50.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcitonin (salmon synthetic)', 'H05BA01', 100.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcitonin (salmon synthetic)', 'H05BA01', 200.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcitriol', 'D05AX03', 0.25, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcitriol', 'D05AX03', 0.5, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcitriol', 'D05AX03', 1.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcitriol', 'D05AX03', 2.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcitriol', 'D05AX03', 3.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium (calcium carbonate)', NULL, 270.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium (calcium carbonate)', NULL, 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium (calcium carbonate)', NULL, 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium acetate', 'V03AE', 440.0, 'mg/25ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium acetate', 'V03AE', 667.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium carbonate', 'A02AC01', 160.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium carbonate', 'A02AC01', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium carbonate', 'A02AC01', 200.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium carbonate', 'A02AC01', 246.2, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium carbonate', 'A02AC01', 350.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium carbonate', 'A02AC01', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium carbonate', 'A02AC01', 675.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium carbonate', 'A02AC01', 800.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium carbonate', 'A02AC01', 1000.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium carbonate', 'A02AC01', 1177.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 0.0154, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 0.048, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 0.176, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 0.1838, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 0.2, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 0.209, 'g/1000ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 0.257, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 0.271, 'g/1000ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 0.343, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 0.36, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 0.48, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 0.507, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 1.84, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 2.49, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 2.5, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 3.31, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 3.78, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 4.99, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 5.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 5.145, 'g/1000ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 6.24, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 6.61, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 6.62, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 7.44, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 7.45, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 7.47, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 7.48, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 7.49, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 7.74, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 8.268, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 8.269, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 8.27, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 9.92, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 9.923, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 10.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 10.25, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 11.58, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 14.9, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 16.55, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 18.3, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 18.4, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 20.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 23.9, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 25.7, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 33.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 37.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 40.0, 'µmol/1ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 80.0, 'µmol/2ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 200.0, 'µmol/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 257.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium chloride', 'B05ZA', 370.0, 'mg/20ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium gluconate', 'A12AA03', 94.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium glycerophosphate', NULL, 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium levulinate', NULL, 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium polycarbophil', 'A06AC08', 625.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium polystyrene sulfonate', 'V03AE01', 999.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('calcium saccharate', NULL, 4.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('camphor', NULL, 0.3, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('camphor', NULL, 0.38, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('camphor', NULL, 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('camphor', NULL, 0.97, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('camphor', NULL, 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('camphor', NULL, 1.7, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('camphor', NULL, 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('camphor', NULL, 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('camphor', NULL, 65.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('camphor', NULL, 649.0, 'mg/1g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('canakinumab', 'L04AC08', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('candesartan cilexetil', 'C09CA06', 4.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('candesartan cilexetil', 'C09CA06', 8.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('candesartan cilexetil', 'C09CA06', 16.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('candesartan cilexetil', 'C09CA06', 32.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cannabidiol (cannabis sativa extract)', NULL, 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cantharidin', NULL, 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('capecitabine', 'L01BC06', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('capecitabine', 'L01BC06', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('capsaicin', 'N01BX04', 0.035, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('capsicum oleoresin', NULL, 0.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('captopril', 'C09AA01', 6.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('captopril', 'C09AA01', 12.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('captopril', 'C09AA01', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('captopril', 'C09AA01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('captopril', 'C09AA01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carbachol', 'S01EB02', 0.01, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carbachol', 'S01EB02', 0.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carbachol', 'S01EB02', 1.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carbachol', 'S01EB02', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carbachol', 'S01EB02', 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carbamazepine', 'N03AF01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carbamazepine', 'N03AF01', 100.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carbamazepine', 'N03AF01', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carbamazepine', 'N03AF01', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carbetocin', 'H01BB03', 100.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carbidopa', NULL, 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carbidopa', NULL, 12.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carbidopa', NULL, 18.75, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carbidopa', NULL, 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carbidopa', NULL, 31.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carbidopa', NULL, 37.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carbidopa', NULL, 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carbidopa (carbidopa monohydrate)', NULL, 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carbolic oil', NULL, 50.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carbon dioxide', 'V03AN02', 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carbon dioxide', 'V03AN02', 7.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carbon dioxide', 'V03AN02', 12.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carbon dioxide', 'V03AN02', 15.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carbon dioxide', 'V03AN02', 23.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carbon dioxide', 'V03AN02', 30.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carbon dioxide', 'V03AN02', 50.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carbon dioxide', 'V03AN02', 99.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carbon dioxide', 'V03AN02', 100.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carbon monoxide', NULL, 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carbon monoxide', NULL, 0.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carboplatin', 'L01XA02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carboprost (carboprost tromethamine)', 'G02AD04', 250.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carmustine', 'L01AD01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carvacrol', NULL, 0.02, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carvacrol', NULL, 2.37, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carvedilol', 'C07AG02', 3.125, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carvedilol', 'C07AG02', 6.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carvedilol', 'C07AG02', 12.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('carvedilol', 'C07AG02', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cascara sagrada', NULL, 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('caspofungin (caspofungin acetate)', 'J02AX04', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('caspofungin (caspofungin acetate)', 'J02AX04', 70.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cat (felis domesticus) pelt and cat dander', 'V01AA11', 10000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefaclor', 'J01DC04', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefaclor', 'J01DC04', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefaclor', 'J01DC04', 75.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefaclor', 'J01DC04', 125.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefaclor', 'J01DC04', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefaclor', 'J01DC04', 250.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefaclor', 'J01DC04', 375.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefaclor', 'J01DC04', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefadroxil', 'J01DB05', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefazolin (cefazolin sodium)', 'J01DB04', 1.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefazolin (cefazolin sodium)', 'J01DB04', 10.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefazolin (cefazolin sodium)', 'J01DB04', 20.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefazolin (cefazolin sodium)', 'J01DB04', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefepime (cefepime hydrochloride)', 'J01DE01', 1.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefepime (cefepime hydrochloride)', 'J01DE01', 2.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefixime', 'J01DD08', 100.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefixime', 'J01DD08', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefotaxime (cefotaxime sodium)', 'J01DD01', 1.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefotaxime (cefotaxime sodium)', 'J01DD01', 2.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefotaxime (cefotaxime sodium)', 'J01DD01', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefotaxime sodium', 'J01DD01', 1.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefotaxime sodium', 'J01DD01', 2.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefotaxime sodium', 'J01DD01', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefoxitin (cefoxitin sodium)', 'J01DC01', 1.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefoxitin (cefoxitin sodium)', 'J01DC01', 2.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefoxitin (cefoxitin sodium)', 'J01DC01', 10.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefprozil', 'J01DC10', 125.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefprozil', 'J01DC10', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefprozil', 'J01DC10', 250.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefprozil', 'J01DC10', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefprozil (cefprozil monohydrate)', 'J01DC10', 125.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefprozil (cefprozil monohydrate)', 'J01DC10', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefprozil (cefprozil monohydrate)', 'J01DC10', 250.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefprozil (cefprozil monohydrate)', 'J01DC10', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ceftazidime', 'J01DD02', 1.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ceftazidime', 'J01DD02', 2.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ceftazidime', 'J01DD02', 6.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ceftazidime (ceftazidime pentahydrate)', 'J01DD02', 1.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ceftazidime (ceftazidime pentahydrate)', 'J01DD02', 2.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ceftazidime (ceftazidime pentahydrate)', 'J01DD02', 6.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ceftriaxone (ceftriaxone sodium)', 'J01DD04', 0.25, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ceftriaxone (ceftriaxone sodium)', 'J01DD04', 1.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ceftriaxone (ceftriaxone sodium)', 'J01DD04', 2.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ceftriaxone (ceftriaxone sodium)', 'J01DD04', 10.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ceftriaxone (ceftriaxone sodium)', 'J01DD04', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefuroxime (cefuroxime axetil)', 'J01DC02', 125.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefuroxime (cefuroxime axetil)', 'J01DC02', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefuroxime (cefuroxime axetil)', 'J01DC02', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefuroxime (cefuroxime sodium)', 'J01DC02', 1.5, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefuroxime (cefuroxime sodium)', 'J01DC02', 7.5, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cefuroxime (cefuroxime sodium)', 'J01DC02', 750.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('celecoxib', 'M01AH01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('celecoxib', 'M01AH01', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cellulase', NULL, 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cephalexin', 'J01DB01', 125.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cephalexin', 'J01DB01', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cephalexin', 'J01DB01', 250.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cephalexin', 'J01DB01', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cephalothin (cephalothin sodium)', 'J01DB03', 1.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('certolizumab pegol', 'L04AB05', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cetalkonium chloride', NULL, 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cetirizine hydrochloride', 'R06AE07', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cetirizine hydrochloride', 'R06AE07', 5.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cetirizine hydrochloride', 'R06AE07', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cetirizine hydrochloride', 'R06AE07', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cetrimide', 'D08AJ04', 0.15, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cetrimide', 'D08AJ04', 150.0, 'mg/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cetrimonium bromide', 'D08AJ02', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cetrimonium bromide', 'D08AJ02', 150.0, 'mg/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cetrimonium bromide', 'D08AJ02', 750.0, 'mg/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cetrorelix (cetrorelix acetate)', 'H01CC02', 0.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cetrorelix (cetrorelix acetate)', 'H01CC02', 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cetuximab', 'L01XC06', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cetylpyridinium chloride', 'R02AA06', 0.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cetylpyridinium chloride', 'R02AA06', 0.07, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cetylpyridinium chloride', 'R02AA06', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cetylpyridinium chloride', 'R02AA06', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cetylpyridinium chloride', 'R02AA06', 1.4, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cetylpyridinium chloride', 'R02AA06', 1.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cetylpyridinium chloride', 'R02AA06', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('charcoal activated', 'A07BA01', 1.0, 'g/1g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('charcoal activated', 'A07BA01', 50.0, 'g/225ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('charcoal activated', 'A07BA01', 50.0, 'g/250ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('charcoal activated', 'A07BA01', 100.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('charcoal activated', 'A07BA01', 140.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('charcoal activated', 'A07BA01', 170.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('charcoal activated', 'A07BA01', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('charcoal activated', 'A07BA01', 222.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('charcoal activated', 'A07BA01', 225.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('charcoal activated', 'A07BA01', 260.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chloral hydrate', 'N05CC01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chloral hydrate', 'N05CC01', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorambucil', 'L01AA02', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chloramphenicol', 'S01AA01', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chloramphenicol', 'S01AA01', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chloramphenicol', 'S01AA01', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chloramphenicol', 'S01AA01', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chloramphenicol', 'S01AA01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chloramphenicol', 'S01AA01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chloramphenicol (chloramphenicol sodium succinate)', 'J01BA01', 1.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlordiazepoxide hydrochloride', 'N05BA02', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlordiazepoxide hydrochloride', 'N05BA02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlordiazepoxide hydrochloride', 'N05BA02', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorhexidine acetate', 'V07AV', 0.01, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorhexidine acetate', 'V07AV', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorhexidine acetate', 'V07AV', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorhexidine acetate', 'V07AV', 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorhexidine gluconate', 'V07AV', 0.003, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorhexidine gluconate', 'V07AV', 0.01, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorhexidine gluconate', 'V07AV', 0.015, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorhexidine gluconate', 'V07AV', 0.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorhexidine gluconate', 'V07AV', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorhexidine gluconate', 'V07AV', 0.12, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorhexidine gluconate', 'V07AV', 0.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorhexidine gluconate', 'V07AV', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorhexidine gluconate', 'V07AV', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorhexidine gluconate', 'V07AV', 0.75, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorhexidine gluconate', 'V07AV', 0.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorhexidine gluconate', 'V07AV', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorhexidine gluconate', 'V07AV', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorhexidine gluconate', 'V07AV', 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorhexidine gluconate', 'V07AV', 20.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorhexidine gluconate', 'V07AV', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorine (sodium dichloro-s-triazinetrione)', NULL, 3.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorine peroxide', NULL, 0.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorobutanol', 'A04AD04', 0.55, 'g/11ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorobutanol', 'A04AD04', 1.41875, 'kg/576l');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorobutanol', 'A04AD04', 38.3, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chloroprocaine hydrochloride', 'N01BA04', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chloroquinaldol', NULL, 0.08, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chloroquine diphosphate', 'P01BA01', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chloroxylenol', 'D08AE05', 0.15, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chloroxylenol', 'D08AE05', 0.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chloroxylenol', 'D08AE05', 0.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chloroxylenol', 'D08AE05', 0.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chloroxylenol', 'D08AE05', 0.36, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chloroxylenol', 'D08AE05', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chloroxylenol', 'D08AE05', 0.52, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chloroxylenol', 'D08AE05', 0.6, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chloroxylenol', 'D08AE05', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chloroxylenol', 'D08AE05', 1.49, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chloroxylenol', 'D08AE05', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chloroxylenol', 'D08AE05', 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chloroxylenol', 'D08AE05', 4.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chloroxylenol', 'D08AE05', 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chloroxylenol', 'D08AE05', 8.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorpheniramine maleate', 'R06AB04', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorpheniramine maleate', 'R06AB04', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorpheniramine maleate', 'R06AB04', 1.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorpheniramine maleate', 'R06AB04', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorpheniramine maleate', 'R06AB04', 2.0, 'mg/15ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorpheniramine maleate', 'R06AB04', 2.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorpheniramine maleate', 'R06AB04', 4.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorpheniramine maleate', 'R06AB04', 4.0, 'mg/15ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorpheniramine maleate', 'R06AB04', 4.0, 'mg/20ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorpheniramine maleate', 'R06AB04', 4.0, 'mg/24g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorpheniramine maleate', 'R06AB04', 4.0, 'mg/30ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorpheniramine maleate', 'R06AB04', 12.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorpromazine hydrochloride', 'N05AA01', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorpromazine hydrochloride', 'N05AA01', 27.9, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorpromazine hydrochloride', 'N05AA01', 55.7, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorpromazine hydrochloride', 'N05AA01', 55.8, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorpromazine hydrochloride', 'N05AA01', 111.4, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorpromazine hydrochloride', 'N05AA01', 111.6, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorpropamide', 'A10BB02', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorpropamide', 'A10BB02', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorthalidone', 'C03BA04', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorthalidone', 'C03BA04', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorthalidone', 'C03BA04', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chlorzoxazone', 'M03BB03', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cholestyramine resin', 'C10AC01', 4.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cholestyramine resin', 'C10AC01', 4.0, 'g/5g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cholestyramine resin', 'C10AC01', 4.0, 'g/9g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('choline', NULL, 2.222, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('choline bitartrate', NULL, 70.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('choriogonadotropin alpha', 'G03GA08', 250.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chorionic gonadotropin', 'G03GA01', 10000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chromic chloride', NULL, 6.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chromium (chromic chloride)', 'A12CX', 4.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chromium (chromic chloride)', 'A12CX', 10.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('chromium (chromium hvp chelate)', NULL, 20.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ciclesonide', 'R03BA08', 50.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ciclesonide', 'R03BA08', 100.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ciclesonide', 'R03BA08', 200.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ciclopirox', 'D01AE14', 8.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ciclopirox', 'D01AE14', 80.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ciclopirox olamine', 'D01AE14', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ciclopirox olamine', 'D01AE14', 1.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ciclopirox olamine', 'D01AE14', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cilastatin (cilastatin sodium)', NULL, 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cilastatin (cilastatin sodium)', NULL, 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cilazapril', 'C09AA08', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cilazapril', 'C09AA08', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cilazapril (cilazapril monohydrate)', 'C09AA08', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cilazapril (cilazapril monohydrate)', 'C09AA08', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cilazapril (cilazapril monohydrate)', 'C09AA08', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cimetidine', 'A02BA01', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cimetidine', 'A02BA01', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cimetidine', 'A02BA01', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cimetidine', 'A02BA01', 600.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cimetidine', 'A02BA01', 800.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cimetidine (cimetidine hydrochloride)', 'A02BA01', 300.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cinacalcet (cinacalcet hydrochloride)', 'H05BX01', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cinacalcet (cinacalcet hydrochloride)', 'H05BX01', 60.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cinacalcet (cinacalcet hydrochloride)', 'H05BX01', 90.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cinnamaldehyde', NULL, 0.034, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cinnamaldehyde', NULL, 5.0, 'ml/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cinnamon oil', NULL, 5.0, 'ml/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cinnamyl alcohol', NULL, 0.054, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ciprofloxacin', 'J01MA02', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ciprofloxacin', 'J01MA02', 10.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ciprofloxacin', 'J01MA02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'S01AX13', 0.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'S01AX13', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'S01AX13', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride)', 'S01AX13', 750.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride, ciprofloxacin)', 'J01MA02', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ciprofloxacin (ciprofloxacin hydrochloride, ciprofloxacin)', 'J01MA02', 1000.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ciprofloxacin (ciprofloxacin lactate)', 'J01MA02', 0.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ciprofloxacin hydrochloride', 'S01AX13', 0.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cisatracurium (cisatracurium besylate)', 'M03AC11', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cisplatin', 'L01XA01', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('citalopram (citalopram hydrobromide)', 'N06AB04', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('citric acid', 'V07AV', 1.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('citric acid', 'V07AV', 2.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('citric acid', 'V07AV', 3.24, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('citric acid', 'V07AV', 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('citric acid', 'V07AV', 4.875, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('citric acid', 'V07AV', 5.33, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('citric acid', 'V07AV', 12.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('citric acid', 'V07AV', 32.4, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('citric acid', 'V07AV', 37.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('citric acid', 'V07AV', 59.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('citric acid', 'V07AV', 93.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('citric acid', 'V07AV', 148.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('citric acid', 'V07AV', 189.0, 'mg/63ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('citric acid', 'V07AV', 440.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('citric acid', 'V07AV', 730.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('citric acid', 'V07AV', 1000.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cladribine', 'L01BB04', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clarithromycin', 'J01FA09', 125.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clarithromycin', 'J01FA09', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clarithromycin', 'J01FA09', 250.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clarithromycin', 'J01FA09', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clavulanic acid (clavulanate potassium)', NULL, 28.5, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clavulanic acid (clavulanate potassium)', NULL, 31.25, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clavulanic acid (clavulanate potassium)', NULL, 57.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clavulanic acid (clavulanate potassium)', NULL, 62.5, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clavulanic acid (clavulanate potassium)', NULL, 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clavulanic acid (clavulanate potassium)', NULL, 125.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clavulanic acid (potassium clavulanate)', NULL, 1.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clavulanic acid (potassium clavulanate)', NULL, 31.25, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clavulanic acid (potassium clavulanate)', NULL, 62.5, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clavulanic acid (potassium clavulanate)', NULL, 125.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clemastine (clemastine hydrogen fumarate)', 'R06AA04', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clidinium bromide', NULL, 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clindamycin (clindamycin 2-palmitate hydrochloride)', 'J01FF01', 75.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clindamycin (clindamycin hydrochloride)', 'J01FF01', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clindamycin (clindamycin hydrochloride)', 'J01FF01', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clindamycin (clindamycin phosphate)', 'J01FF01', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clindamycin (clindamycin phosphate)', 'J01FF01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clindamycin (clindamycin phosphate)', 'J01FF01', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clindamycin (clindamycin phosphate)', 'J01FF01', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clioquinol', 'D08AH30', 0.08, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clioquinol', 'D08AH30', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clioquinol', 'D08AH30', 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clobazam', 'N05BA09', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clobetasol propionate', 'D07AD01', 0.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clobetasone butyrate', 'D07AB01', 0.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clodronate disodium', 'M05BA02', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clodronate disodium (clodronate disodium tetrahydrate)', 'M05BA02', 60.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clodronate disodium (clodronate disodium tetrahydrate)', 'M05BA02', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clofarabine', 'L01BB06', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clofedanol hydrochloride', 'R05DB10', 25.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clomiphene citrate', 'G03GB02', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clomipramine hydrochloride', 'N06AA04', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clomipramine hydrochloride', 'N06AA04', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clomipramine hydrochloride', 'N06AA04', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clonazepam', 'N03AE01', 0.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clonazepam', 'N03AE01', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clonazepam', 'N03AE01', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clonazepam', 'N03AE01', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clonidine hydrochloride', 'N02CX02', 0.025, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clonidine hydrochloride', 'N02CX02', 0.1, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clonidine hydrochloride', 'N02CX02', 0.2, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clopidogrel (clopidogrel bisulfate)', 'B01AC04', 75.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clopidogrel (clopidogrel bisulfate)', 'B01AC04', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clorazepate dipotassium', 'N05BA05', 3.75, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clorazepate dipotassium', 'N05BA05', 7.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clorazepate dipotassium', 'N05BA05', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clorophene', 'V07AV', 0.03, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clorophene', 'V07AV', 0.7, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clorophene', 'V07AV', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clorophene', 'V07AV', 1.7, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clorophene', 'V07AV', 1.72, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clorophene', 'V07AV', 2.75, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clorophene', 'V07AV', 3.15, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clorophene', 'V07AV', 3.225, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clorophene', 'V07AV', 3.37, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clorophene', 'V07AV', 3.56, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clorophene', 'V07AV', 3.6, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clorophene', 'V07AV', 3.75, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clorophene', 'V07AV', 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clorophene', 'V07AV', 5.32, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clorophene', 'V07AV', 5.45, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clorophene', 'V07AV', 6.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clorophene', 'V07AV', 8.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clorophene', 'V07AV', 10.6, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clorophene', 'V07AV', 10.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clorophene sodium', NULL, 6.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clostridium botulinum neurotoxin type a (150kd), free from complexing proteins', 'M03AX01', 100.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clotrimazole', 'G01AF02', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clotrimazole', 'G01AF02', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clotrimazole', 'G01AF02', 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clotrimazole', 'G01AF02', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clotrimazole', 'G01AF02', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clove oil', NULL, 63.4, 'ml/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cloxacillin (cloxacillin sodium)', 'J01CF02', 125.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cloxacillin (cloxacillin sodium)', 'J01CF02', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cloxacillin (cloxacillin sodium)', 'J01CF02', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cloxacillin sodium', 'J01CF02', 1.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cloxacillin sodium', 'J01CF02', 2.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cloxacillin sodium', 'J01CF02', 125.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cloxacillin sodium', 'J01CF02', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cloxacillin sodium', 'J01CF02', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clozapine', 'N05AH02', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clozapine', 'N05AH02', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clozapine', 'N05AH02', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('clozapine', 'N05AH02', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('coagulation factor ii (human)', NULL, 760.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('coagulation factor ix (human)', 'B02BD04', 620.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('coagulation factor ix (human)', 'B02BD04', 720.0, 'unit/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('coagulation factor ix (recombinant)', 'B02BD04', 250.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('coagulation factor ix (recombinant)', 'B02BD04', 500.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('coagulation factor ix (recombinant)', 'B02BD04', 1000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('coagulation factor ix (recombinant)', 'B02BD04', 2000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('coagulation factor vii (human)', NULL, 480.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('coagulation factor x (human)', NULL, 600.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('coal tar', 'D05AA', 0.04, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('coal tar', 'D05AA', 0.09, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('coal tar', 'D05AA', 0.166, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('coal tar', 'D05AA', 0.33, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('coal tar', 'D05AA', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('coal tar', 'D05AA', 0.55, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('coal tar', 'D05AA', 0.66, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('coal tar', 'D05AA', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('coal tar', 'D05AA', 1.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('coal tar', 'D05AA', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('coal tar', 'D05AA', 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('coal tar', 'D05AA', 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('coal tar', 'D05AA', 4.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('coal tar', 'D05AA', 4.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('coal tar', 'D05AA', 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('coal tar', 'D05AA', 7.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('coal tar', 'D05AA', 8.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('coal tar', 'D05AA', 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('coal tar', 'D05AA', 20.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('coal tar', 'D05AA', 40.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cobaltous chloride', NULL, 0.016, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cocaine hydrochloride', 'R02AD03', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cocaine hydrochloride', 'R02AD03', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cocillana', NULL, 1.36, 'mg/1ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cocoa butter', NULL, 85.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('codeine', 'R05DA04', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('codeine', 'R05DA04', 75.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('codeine', 'R05DA04', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('codeine (codeine monohydrate)', NULL, 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('codeine (codeine sulfate)', NULL, 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('codeine (codeine sulfate)', NULL, 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('codeine (codeine sulfate)', NULL, 75.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('codeine (codeine sulfate)', NULL, 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('codeine phosphate', 'R05DA04', 0.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('codeine phosphate', 'R05DA04', 0.667, 'mg/1ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('codeine phosphate', 'R05DA04', 3.3, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('codeine phosphate', 'R05DA04', 3.33, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('codeine phosphate', 'R05DA04', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('codeine phosphate', 'R05DA04', 8.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('codeine phosphate', 'R05DA04', 8.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('codeine phosphate', 'R05DA04', 10.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('codeine phosphate', 'R05DA04', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('codeine phosphate', 'R05DA04', 16.2, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('codeine phosphate', 'R05DA04', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('codeine phosphate', 'R05DA04', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('codeine phosphate', 'R05DA04', 32.4, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('codeine phosphate', 'R05DA04', 60.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('codeine phosphate', 'R05DA04', 143.0, 'mg/30ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('colchicine', 'M04AC01', 0.6, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('colchicine', 'M04AC01', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('colestipol hydrochloride', 'C10AC02', 1.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('colestipol hydrochloride', 'C10AC02', 5.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('colistin (colistimethate sodium)', 'J01XB01', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('collagenase', 'D03BA02', 250.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('conjugated estrogens', 'G03CA57', 0.3, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('conjugated estrogens', 'G03CA57', 0.625, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('conjugated estrogens', 'G03CA57', 0.9, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('conjugated estrogens', 'G03CA57', 1.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('conjugated estrogens', 'G03CA57', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('conjugated estrogens', 'G03CA57', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('copper (copper gluconate)', NULL, 0.45, 'mg/2ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('copper (copper sulfate)', 'A12CX', 0.4, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('copper (copper sulfate)', 'A12CX', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('copper (cupric oxide)', NULL, 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('corbadrine', NULL, 0.05, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('corbadrine (corbadrine hydrochloride)', NULL, 0.05, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('corbadrine (corbadrine hydrochloride)', NULL, 50.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cortisone acetate', 'H02AB10', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('corynebacterium diphtheriae crm-197 protein', NULL, 15.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('corynebacterium diphtheriae crm-197 protein', NULL, 20.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('corynebacterium diphtheriae crm-197 protein', NULL, 25.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('corynebacterium diphtheriae crm-197 protein', NULL, 34.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('desloratadine', 'R06AX27', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('corynebacterium diphtheriae crm-197 protein', NULL, 47.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cosyntropin', 'H01AA02', 0.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cosyntropin (cosyntropin zinc hydroxide complex)', 'H01AA02', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cromolyn sodium', 'S01GX01', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cromolyn sodium', 'S01GX01', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cromolyn sodium', 'S01GX01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cromolyn sodium', 'S01GX01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('crotamiton', 'P03AX', 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cupric chloride', NULL, 0.42, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cyclobenzaprine hydrochloride', 'M03BX08', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cyclopentamine hydrochloride', NULL, 2.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cyclopentolate hydrochloride', 'S01FA04', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cyclopentolate hydrochloride', 'S01FA04', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cyclophosphamide', 'L01AA01', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cyclophosphamide', 'L01AA01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cyclophosphamide', 'L01AA01', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cyclophosphamide', 'L01AA01', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cyclophosphamide', 'L01AA01', 1000.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cyclophosphamide', 'L01AA01', 2000.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cyclosporine', 'S01XA18', 0.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cyclosporine', 'S01XA18', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cyclosporine', 'S01XA18', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cyclosporine', 'S01XA18', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cyclosporine', 'S01XA18', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cynara scolymus', NULL, 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cyproheptadine hydrochloride', 'R06AX02', 2.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cyproheptadine hydrochloride', 'R06AX02', 4.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cyproterone acetate', 'G03HA01', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cyproterone acetate', 'G03HA01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cyproterone acetate', 'G03HA01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cytarabine', 'L01BC01', 1.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cytarabine', 'L01BC01', 2.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cytarabine', 'L01BC01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cytarabine', 'L01BC01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cytarabine', 'L01BC01', 100.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cytarabine', 'L01BC01', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('cytomegalovirus immune globulin (human)', 'J06BB09', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('d&c red no. 28', 'V04CX', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('d-alpha tocopherol', NULL, 150.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('d-pantothenic acid (calcium d-pantothenate)', NULL, 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('d-pantothenic acid (calcium d-pantothenate)', NULL, 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('d-pantothenic acid (calcium d-pantothenate)', NULL, 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('d-pantothenic acid (calcium d-pantothenate, riboflavin-5-phosphate)', NULL, 2.6, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('d-penicillamine', 'M01CC01', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dabigatran etexilate (dabigatran etexilate mesilate)', 'B01AE07', 75.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dabigatran etexilate (dabigatran etexilate mesilate)', 'B01AE07', 110.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dabigatran etexilate (dabigatran etexilate mesilate)', 'B01AE07', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dacarbazine', 'L01AX04', 600.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('daclizumab', 'L04AC01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dactinomycin', 'L01DA01', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dalteparin sodium', 'B01AB04', 2500.0, 'unit/0.2ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dalteparin sodium', 'B01AB04', 5000.0, 'unit/0.2ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dalteparin sodium', 'B01AB04', 10000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dalteparin sodium', 'B01AB04', 25000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('danaparoid sodium', 'B01AB09', 750.0, 'unit/0.6ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('danazol', 'G03XA01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('danazol', 'G03XA01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('danazol', 'G03XA01', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dantrolene sodium', 'M03CA01', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dantrolene sodium', 'M03CA01', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dantrolene sodium', 'M03CA01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dapsone', 'J04BA02', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('daptomycin', 'J01XX09', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('darbepoetin alfa', 'B03XA02', 25.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('darbepoetin alfa', 'B03XA02', 40.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('darbepoetin alfa', 'B03XA02', 100.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('darbepoetin alfa', 'B03XA02', 200.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('darbepoetin alfa', 'B03XA02', 500.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('darifenacin (darifenacin hydrobromide)', 'G04BD10', 7.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('darifenacin (darifenacin hydrobromide)', 'G04BD10', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('darunavir (darunavir ethanolate)', 'J05AE10', 75.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('darunavir (darunavir ethanolate)', 'J05AE10', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('darunavir (darunavir ethanolate)', 'J05AE10', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('darunavir (darunavir ethanolate)', 'J05AE10', 600.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dasatinib (dasatinib monohydrate)', 'L01XE06', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dasatinib (dasatinib monohydrate)', 'L01XE06', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dasatinib (dasatinib monohydrate)', 'L01XE06', 70.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dasatinib (dasatinib monohydrate)', 'L01XE06', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('daunorubicin (daunorubicin hydrochloride)', 'L01DB02', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dea methoxycinnamate', NULL, 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('deferasirox', 'V03AC03', 125.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('deferasirox', 'V03AC03', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('deferasirox', 'V03AC03', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('deferoxamine mesylate', 'V03AC01', 2.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('deferoxamine mesylate', 'V03AC01', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('degarelix (degarelix acetate)', 'L02BX02', 80.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('degarelix (degarelix acetate)', 'L02BX02', 120.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dehydrocholic acid', 'A05AA', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dehydrocholic acid', 'A05AA', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dehydrocholic acid', 'A05AA', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('delavirdine mesylate', 'J05AG02', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('delta-9-tetrahydrocannabinol (cannabis sativa extract)', NULL, 27.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('denosumab', 'M05BX04', 60.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('deoxycholic acid', NULL, 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dequalinium chloride', 'R02AA02', 0.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dequalinium chloride', 'R02AA02', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dermatophagoides farinae', 'V01AA07', 5000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dermatophagoides farinae', 'V01AA07', 10000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dermatophagoides farinae', 'V01AA07', 15000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dermatophagoides farinae', 'V01AA07', 30000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dermatophagoides pteronyssinus', 'V01AA07', 5000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dermatophagoides pteronyssinus', 'V01AA07', 10000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dermatophagoides pteronyssinus', 'V01AA07', 15000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dermatophagoides pteronyssinus', 'V01AA07', 30000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('desflurane', 'N01AB07', 1.0, 'ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('desipramine (desipramine hydrochloride)', 'N06AA01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('desipramine (desipramine hydrochloride)', 'N06AA01', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('desipramine (desipramine hydrochloride)', 'N06AA01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('desipramine (desipramine hydrochloride)', 'N06AA01', 75.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('desipramine (desipramine hydrochloride)', 'N06AA01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('desipramine hydrochloride', 'N06AA01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('desipramine hydrochloride', 'N06AA01', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('desipramine hydrochloride', 'N06AA01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('desipramine hydrochloride', 'N06AA01', 75.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('desipramine hydrochloride', 'N06AA01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('desloratadine', 'R06AX27', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('desloratadine', 'R06AX27', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('desmopressin (desmopressin acetate)', 'H01BA02', 60.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('desmopressin (desmopressin acetate)', 'H01BA02', 120.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('desmopressin (desmopressin acetate)', 'H01BA02', 240.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('desmopressin acetate', 'H01BA02', 0.1, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('desmopressin acetate', 'H01BA02', 0.2, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('desmopressin acetate', 'H01BA02', 4.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('desmopressin acetate', 'H01BA02', 10.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('desmopressin acetate', 'H01BA02', 15.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('desmopressin acetate', 'H01BA02', 150.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('desmopressin acetate trihydrate', 'H01BA02', 0.1, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('desmopressin acetate trihydrate', 'H01BA02', 0.2, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('desogestrel', 'G03AC09', 0.1, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('desogestrel', 'G03AC09', 0.125, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('desogestrel', 'G03AC09', 0.15, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('desonide', 'D07AB08', 0.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('desoximetasone', 'D07AC03', 0.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('desoximetasone', 'D07AC03', 0.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('desvenlafaxine (desvenlafaxine succinate)', 'N06AX23', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('desvenlafaxine (desvenlafaxine succinate)', 'N06AX23', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dexamethasone', 'S01BA01', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dexamethasone', 'S01BA01', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dexamethasone', 'S01BA01', 0.5, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dexamethasone', 'S01BA01', 0.75, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dexamethasone', 'S01BA01', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dexamethasone', 'S01BA01', 1.0, 'mg/1g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dexamethasone', 'S01BA01', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dexamethasone', 'S01BA01', 4.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dexamethasone', 'S01BA01', 10.0, 'mg/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dexamethasone (dexamethasone sodium metasulphobenzoate)', NULL, 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dexamethasone (dexamethasone sodium phosphate)', 'H02AB02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dexamethasone phosphate (dexamethasone sodium phosphate)', 'S03BA01', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dexamethasone phosphate (dexamethasone sodium phosphate)', 'S03BA01', 4.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dexamethasone phosphate (dexamethasone sodium phosphate)', 'S03BA01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dexamethasone sodium phosphate', 'S03BA01', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dexamethasone sodium phosphate', 'S03BA01', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dexbrompheniramine maleate', NULL, 1.5, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dexbrompheniramine maleate', NULL, 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dexbrompheniramine maleate', NULL, 6.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dexlansoprazole', 'A02BC', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dexlansoprazole', 'A02BC', 60.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dexmedetomidine (dexmedetomidine hydrochloride)', 'N05CM18', 100.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dexpanthenol', 'A11HA30', 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dexpanthenol', 'A11HA30', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dexpanthenol', 'A11HA30', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dexpanthenol (panthenol)', NULL, 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dexrazoxane', 'V03AF02', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dexrazoxane', 'V03AF02', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextran', 'B05AA05', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextran', 'B05AA05', 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextran', 'B05AA05', 60.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextran', 'B05AA05', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextran (dextran 70)', NULL, 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextran 40', 'ZXX0060', 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextran 70', NULL, 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextran 70', NULL, 6.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextroamphetamine saccharate', NULL, 1.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextroamphetamine saccharate', NULL, 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextroamphetamine saccharate', NULL, 3.75, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextroamphetamine saccharate', NULL, 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextroamphetamine saccharate', NULL, 6.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextroamphetamine saccharate', NULL, 7.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextroamphetamine sulfate', 'N06BA02', 1.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextroamphetamine sulfate', 'N06BA02', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextroamphetamine sulfate', 'N06BA02', 3.75, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextroamphetamine sulfate', 'N06BA02', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextroamphetamine sulfate', 'N06BA02', 6.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextroamphetamine sulfate', 'N06BA02', 7.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextroamphetamine sulfate', 'N06BA02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextroamphetamine sulfate', 'N06BA02', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextromethorphan (dextromethorphan hydrobromide)', NULL, 7.5, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 3.75, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 5.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 7.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 7.5, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 10.0, 'mg/15ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 10.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 12.5, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 15.0, 'mg/15ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 15.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 20.0, 'mg/15ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 20.0, 'mg/24g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 20.0, 'mg/30ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 20.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 28.5, 'mg/30ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 30.0, 'mg/15ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 30.0, 'mg/20ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 30.0, 'mg/22g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 30.0, 'mg/23g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 30.0, 'mg/30ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextromethorphan hydrobromide', 'R05DA09', 30.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextromethorphan hydrobromide (dextromethorphan polistirex)', 'R05DA09', 15.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextromethorphan hydrobromide (dextromethorphan polistirex)', 'R05DA09', 30.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextropropoxyphene napsylate', 'N02AC04', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 0.092, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 1.47, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 1.5, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 2.0, 'g/63ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 2.45, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 2.5, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 3.3, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 4.25, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 5.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 10.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 13.3, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 16.5, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 16.6, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 20.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 25.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 25.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 33.3, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 33.3, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 37.5, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 40.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 40.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 45.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 46.75, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 49.05, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 49.49, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 49.5, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 50.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 50.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 62.6, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 67.5, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 67.54, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 70.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 74.25, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 74.28, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 89.99, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 90.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 91.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 98.99, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 99.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 105.5, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 112.53, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 200.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 222.7, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 500.0, 'g/1000ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 500.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose', 'B05ZA', 700.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose anhydrous', NULL, 1.33, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose anhydrous', NULL, 22.0, 'g/1000ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dextrose anhydrous (dextrose monohydrate)', NULL, 1.1, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diatrizoate meglumine', NULL, 52.7, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diatrizoate meglumine', NULL, 66.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diatrizoate sodium', 'V08AA01', 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diatrizoate sodium', 'V08AA01', 997.4, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diazepam', 'N05BA01', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diazepam', 'N05BA01', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diazepam', 'N05BA01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diazepam', 'N05BA01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diazoxide', 'V03AH01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dibucaine', 'C05AD04', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dibucaine', 'C05AD04', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dibucaine hydrochloride', NULL, 0.073, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dibucaine hydrochloride', NULL, 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dichlorobenzene', NULL, 0.22, 'g/11ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dichlorobenzyl alcohol', 'R02AA03', 1.2, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diclofenac diethylamine', 'M02AA15', 1.16, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diclofenac potassium', 'M01AB05', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diclofenac sodium', 'S01BC03', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diclofenac sodium', 'S01BC03', 1.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diclofenac sodium', 'S01BC03', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diclofenac sodium', 'S01BC03', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diclofenac sodium', 'S01BC03', 75.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diclofenac sodium', 'S01BC03', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dicyclomine hydrochloride', 'A03AA07', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dicyclomine hydrochloride', 'A03AA07', 10.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dicyclomine hydrochloride', 'A03AA07', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didanosine', 'J05AF02', 125.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didanosine', 'J05AF02', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didanosine', 'J05AF02', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didanosine', 'J05AF02', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.01125, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.013, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.015, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.016, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.018, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.01995, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.026, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.03, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.048, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.0525, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.09, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.0945, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.104, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.14, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.24, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.27, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.29, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.324, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.407, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.45, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.47, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.52, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.54, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.684, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.814, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.815, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.825, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 0.99, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.125, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.1475, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.26, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.35, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.44, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.47, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.5375, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.58, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.628, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.63, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.875, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.95, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 1.953, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 2.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 2.31, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 2.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 2.53, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 2.534, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 2.54, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 2.75, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 2.76, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 2.88, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.255, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.84, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.85, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 3.906, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 4.1472, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 4.35, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 4.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 4.61, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 5.07, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 5.28, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 6.72, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 7.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 7.68, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 7.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 8.704, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 9.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 9.22, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 10.14, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 10.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 11.525, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 11.53, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 15.36, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('didecyl dimethyl ammonium chloride', 'V07AV', 30.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diethylamine salicylate', 'M02AC', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diflucortolone valerate', 'D07AC06', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diflunisal', 'N02BA11', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diflunisal', 'N02BA11', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('digoxin', 'C01AA05', 0.05, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('digoxin', 'C01AA05', 0.0625, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('digoxin', 'C01AA05', 0.125, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('digoxin', 'C01AA05', 0.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('digoxin immune fab (ovine)', 'V03AB24', 38.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dihydroergotamine mesylate', 'N02CA01', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dihydroergotamine mesylate', 'N02CA01', 4.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diiodohydroxyquin', 'P01AA', 210.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diiodohydroxyquin', 'P01AA', 650.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diltiazem hydrochloride', 'C08DB01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diltiazem hydrochloride', 'C08DB01', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diltiazem hydrochloride', 'C08DB01', 60.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diltiazem hydrochloride', 'C08DB01', 90.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diltiazem hydrochloride', 'C08DB01', 120.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diltiazem hydrochloride', 'C08DB01', 180.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diltiazem hydrochloride', 'C08DB01', 240.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diltiazem hydrochloride', 'C08DB01', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diltiazem hydrochloride', 'C08DB01', 360.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diluent', NULL, 3.15, 'ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dimenhydrinate', 'R06AA02', 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dimenhydrinate', 'R06AA02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dimenhydrinate', 'R06AA02', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dimenhydrinate', 'R06AA02', 15.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dimenhydrinate', 'R06AA02', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dimenhydrinate', 'R06AA02', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dimenhydrinate', 'R06AA02', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dimercaprol', 'V03AB09', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dimethicone', 'D02AA', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dimethicone', 'D02AA', 1.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dimethicone', 'D02AA', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dimethicone', 'D02AA', 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dimethicone', 'D02AA', 3.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dimethicone', 'D02AA', 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dimethicone', 'D02AA', 6.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dimethicone', 'D02AA', 25.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dimethicone', 'D02AA', 45.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dimethicone', 'D02AA', 160.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dimethyl sulfoxide', 'M02AX03', 70.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dimethyl sulfoxide', 'M02AX03', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dimethylbenzyl ammonium chloride', NULL, 3.17, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dinoprost (dinoprost tromethamine)', 'G02AD01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dinoprostone', 'G02AD02', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dinoprostone', 'G02AD02', 0.5, 'mg/2.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dinoprostone', 'G02AD02', 1.0, 'mg/3g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dinoprostone', 'G02AD02', 2.0, 'mg/3g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dinoprostone', 'G02AD02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 0.01, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 0.01125, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 0.012, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 0.013, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 0.015, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 0.01995, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 0.026, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 0.035, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 0.06, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 0.0945, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 0.156, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 0.19, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 0.216, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 0.24, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 0.27, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 0.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 0.37, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 0.407, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 0.456, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 0.6, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 0.66, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 0.814, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 0.815, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 0.825, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 0.84, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 0.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 0.96, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 1.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 1.06, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 1.125, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 1.1475, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 1.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 1.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 1.302, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 1.5375, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 1.628, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 1.63, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 1.69, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 1.84, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 1.875, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 2.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 2.6, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 2.604, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 2.7648, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 3.255, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dioctyl dimethyl ammonium chloride', NULL, 8.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diphenhydramine citrate', 'R06AA02', 19.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diphenhydramine citrate', 'R06AA02', 38.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 1.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 6.25, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 12.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 12.5, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 25.0, 'mg/30ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diphenhydramine hydrochloride', 'R06AA02', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diphenoxylate hydrochloride', NULL, 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diphenylguanidine', NULL, 0.068, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diphenylpyraline hydrochloride', NULL, 0.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diphenylpyraline hydrochloride', NULL, 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diphenylpyraline hydrochloride', NULL, 1.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diphtheria toxoid', 'J07AF01', 2.0, 'lf/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diphtheria toxoid', 'J07AF01', 2.0, 'unit/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diphtheria toxoid', 'J07AF01', 15.0, 'lf/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diphtheria toxoid', 'J07AF01', 25.0, 'lf/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diphtheria toxoid adsorbed', NULL, 2.0, 'lf/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('diphtheria toxoid adsorbed', NULL, 2.5, 'lf/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dipivefrin', 'S01EA02', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dipivefrin hydrochloride', 'S01EA02', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dipyridamole', 'B01AC07', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dipyridamole', 'B01AC07', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dipyridamole', 'B01AC07', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dipyridamole', 'B01AC07', 75.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dipyridamole', 'B01AC07', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('disodium dodecyl diphenyloxide disulfonate', NULL, 1.342, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('disodium edetate', NULL, 0.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('disodium edetate', NULL, 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('disodium edetate', NULL, 15.0, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('disopyramide', 'C01BA03', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('disopyramide', 'C01BA03', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('disulfiram', 'N07BB01', 0.005, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dithiobis(benzothiazole)', NULL, 0.02, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dithranol', 'D05AC01', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dithranol', 'D05AC01', 0.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dithranol', 'D05AC01', 0.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dithranol', 'D05AC01', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dithranol', 'D05AC01', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dl-methionine', NULL, 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dl-methionine', NULL, 85.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dl-methionine', NULL, 450.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dl-methionine', NULL, 760.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dl-methionine', NULL, 880.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dobutamine (dobutamine hydrochloride)', 'C01CA07', 12.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('docetaxel', 'L01CD02', 20.0, 'mg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('docetaxel', 'L01CD02', 80.0, 'mg/2ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('docosanol', 'D06BB11', 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('docusate calcium', 'A06AA02', 240.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('docusate sodium', 'A06AA02', 4.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('docusate sodium', 'A06AA02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('docusate sodium', 'A06AA02', 20.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('docusate sodium', 'A06AA02', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('docusate sodium', 'A06AA02', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('docusate sodium', 'A06AA02', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('docusate sodium', 'A06AA02', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dodecyl dimethyl benzyl ammonium chloride', NULL, 1.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dodicin', NULL, 0.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dodicin hydrochloride', 'V07AV', 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dodicin hydrochloride', 'V07AV', 3.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dodicin hydrochloride', 'V07AV', 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dolasetron mesylate', 'A04AA04', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dolasetron mesylate', 'A04AA04', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dolasetron mesylate', 'A04AA04', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dolichovespula arenaria venom protein extract', 'V01AA07', 1.1, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dolichovespula arenaria venom protein extract', 'V01AA07', 120.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dolichovespula maculata venom protein extract', 'V01AA07', 1.1, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dolichovespula maculata venom protein extract', 'V01AA07', 120.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('domiphen bromide', NULL, 0.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('domperidone (domperidone maleate)', 'A03FA03', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('donepezil hydrochloride', 'N06DA02', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('donepezil hydrochloride', 'N06DA02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dopamine hydrochloride', NULL, 0.8, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dopamine hydrochloride', NULL, 1.6, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dopamine hydrochloride', NULL, 3.2, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('doripenem (doripenem monohydrate)', 'J01DH04', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dornase alfa', 'R05CB13', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dorzolamide (dorzolamide hydrochloride)', 'S01EC03', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dorzolamide (dorzolamide hydrochloride)', 'S01EC03', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('doxazosin (doxazosin mesylate)', 'C02CA04', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('doxazosin (doxazosin mesylate)', 'C02CA04', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('doxazosin (doxazosin mesylate)', 'C02CA04', 4.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('doxepin (doxepin hydrochloride)', 'N06AA12', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('doxepin (doxepin hydrochloride)', 'N06AA12', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('doxepin (doxepin hydrochloride)', 'N06AA12', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('doxepin (doxepin hydrochloride)', 'N06AA12', 75.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('doxepin (doxepin hydrochloride)', 'N06AA12', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('doxepin (doxepin hydrochloride)', 'N06AA12', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('doxepin hydrochloride', 'N06AA12', 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('doxepin hydrochloride', 'N06AA12', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('doxepin hydrochloride', 'N06AA12', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('doxepin hydrochloride', 'N06AA12', 75.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('doxepin hydrochloride', 'N06AA12', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('doxepin hydrochloride', 'N06AA12', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('doxorubicin hydrochloride', 'L01DB01', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('doxorubicin hydrochloride', 'L01DB01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('doxorubicin hydrochloride', 'L01DB01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('doxorubicin hydrochloride', 'L01DB01', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('doxycycline (doxycycline hyclate)', 'J01AA02', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('doxycycline (doxycycline hyclate)', 'J01AA02', 44.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('doxycycline (doxycycline hyclate)', 'J01AA02', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('doxycycline hyclate', 'J01AA02', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('doxylamine succinate', 'R06AA09', 1.2, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('doxylamine succinate', 'R06AA09', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('doxylamine succinate', 'R06AA09', 6.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('doxylamine succinate', 'R06AA09', 6.25, 'mg/15ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('doxylamine succinate', 'R06AA09', 7.5, 'mg/30ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('doxylamine succinate', 'R06AA09', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('doxylamine succinate', 'R06AA09', 12.5, 'mg/30ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('doxylamine succinate', 'R06AA09', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('drometrizole trisiloxane', NULL, 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('drometrizole trisiloxane', NULL, 0.75, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('drometrizole trisiloxane', NULL, 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('drometrizole trisiloxane', NULL, 1.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('drometrizole trisiloxane', NULL, 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('drometrizole trisiloxane', NULL, 2.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('drometrizole trisiloxane', NULL, 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('drometrizole trisiloxane', NULL, 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('drometrizole trisiloxane', NULL, 4.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('drometrizole trisiloxane', NULL, 6.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dronabinol', 'A04AD10', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dronabinol', 'A04AD10', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dronedarone (dronedarone hydrochloride)', 'C01BD07', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('droperidol', 'N01AX01', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('drospirenone', NULL, 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('drospirenone', NULL, 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('drotrecogin alfa (activated)', 'B01AD10', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('drotrecogin alfa (activated)', 'B01AD10', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('duloxetine (duloxetine hydrochloride)', 'N06AX21', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('duloxetine (duloxetine hydrochloride)', 'N06AX21', 60.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dutasteride', 'G04CB02', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dyclonine hydrochloride', 'R02AD04', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dyclonine hydrochloride', 'R02AD04', 1.2, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('dyclonine hydrochloride', 'R02AD04', 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('eculizumab', 'L04AA25', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('edetate sodium', NULL, 0.38, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('edetate sodium', NULL, 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('edetate sodium', NULL, 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('edetate sodium', NULL, 1.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('edetate sodium', NULL, 1.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('edetate sodium', NULL, 1.6, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('edetate sodium', NULL, 2.28, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('edetate sodium', NULL, 2.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('edetic acid', NULL, 0.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('edetic acid', NULL, 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('edrophonium chloride', 'V04CX', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('efavirenz', 'J05AG03', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('efavirenz', 'J05AG03', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('efavirenz', 'J05AG03', 600.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('eflornithine hydrochloride', 'D11AX16', 13.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('egg phospholipids', NULL, 0.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('egg phospholipids', NULL, 1.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('egg phospholipids', NULL, 1.2, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('egg phospholipids', NULL, 700.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('eletriptan (eletriptan hydrobromide)', 'N02CC06', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('eletriptan (eletriptan hydrobromide)', 'N02CC06', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('emedastine (emedastine difumarate)', 'S01GX06', 0.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('emtricitabine', 'J05AF09', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('enalapril maleate', 'C09AA02', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('enalapril maleate', 'C09AA02', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('enalapril maleate', 'C09AA02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('enalapril maleate', 'C09AA02', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('enalapril sodium', 'C09AA02', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('enalapril sodium', 'C09AA02', 4.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('enalapril sodium', 'C09AA02', 8.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('enalapril sodium', 'C09AA02', 16.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('enalapril sodium', 'C09AA02', 32.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('enalaprilat', 'C09AA02', 1.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('enfuvirtide', 'J05AX07', 108.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('enoxaparin sodium', 'B01AB05', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('enoxaparin sodium', 'B01AB05', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ensulizole', NULL, 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ensulizole', NULL, 1.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ensulizole', NULL, 1.7, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ensulizole', NULL, 1.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ensulizole', NULL, 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ensulizole', NULL, 2.0, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ensulizole', NULL, 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ensulizole', NULL, 3.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ensulizole', NULL, 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('entacapone', 'N04BX02', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('entecavir', 'J05AF10', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('enzacamene', NULL, 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('enzacamene', NULL, 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('enzacamene', NULL, 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ephedrine hydrochloride', NULL, 8.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ephedrine sulfate', 'R03CA02', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epinephrine', 'C01CA24', 0.01, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epinephrine', 'C01CA24', 0.1, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epinephrine', 'C01CA24', 0.15, 'mg/0.15ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epinephrine', 'C01CA24', 0.15, 'mg/0.3ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epinephrine', 'C01CA24', 0.3, 'mg/0.3ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epinephrine', 'C01CA24', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epinephrine', 'C01CA24', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epinephrine', 'C01CA24', 5.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epinephrine', 'C01CA24', 10.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epinephrine', 'C01CA24', 18.0, 'µg/1.8ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epinephrine (epinephrine bitartrate)', NULL, 0.005, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epinephrine (epinephrine bitartrate)', NULL, 0.01, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epinephrine (epinephrine bitartrate)', NULL, 0.02, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epinephrine (epinephrine bitartrate)', NULL, 5.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epinephrine (epinephrine bitartrate)', NULL, 36.0, 'µg/1.8ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epinephrine (epinephrine hydrochloride)', 'R01AA14', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epinephrine bitartrate', NULL, 0.009, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epinephrine bitartrate', NULL, 0.0091, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epinephrine bitartrate', NULL, 0.01, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epinephrine bitartrate', NULL, 0.018, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epinephrine bitartrate', NULL, 0.02, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epinephrine bitartrate', NULL, 9.1, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epinephrine racemic', 'R03AA01', 22.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epirubicin hydrochloride', 'L01DB03', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epirubicin hydrochloride', 'L01DB03', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('eplerenone', 'C03DA04', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('eplerenone', 'C03DA04', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epoetin alfa', 'B03XA01', 1000.0, 'unit/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epoetin alfa', 'B03XA01', 2000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epoetin alfa', 'B03XA01', 2000.0, 'unit/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epoetin alfa', 'B03XA01', 3000.0, 'unit/0.3ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epoetin alfa', 'B03XA01', 4000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epoetin alfa', 'B03XA01', 4000.0, 'unit/0.4ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epoetin alfa', 'B03XA01', 5000.0, 'unit/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epoetin alfa', 'B03XA01', 6000.0, 'unit/0.6ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epoetin alfa', 'B03XA01', 8000.0, 'unit/0.8ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epoetin alfa', 'B03XA01', 10000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epoetin alfa', 'B03XA01', 20000.0, 'unit/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epoetin alfa', 'B03XA01', 30000.0, 'unit/0.75ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epoetin alfa', 'B03XA01', 40000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epoprostenol (epoprostenol sodium)', 'B01AC09', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epoprostenol (epoprostenol sodium)', 'B01AC09', 1.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('epoxy resin', NULL, 0.041, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('eprosartan (eprosartan mesylate)', 'C09CA02', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('eprosartan (eprosartan mesylate)', 'C09CA02', 600.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('eptacog alfa (activated)', 'B02BD08', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('eptacog alfa (activated)', 'B02BD08', 1.2, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('eptacog alfa (activated)', 'B02BD08', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('eptacog alfa (activated)', 'B02BD08', 2.4, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('eptacog alfa (activated)', 'B02BD08', 4.8, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('eptacog alfa (activated)', 'B02BD08', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('eptifibatide', 'B01AC16', 0.75, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('eptifibatide', 'B01AC16', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ergoloid mesylates', 'C04AE01', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ergonovine maleate', 'G02AB03', 0.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ergotamine tartrate', NULL, 0.6, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ergotamine tartrate', NULL, 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('erlotinib (erlotinib hydrochloride)', 'L01XE03', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('erlotinib (erlotinib hydrochloride)', 'L01XE03', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('erlotinib (erlotinib hydrochloride)', 'L01XE03', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ertapenem (ertapenem sodium)', 'J01DH03', 1.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('erythromycin', 'S01AA17', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('erythromycin', 'S01AA17', 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('erythromycin', 'S01AA17', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('erythromycin', 'S01AA17', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('erythromycin', 'S01AA17', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('erythromycin', 'S01AA17', 333.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('erythromycin', 'S01AA17', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('erythromycin (erythromycin estolate)', 'J01FA01', 125.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('erythromycin (erythromycin estolate)', 'J01FA01', 250.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('erythromycin (erythromycin ethylsuccinate)', 'J01FA01', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('erythromycin (erythromycin ethylsuccinate)', 'J01FA01', 200.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('erythromycin (erythromycin ethylsuccinate)', 'J01FA01', 400.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('erythromycin (erythromycin ethylsuccinate)', 'J01FA01', 600.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('erythromycin (erythromycin lactobionate)', 'J01FA01', 1.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('erythromycin (erythromycin lactobionate)', 'J01FA01', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('erythromycin (erythromycin stearate)', 'J01FA01', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('erythromycin (erythromycin stearate)', 'J01FA01', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('erythrosine', 'V04C', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('escitalopram (escitalopram oxalate)', 'N06AB10', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('escitalopram (escitalopram oxalate)', 'N06AB10', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('esculin', NULL, 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('esmolol hydrochloride', 'C07AB09', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('esomeprazole (esomeprazole magnesium trihydrate)', 'A02BC05', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('esomeprazole (esomeprazole magnesium trihydrate)', 'A02BC05', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('esomeprazole (esomeprazole magnesium trihydrate)', 'A02BC05', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('esterified estrogens', 'G03CA07', 0.3, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('esterified estrogens', 'G03CA07', 0.625, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('estradiol', 'G03CA03', 0.06, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('estradiol', 'G03CA03', 0.39, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('estradiol', 'G03CA03', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('estradiol', 'G03CA03', 0.51, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('estradiol', 'G03CA03', 0.585, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('estradiol', 'G03CA03', 0.62, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('estradiol', 'G03CA03', 0.78, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('estradiol', 'G03CA03', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('estradiol', 'G03CA03', 1.17, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('estradiol', 'G03CA03', 1.56, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('estradiol', 'G03CA03', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('estradiol', 'G03CA03', 4.4, '0mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('estradiol', 'G03CA03', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('estradiol', 'G03CA03', 8.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('estradiol', 'G03CA03', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('estradiol', 'G03CA03', 25.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('estradiol (estradiol hemihydrate)', 'G03CA03', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('estradiol (estradiol hemihydrate)', 'G03CA03', 3.8, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('estradiol (estradiol hemihydrate)', 'G03CA03', 4.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('estradiol (estradiol hemihydrate)', 'G03CA03', 5.7, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('estradiol (estradiol hemihydrate)', 'G03CA03', 6.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('estradiol (estradiol hemihydrate)', 'G03CA03', 7.6, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('estradiol (estradiol hemihydrate)', 'G03CA03', 8.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('estradiol (estradiol hemihydrate)', 'G03CA03', 10.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('estradiol valerate', 'G03CA03', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('estramustine phosphate sodium', 'L01XX11', 140.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('estrone', 'G03CA07', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('estropipate', 'G03CA07', 0.75, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('estropipate', 'G03CA07', 1.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('estropipate', 'G03CA07', 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('etafedrin hydrochloride', NULL, 3.33, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('etanercept', 'L04AB01', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('etanercept', 'L04AB01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ethacrynic acid', 'C03CC01', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ethacrynic acid (sodium ethacrynate)', 'C03CC01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ethambutol hydrochloride', 'J04AK02', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ethambutol hydrochloride', 'J04AK02', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ethinyl estradiol', NULL, 0.02, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ethinyl estradiol', NULL, 0.025, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ethinyl estradiol', NULL, 0.03, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ethinyl estradiol', NULL, 0.035, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ethinyl estradiol', NULL, 0.6, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ethinyl estradiol', NULL, 2.6, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ethinyl estradiol', NULL, 5.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ethinyl estradiol', NULL, 20.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ethinyl estradiol', NULL, 30.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ethinyl estradiol', NULL, 35.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ethinyl estradiol', NULL, 40.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ethopropazine (ethopropazine hydrochloride)', 'N04AA05', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ethosuximide', 'N03AD01', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ethosuximide', 'N03AD01', 250.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ethyl paraben', NULL, 0.16, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ethylene oxide', 'V07AV', 8.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ethylene oxide', 'V07AV', 8.6, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ethylene oxide', 'V07AV', 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ethylene oxide', 'V07AV', 10.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ethylene oxide', 'V07AV', 100.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ethylenediamine dihydrochloride', NULL, 0.041, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ethynodiol diacetate', NULL, 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('etidronate disodium', 'M05BA01', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('etidronate disodium', 'M05BA01', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('etodolac', 'M01AB08', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('etodolac', 'M01AB08', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('etonogestrel', 'G03AC08', 11.4, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('etoposide', 'L01CB01', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('etoposide', 'L01CB01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('etravirine', 'J05AG04', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('eugenol', NULL, 0.034, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('eugenol', NULL, 13.7, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('euphorbia', NULL, 3.73, 'mg/1ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('everolimus', 'L04AA18', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('everolimus', 'L04AA18', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('exemestane', 'L02BG06', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ezetimibe', 'C10AX09', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('factor xiii', NULL, 50.0, 'unit/1ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('factor xiii', NULL, 100.0, 'unit/2ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('factor xiii', NULL, 250.0, 'unit/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('famciclovir', 'J05AB09', 125.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('famciclovir', 'J05AB09', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('famciclovir', 'J05AB09', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('famotidine', 'A02BA03', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('famotidine', 'A02BA03', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('famotidine', 'A02BA03', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('febuxostat', 'M04AA03', 80.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('felodipine', 'C08CA02', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('felodipine', 'C08CA02', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('felodipine', 'C08CA02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fenofibrate', 'C10AB05', 48.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fenofibrate', 'C10AB05', 67.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fenofibrate', 'C10AB05', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fenofibrate', 'C10AB05', 145.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fenofibrate', 'C10AB05', 160.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fenofibrate', 'C10AB05', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fenoterol hydrobromide', NULL, 0.3125, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fentanyl', 'N02AB03', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fentanyl', 'N02AB03', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fentanyl', 'N02AB03', 7.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fentanyl', 'N02AB03', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fentanyl', 'N02AB03', 12.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fentanyl', 'N02AB03', 25.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fentanyl', 'N02AB03', 50.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fentanyl', 'N02AB03', 75.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fentanyl', 'N02AB03', 100.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fentanyl (fentanyl citrate)', 'N01AH01', 50.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fexofenadine hydrochloride', 'R06AX26', 60.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fexofenadine hydrochloride', 'R06AX26', 120.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fibrinogen (human)', NULL, 110.0, 'mg/1ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fibrinogen (human)', NULL, 220.0, 'mg/2ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fibrinogen (human)', NULL, 550.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('filamentous haemagglutinin', NULL, 5.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('filamentous haemagglutinin', NULL, 8.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('filamentous haemagglutinin', NULL, 20.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('filamentous haemagglutinin', NULL, 25.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('filamentous haemagglutinin adsorbed', NULL, 8.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('filgrastim (r-methug-csf)', 'L03AA02', 300.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fimbriae types 2 and 3 (fim)', NULL, 5.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('finasteride', 'G04CB01', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('finasteride', 'G04CB01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('flavoxate hydrochloride', 'G04BD02', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('flecainide acetate', 'C01BC04', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('flecainide acetate', 'C01BC04', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('floctafenine', 'N02BG04', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('floctafenine', 'N02BG04', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluconazole', 'J02AC01', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluconazole', 'J02AC01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluconazole', 'J02AC01', 50.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluconazole', 'J02AC01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluconazole', 'J02AC01', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fludarabine phosphate', 'L01BB05', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fludarabine phosphate', 'L01BB05', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fludarabine phosphate', 'L01BB05', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fludarabine phosphate (fludarabine phosphate sodium)', 'L01BB05', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fludrocortisone 21-acetate', 'H02AA02', 0.1, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('flumazenil', 'V03AB25', 0.1, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('flumethasone pivalate', NULL, 0.02, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('flunarizine (flunarizine hydrochloride)', 'N07CA03', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('flunisolide', 'R01AD04', 0.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('flunisolide', 'R01AD04', 25.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluocinolone acetonide', 'S02BA08', 0.01, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluocinolone acetonide', 'S02BA08', 0.025, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluocinolone acetonide', 'S02BA08', 0.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluocinonide', 'D07AC08', 0.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluocinonide', 'D07AC08', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluorescein sodium', 'V04CX', 0.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluorescein sodium', 'V04CX', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluorescein sodium', 'V04CX', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluorescein sodium', 'V04CX', 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluorescein sodium', 'V04CX', 25.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluorescein sodium', 'V04CX', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluorescein sodium', 'V04CX', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluorometholone', 'S01BA07', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluorometholone', 'S01BA07', 0.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluorometholone acetate', 'S01BA07', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluorouracil', 'L01BC02', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluorouracil', 'L01BC02', 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluorouracil', 'L01BC02', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 20.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluoxetine (fluoxetine hydrochloride)', 'N06AB03', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('flupentixol (flupentixol dihydrochloride)', 'N05AF01', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('flupentixol (flupentixol dihydrochloride)', 'N05AF01', 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('flupentixol decanoate', 'N05AF01', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('flupentixol decanoate', 'N05AF01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluphenazine decanoate', 'N05AB02', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluphenazine decanoate', 'N05AB02', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluphenazine hydrochloride', 'N05AB02', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluphenazine hydrochloride', 'N05AB02', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluphenazine hydrochloride', 'N05AB02', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluphenazine hydrochloride', 'N05AB02', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('flurazepam hydrochloride', 'N05CD01', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('flurazepam hydrochloride', 'N05CD01', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('flurbiprofen', 'M01AE09', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('flurbiprofen', 'M01AE09', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('flurbiprofen sodium', 'S01BC04', 0.03, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('flutamide', 'L02BB01', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluticasone furoate', 'R01AD12', 27.5, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluticasone propionate', 'R03BA05', 0.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluticasone propionate', 'R03BA05', 50.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluticasone propionate', 'R03BA05', 100.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluticasone propionate', 'R03BA05', 125.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluticasone propionate', 'R03BA05', 250.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluticasone propionate', 'R03BA05', 500.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluvastatin (fluvastatin sodium)', 'C10AA04', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluvastatin (fluvastatin sodium)', 'C10AA04', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluvastatin (fluvastatin sodium)', 'C10AA04', 80.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluvoxamine maleate', 'N06AB08', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fluvoxamine maleate', 'N06AB08', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('folic acid', 'B03BB01', 0.04, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('folic acid', 'B03BB01', 0.2, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('folic acid', 'B03BB01', 1.1, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('folic acid', 'B03BB01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('folic acid', 'B03BB01', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('folic acid', 'B03BB01', 80.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('folic acid', 'B03BB01', 140.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('follitropin alpha', 'G03GA05', 5.5, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('follitropin alpha', 'G03GA05', 33.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('follitropin alpha', 'G03GA05', 77.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('follitropin alpha', 'G03GA05', 150.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('follitropin alpha', 'G03GA05', 300.0, 'unit/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('follitropin alpha', 'G03GA05', 450.0, 'unit/0.75ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('follitropin alpha', 'G03GA05', 900.0, 'unit/1.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('follitropin alpha', 'G03GA05', 1200.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('follitropin beta', 'G03GA06', 50.0, 'unit/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('follitropin beta', 'G03GA06', 100.0, 'unit/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('follitropin beta', 'G03GA06', 833.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fomepizole', 'V03AB34', 1.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fondaparinux sodium', 'B01AX05', 2.5, 'mg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fondaparinux sodium', 'B01AX05', 12.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('formaldehyde', 'V07AV', 0.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('formaldehyde', 'V07AV', 0.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('formaldehyde', 'V07AV', 0.23, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('formaldehyde', 'V07AV', 0.23, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('formaldehyde', 'V07AV', 2.02, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('formaldehyde', 'V07AV', 2.28, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('formaldehyde', 'V07AV', 37.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('formoterol fumarate', 'R03AC13', 12.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('formoterol fumarate dihydrate', 'R03AC13', 6.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('formoterol fumarate dihydrate', 'R03AC13', 12.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fosamprenavir (fosamprenavir calcium)', 'J05AE07', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fosamprenavir (fosamprenavir calcium)', 'J05AE07', 700.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fosfomycin (fosfomycin tromethamine)', 'J01XX01', 3.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fosinopril sodium', 'C09AA09', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fosinopril sodium', 'C09AA09', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fosphenytoin sodium', 'N03AB05', 75.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('framycetin sulfate', 'S01AA07', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('framycetin sulfate', 'S01AA07', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('framycetin sulfate', 'S01AA07', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('framycetin sulfate', 'S01AA07', 12.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('framycetin sulfate', 'S01AA07', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('frovatriptan (frovatriptan succinate)', 'N02CC07', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fulvestrant', 'L02BA03', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('furosemide', 'C03CA01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('furosemide', 'C03CA01', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('furosemide', 'C03CA01', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('furosemide', 'C03CA01', 80.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('furosemide', 'C03CA01', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fusidate sodium', 'D06AX01', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fusidic acid', 'S01AA13', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('fusidic acid', 'S01AA13', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gabapentin', 'N03AX12', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gabapentin', 'N03AX12', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gabapentin', 'N03AX12', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gabapentin', 'N03AX12', 600.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gabapentin', 'N03AX12', 800.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gadobenate dimeglumine', 'V08CA08', 529.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gadobutrol', 'V08CA09', 604.72, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gadodiamide', 'V08CA03', 287.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gadofosveset trisodium', 'V08CA11', 244.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gadopentetate dimeglumine', 'V08CA01', 469.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gadoteridol', 'V08CA04', 279.3, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gadoversetamide', 'V08CA06', 330.9, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gadoxetate disodium', 'V08CA10', 181.43, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('galantamine (galantamine hydrobromide)', 'N06DA04', 8.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('galantamine (galantamine hydrobromide)', 'N06DA04', 16.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('galantamine (galantamine hydrobromide)', 'N06DA04', 24.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ganciclovir (ganciclovir sodium)', 'J05AB06', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ganirelix (ganirelix acetate)', 'H01CC01', 250.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gatifloxacin', 'S01AX21', 0.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gefitinib', 'L01XE02', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gelatin', NULL, 13.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gemcitabine (gemcitabine hydrochloride)', 'L01BC05', 1.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gemcitabine (gemcitabine hydrochloride)', 'L01BC05', 2.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gemcitabine (gemcitabine hydrochloride)', 'L01BC05', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gemfibrozil', 'C10AB04', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gemfibrozil', 'C10AB04', 600.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gentamicin (gentamicin sulfate)', 'S02AA14', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gentamicin (gentamicin sulfate)', 'S02AA14', 0.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gentamicin (gentamicin sulfate)', 'S02AA14', 0.8, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gentamicin (gentamicin sulfate)', 'S02AA14', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gentamicin (gentamicin sulfate)', 'S02AA14', 1.2, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gentamicin (gentamicin sulfate)', 'S02AA14', 1.4, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gentamicin (gentamicin sulfate)', 'S02AA14', 1.6, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gentamicin (gentamicin sulfate)', 'S02AA14', 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gentamicin (gentamicin sulfate)', 'S02AA14', 4.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gentamicin (gentamicin sulfate)', 'S02AA14', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gentamicin (gentamicin sulfate)', 'S02AA14', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gentamicin sulfate', 'S02AA14', 1.67, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gentamicin sulfate', 'S02AA14', 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gentamicin sulfate', 'S02AA14', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gentian violet', 'D01AE02', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('geraniol', NULL, 0.07, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glatiramer acetate', 'L03AX13', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glatiramer acetate', 'L03AX13', 20.0, 'mg/1ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gliclazide', 'A10BB09', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gliclazide', 'A10BB09', 80.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glimepiride', 'A10BB12', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glimepiride', 'A10BB12', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glimepiride', 'A10BB12', 4.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glucagon (recombinant dna origin)', 'H04AA01', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glucagon (recombinant dna origin) (glucagon hydrochloride)', 'H04AA01', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glutamic acid', NULL, 1.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glutamic acid', NULL, 1.02, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glutamic acid', NULL, 1.107, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glutamic acid', NULL, 258.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glutamic acid', NULL, 314.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glutamic acid', NULL, 369.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glutamic acid', NULL, 517.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glutamic acid', NULL, 576.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glutamic acid', NULL, 627.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glutamic acid', NULL, 738.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glutamic acid', NULL, 820.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glutaral', 'V07AV', 0.15, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glutaral', 'V07AV', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glutaral', 'V07AV', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glutaral', 'V07AV', 2.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glutaral', 'V07AV', 2.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glutaral', 'V07AV', 2.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glutaral', 'V07AV', 2.6, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glutaral', 'V07AV', 2.65, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glutaral', 'V07AV', 3.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glutaral', 'V07AV', 7.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glutaral', 'V07AV', 7.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glutaral', 'V07AV', 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glutaral', 'V07AV', 10.725, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glutaral', 'V07AV', 12.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glutaral', 'V07AV', 12.75, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glutaral', 'V07AV', 20.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glutaral', 'V07AV', 24.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glutathione disulfide', NULL, 0.0184, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glyburide', 'A10BB01', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glyburide', 'A10BB01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycerine', 'V07AB', 0.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycerine', 'V07AB', 0.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycerine', 'V07AB', 0.26, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycerine', 'V07AB', 0.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycerine', 'V07AB', 1.67, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycerine', 'V07AB', 2.2, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycerine', 'V07AB', 2.6, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycerine', 'V07AB', 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycerine', 'V07AB', 50.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycerine', 'V07AB', 57.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycerine', 'V07AB', 800.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycine', 'B05CX03', 1.03, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycine', 'B05CX03', 1.04, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycine', 'B05CX03', 1.1, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycine', 'B05CX03', 1.19, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycine', 'B05CX03', 1.28, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycine', 'B05CX03', 1.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycine', 'B05CX03', 1.5, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycine', 'B05CX03', 2.06, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycine', 'B05CX03', 2.08, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycine', 'B05CX03', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycine', 'B05CX03', 51.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycine', 'B05CX03', 94.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycine', 'B05CX03', 175.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycine', 'B05CX03', 212.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycine', 'B05CX03', 250.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycine', 'B05CX03', 260.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycine', 'B05CX03', 270.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycine', 'B05CX03', 300.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycine', 'B05CX03', 350.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycine', 'B05CX03', 385.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycine', 'B05CX03', 400.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycine', 'B05CX03', 425.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycine', 'B05CX03', 438.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycine', 'B05CX03', 500.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycine', 'B05CX03', 515.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycine', 'B05CX03', 520.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycine', 'B05CX03', 640.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycine', 'B05CX03', 750.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycine', 'B05CX03', 880.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycine', 'B05CX03', 900.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycine', 'B05CX03', 1040.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycol salicylate', NULL, 1.25, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycol salicylate', NULL, 1.62, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('glycopyrrolate', 'A03AB02', 0.2, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gold', NULL, 1.4, 'µg/2ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gold sodium thiomalate', 'M01CB01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gold sodium thiomalate', 'M01CB01', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gold sodium thiomalate', 'M01CB01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('golimumab', 'L04AB06', 50.0, 'mg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gonadorelin (gonadorelin acetate)', NULL, 100.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gonadorelin (gonadorelin acetate)', NULL, 500.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gonadorelin acetate', 'H01CA01', 0.8, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('goserelin (goserelin acetate)', 'L02AE03', 3.6, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('goserelin (goserelin acetate)', 'L02AE03', 10.8, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gramicidin', 'R02AB30', 0.025, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gramicidin', 'R02AB30', 0.05, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gramicidin', 'R02AB30', 0.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('gramicidin', 'R02AB30', 50.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('granisetron (granisetron hydrochloride)', 'A04AA02', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('guaiacol carbonate', NULL, 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('guaiacol carbonate', NULL, 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('guaiacol carbonate', NULL, 600.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('guaifenesin', 'R05CA03', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('guaifenesin', 'R05CA03', 50.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('guaifenesin', 'R05CA03', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('guaifenesin', 'R05CA03', 100.0, 'mg/15ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('guaifenesin', 'R05CA03', 100.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('guaifenesin', 'R05CA03', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('guaifenesin', 'R05CA03', 200.0, 'mg/15ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('guaifenesin', 'R05CA03', 200.0, 'mg/30ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('guaifenesin', 'R05CA03', 200.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('guaifenesin', 'R05CA03', 221.0, 'mg/30ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('guaifenesin', 'R05CA03', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('guaifenesin', 'R05CA03', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('guaifenesin', 'R05CA03', 400.0, 'mg/30ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('guaifenesin', 'R05CA03', 600.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('guanethidine sulfate', 'C02CC02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('guanethidine sulfate', 'C02CC02', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('haemagglutinin from a/california/7/2009 (h1n1)v-like strain (x-179a)', NULL, 3.75, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('haemagglutinin-strain a(h1n1)', NULL, 9.0, 'µg/0.1ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('haemagglutinin-strain a(h1n1)', NULL, 15.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('haemagglutinin-strain a(h3n2)', NULL, 9.0, 'µg/0.1ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('haemagglutinin-strain a(h3n2)', NULL, 15.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('haemagglutinin-strain b', NULL, 9.0, 'µg/0.1ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('haemagglutinin-strain b', NULL, 15.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('haemophilus influenzae type b-prp', NULL, 7.5, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('haemophilus influenzae type b-prp', NULL, 10.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('halobetasol propionate', 'D07AC21', 0.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('haloperidol', 'N05AD01', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('haloperidol', 'N05AD01', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('haloperidol', 'N05AD01', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('haloperidol', 'N05AD01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('haloperidol', 'N05AD01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('haloperidol', 'N05AD01', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('haloperidol (haloperidol decanoate)', 'N05AD01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('haloperidol (haloperidol decanoate)', 'N05AD01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('halothane', 'N01AB01', 99.99, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hamamelis virginiana', NULL, 50.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('helium', 'V03AN03', 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('helium', 'V03AN03', 10.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('helium', 'V03AN03', 50.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('helium', 'V03AN03', 76.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('helium', 'V03AN03', 80.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('helium', 'V03AN03', 99.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('helium', 'V03AN03', 100.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('heparin (heparin sodium)', NULL, 2.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('heparin sodium', 'V07AC', 2.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('heparin sodium', 'V07AC', 10.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('heparin sodium', 'V07AC', 40.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('heparin sodium', 'V07AC', 50.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('heparin sodium', 'V07AC', 100.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('heparin sodium', 'V07AC', 200.0, 'unit/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('heparin sodium', 'V07AC', 1000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('heparin sodium', 'V07AC', 4000.0, 'unit/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('heparin sodium', 'V07AC', 5000.0, 'unit/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('heparin sodium', 'V07AC', 10000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('heparin sodium', 'V07AC', 10000.0, 'unit/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('heparin sodium', 'V07AC', 25000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hepatitis a vaccine, inactivated', 'J07BC02', 50.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hepatitis a vaccine, inactivated', 'J07BC02', 80.0, 'unit/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hepatitis a vaccine, inactivated', 'J07BC02', 160.0, 'unit/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hepatitis a vaccine, inactivated', 'J07BC02', 360.0, 'unit/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hepatitis a vaccine, inactivated', 'J07BC02', 500.0, 'unit/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hepatitis a vaccine, inactivated', 'J07BC02', 720.0, 'unit/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hepatitis a vaccine, inactivated', 'J07BC02', 720.0, 'unit/1.0ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hepatitis a vaccine, inactivated', 'J07BC02', 1440.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hepatitis b immune globulin human', 'J06BB04', 217.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hepatitis b immune globulin human', 'J06BB04', 312.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hepatitis b surface antigen (recombinant)', 'J07BC01', 10.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hepatitis b surface antigen (recombinant)', 'J07BC01', 10.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hepatitis b surface antigen (recombinant)', 'J07BC01', 20.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hepatitis b surface antigen (recombinant)', 'J07BC01', 20.0, 'µg/1.0ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hepatitis b surface antigen (recombinant)', 'J07BC01', 40.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hetastarch', 'B05AA07', 6.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hexachlorophene', 'D08AE01', 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hexetidine', 'A01AB12', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hexylresorcinol', 'R02AA12', 2.4, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hexylresorcinol', 'R02AA12', 3.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('histamine phosphate', 'V04CL', 0.275, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('histamine phosphate', 'V04CL', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('histamine phosphate', 'V04CL', 2.75, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('histidine', NULL, 1.18, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('histidine', NULL, 71.4, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('histidine', NULL, 105.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('histidine', NULL, 110.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('histidine', NULL, 120.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('histidine', NULL, 128.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('histidine', NULL, 150.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('histidine', NULL, 186.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('histidine', NULL, 204.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('histidine', NULL, 210.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('histidine', NULL, 220.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('histidine', NULL, 240.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('histidine', NULL, 250.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('histidine', NULL, 255.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('histidine', NULL, 260.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('histidine', NULL, 300.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('histidine', NULL, 312.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('histidine', NULL, 380.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('histidine', NULL, 420.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('histidine', NULL, 429.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('histidine', NULL, 440.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('histidine', NULL, 450.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('histidine', NULL, 480.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('histrelin acetate', 'H01CA03', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('homatropine hydrobromide', 'S01FA05', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('homatropine hydrobromide', 'S01FA05', 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('homosalate', NULL, 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('homosalate', NULL, 2.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('homosalate', NULL, 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('homosalate', NULL, 3.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('homosalate', NULL, 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('homosalate', NULL, 4.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('homosalate', NULL, 4.7, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('homosalate', NULL, 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('homosalate', NULL, 6.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('homosalate', NULL, 6.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('homosalate', NULL, 7.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('homosalate', NULL, 7.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('homosalate', NULL, 8.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('homosalate', NULL, 8.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('homosalate', NULL, 8.78, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('homosalate', NULL, 9.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('homosalate', NULL, 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('homosalate', NULL, 10.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('homosalate', NULL, 12.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('homosalate', NULL, 12.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('homosalate', NULL, 13.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('homosalate', NULL, 14.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('homosalate', NULL, 15.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('honey bee venom protein', 'V01AA07', 120.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('honey bee venom protein', 'V01AA07', 550.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('human plasma proteins', NULL, 7.5, 'mg/5.0ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('human plasma proteins', NULL, 15.0, 'mg/10.0ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydralazine hydrochloride', 'C02DB02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydralazine hydrochloride', 'C02DB02', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydralazine hydrochloride', 'C02DB02', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydralazine hydrochloride', 'C02DB02', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrochloric acid', 'V07AV', 0.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrochloric acid', 'V07AV', 9.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrochloric acid', 'V07AV', 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrochloric acid', 'V07AV', 23.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrochloric acid', 'V07AV', 36.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrochlorothiazide', 'C03AA03', 12.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrochlorothiazide', 'C03AA03', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrochlorothiazide', 'C03AA03', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrochlorothiazide', 'C03AA03', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrochlorothiazide', 'C03AA03', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrocodone', 'R05DA03', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrocodone', 'R05DA03', 5.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrocodone bitartrate', 'R05DA03', 0.33, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrocodone bitartrate', 'R05DA03', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrocodone bitartrate', 'R05DA03', 1.7, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrocodone bitartrate', 'R05DA03', 1.8, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrocodone bitartrate', 'R05DA03', 2.5, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrocodone bitartrate', 'R05DA03', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrocodone bitartrate', 'R05DA03', 5.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrocortisone', 'H02AB09', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrocortisone', 'H02AB09', 2.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrocortisone', 'H02AB09', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrocortisone', 'H02AB09', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrocortisone', 'H02AB09', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrocortisone', 'H02AB09', 100.0, 'mg/60ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrocortisone (hydrocortisone acetate)', NULL, 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrocortisone (hydrocortisone acetate)', NULL, 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrocortisone (hydrocortisone sodium succinate)', 'H02AB09', 1.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrocortisone (hydrocortisone sodium succinate)', 'H02AB09', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrocortisone (hydrocortisone sodium succinate)', 'H02AB09', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrocortisone (hydrocortisone sodium succinate)', 'H02AB09', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrocortisone acetate', 'S01BA02', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrocortisone acetate', 'S01BA02', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrocortisone acetate', 'S01BA02', 1.0, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrocortisone acetate', 'S01BA02', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrocortisone acetate', 'S01BA02', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrocortisone acetate', 'S01BA02', 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrocortisone acetate', 'S01BA02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrocortisone acetate', 'S01BA02', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrocortisone valerate', 'D07AA02', 0.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrogen peroxide', 'V07AV', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrogen peroxide', 'V07AV', 0.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrogen peroxide', 'V07AV', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrogen peroxide', 'V07AV', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrogen peroxide', 'V07AV', 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrogen peroxide', 'V07AV', 3.95, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrogen peroxide', 'V07AV', 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrogen peroxide', 'V07AV', 4.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrogen peroxide', 'V07AV', 4.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrogen peroxide', 'V07AV', 4.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrogen peroxide', 'V07AV', 7.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrogen peroxide', 'V07AV', 7.5, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrogen peroxide', 'V07AV', 7.99, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrogen peroxide', 'V07AV', 14.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrogen peroxide', 'V07AV', 20.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrogen peroxide', 'V07AV', 22.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrogen peroxide', 'V07AV', 25.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrogen peroxide', 'V07AV', 27.11, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrogen peroxide', 'V07AV', 35.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrogen peroxide', 'V07AV', 50.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrogen peroxide', 'V07AV', 58.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydrogen peroxide', 'V07AV', 59.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydromorphone hydrochloride', 'N02AA03', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydromorphone hydrochloride', 'N02AA03', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydromorphone hydrochloride', 'N02AA03', 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydromorphone hydrochloride', 'N02AA03', 4.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydromorphone hydrochloride', 'N02AA03', 6.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydromorphone hydrochloride', 'N02AA03', 8.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydromorphone hydrochloride', 'N02AA03', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydromorphone hydrochloride', 'N02AA03', 12.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydromorphone hydrochloride', 'N02AA03', 16.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydromorphone hydrochloride', 'N02AA03', 18.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydromorphone hydrochloride', 'N02AA03', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydromorphone hydrochloride', 'N02AA03', 24.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydromorphone hydrochloride', 'N02AA03', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydromorphone hydrochloride', 'N02AA03', 32.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydromorphone hydrochloride', 'N02AA03', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydromorphone hydrochloride', 'N02AA03', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydromorphone hydrochloride', 'N02AA03', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydroquinone', 'D11AX11', 1.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydroquinone', 'D11AX11', 1.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydroquinone', 'D11AX11', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydroquinone', 'D11AX11', 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydroquinone', 'D11AX11', 4.0, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydroxocobalamin', 'B03BA03', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydroxychloroquine sulfate', 'P01BA02', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydroxycitronellal', NULL, 0.054, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydroxyethyl starch 130/0.4', 'B05AA07', 6.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydroxyethylcellulose', NULL, 0.35, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydroxyethylcellulose', NULL, 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydroxyurea', 'L01XX05', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydroxyzine hydrochloride', 'N05BB01', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydroxyzine hydrochloride', 'N05BB01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydroxyzine hydrochloride', 'N05BB01', 10.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydroxyzine hydrochloride', 'N05BB01', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hydroxyzine hydrochloride', 'N05BB01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hyoscine butylbromide', 'A04AD01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hyoscine butylbromide', 'A04AD01', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hypromellose', 'S01XA20', 0.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hypromellose', 'S01XA20', 0.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hypromellose', 'S01XA20', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hypromellose', 'S01XA20', 0.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hypromellose', 'S01XA20', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hypromellose', 'S01XA20', 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('hypromellose', 'S01XA20', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('human c1 esterase inhibitor', 'B02AB03', 500.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ibuprofen', 'M01AE01', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ibuprofen', 'M01AE01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ibuprofen', 'M01AE01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ibuprofen', 'M01AE01', 100.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ibuprofen', 'M01AE01', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ibuprofen', 'M01AE01', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ibuprofen', 'M01AE01', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ibuprofen', 'M01AE01', 600.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ibutilide fumarate', 'C01BD05', 0.1, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('icodextrin', NULL, 75.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('idarubicin hydrochloride', 'L01DB06', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('idarubicin hydrochloride', 'L01DB06', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('idarubicin hydrochloride', 'L01DB06', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('idebenone', 'N06BX13', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('idoxuridine', 'S01AD01', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('idursulfase', 'A16AB09', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ifosfamide', 'L01AA06', 1.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ifosfamide', 'L01AA06', 3.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('imatinib (imatinib mesylate)', 'L01XE01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('imatinib (imatinib mesylate)', 'L01XE01', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('imiglucerase', 'A16AB02', 200.0, 'unit/20ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('imiglucerase', 'A16AB02', 400.0, 'unit/20ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('imipenem', NULL, 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('imipenem', NULL, 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('imipramine hydrochloride', 'N06AA02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('imipramine hydrochloride', 'N06AA02', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('imipramine hydrochloride', 'N06AA02', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('imipramine hydrochloride', 'N06AA02', 75.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('imiquimod', 'D06BB10', 3.75, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('imiquimod', 'D06BB10', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('immune globulin (human)', 'J06BA02', 0.5, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('immune globulin (human)', 'J06BA02', 2.5, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('immune globulin (human)', 'J06BA02', 5.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('immune globulin (human)', 'J06BA02', 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('immune globulin (human)', 'J06BA02', 10.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('immune globulin (human)', 'J06BA02', 10.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('immune globulin (human)', 'J06BA02', 18.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('immunoglobulin g (human)', 'J06BA01', 160.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('inact.japanese encephal virus(attenuat. strain sa14-14-2 produced in vero cells)', 'J07BA02', 6.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('inactivated poliomyelitis vaccine (d.c.o.) type 1 mahoney', NULL, 40.0, 'unit/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('inactivated poliomyelitis vaccine (d.c.o.) type 2 m.e.f.1', NULL, 8.0, 'unit/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('inactivated poliomyelitis vaccine (d.c.o.) type 3 saukett', NULL, 32.0, 'unit/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('inactivated poliomyelitis vaccine (v.c.o.) type 1 mahoney', NULL, 40.0, 'unit/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('inactivated poliomyelitis vaccine (v.c.o.) type 2 mef1', NULL, 8.0, 'unit/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('inactivated poliomyelitis vaccine (v.c.o.) type 3 saukett', NULL, 32.0, 'unit/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('inactivated poliovirus type i', NULL, 40.0, 'd/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('inactivated poliovirus type i', NULL, 40.0, 'unit/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('inactivated poliovirus type ii', NULL, 8.0, 'd/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isoflurane', 'N01AB06', 100.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('inactivated poliovirus type ii', NULL, 8.0, 'unit/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('inactivated poliovirus type iii', NULL, 32.0, 'd/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('inactivated poliovirus type iii', NULL, 32.0, 'unit/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('indapamide', 'C03BA11', 0.625, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('indapamide', 'C03BA11', 1.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('indapamide', 'C03BA11', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('indigo carmine', 'V04CH02', 0.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('indinavir (indinavir sulfate)', 'J05AE02', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('indinavir (indinavir sulfate)', 'J05AE02', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('indocyanine green', 'V04CX', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('indomethacin', 'M01AB01', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('indomethacin', 'M01AB01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('indomethacin', 'M01AB01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('indomethacin (sodium indomethacin)', 'C01EB03', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('infliximab', 'L04AB02', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('inosine pranobex', 'J05AX05', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('inositol', 'A11HA07', 2.222, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('inositol', 'A11HA07', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('insulin', 'ZXX0102', 30.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('insulin aspart', 'A10AB05', 30.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('insulin aspart', 'A10AB05', 100.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('insulin aspart protamine', NULL, 70.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('insulin biosynthetic human br', 'A10AC01', 100.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('insulin detemir', 'A10AE05', 100.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('insulin glargine', 'A10AE04', 100.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('insulin glulisine (recombinant dna origin)', 'A10AB06', 100.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('insulin injection human biosynthetic', 'A10AB01', 30.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('insulin injection human biosynthetic', 'A10AB01', 40.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('insulin injection human biosynthetic', 'A10AB01', 50.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('insulin injection human biosynthetic', 'A10AB01', 100.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('insulin injection pork', 'A10AB03', 100.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('insulin isophane (nph)', NULL, 70.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('insulin isophane human biosynthetic', 'A10AC01', 50.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('insulin isophane human biosynthetic', 'A10AC01', 60.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('insulin isophane human biosynthetic', 'A10AC01', 70.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('insulin isophane human biosynthetic', 'A10AC01', 100.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('insulin isophane injection pork', 'A10AC03', 100.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('insulin lispro', 'A10AB04', 25.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('insulin lispro', 'A10AB04', 50.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('insulin lispro', 'A10AB04', 100.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('insulin lispro protamine suspension', NULL, 50.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('insulin lispro protamine suspension', NULL, 75.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('insulin nph human dna origin', 'A10AC01', 100.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('insulin semi synthetic human', 'A10AB01', 100.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('interferon alfa-2b', 'L03AB05', 18.0, 'miu');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('interferon alfa-2b', 'L03AB05', 6000000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('interferon alfa-2b', 'L03AB05', 10000000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('interferon alfa-2b', 'L03AB05', 15000000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('interferon alfa-2b', 'L03AB05', 25000000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('interferon alfa-2b', 'L03AB05', 50000000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('interferon alfacon-1', 'L03AB09', 0.03, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('interferon beta-1a', 'L03AB07', 8.8, 'µg/0.2ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('interferon beta-1a', 'L03AB07', 11.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('interferon beta-1a', 'L03AB07', 22.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('interferon beta-1a', 'L03AB07', 30.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('interferon beta-1a', 'L03AB07', 44.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('interferon beta-1a', 'L03AB07', 66.0, 'µg/1.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('interferon beta-1a', 'L03AB07', 132.0, 'µg/1.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('interferon beta-1b', 'L03AB08', 0.3, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('iodide (sodium iodide)', 'A12CX', 100.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('iodine', 'D08AG03', 60.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('iodine (ethiodized oil)', 'V08AD01', 380.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('iodine (nonyl phenoxypoly ethoxy ethanol-iodine complex)', 'V07AV', 1.75, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('iodine (nonylphenyl-omega-hydroxypoly oxyethylene - iodine complex)', 'V07AV', 1.75, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('iodine (potassium iodide)', NULL, 0.025, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('iodine (potassium iodide)', NULL, 0.15, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('iodine (sodium iodide)', NULL, 25.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('iodine (sodium iodide)', NULL, 60.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('iodine (sodium iodide)', NULL, 75.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('iodixanol', 'V08AB09', 550.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('iodixanol', 'V08AB09', 652.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('iodoform', 'D09AA13', 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('iodoform', 'D09AA13', 15.8, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('iohexol', 'V08AB02', 388.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('iohexol', 'V08AB02', 518.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('iohexol', 'V08AB02', 647.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('iohexol', 'V08AB02', 755.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('iopamidol', 'V08AB04', 41.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('iopamidol', 'V08AB04', 61.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('iopamidol', 'V08AB04', 76.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('iopromide', 'V08AB05', 50.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('iopromide', 'V08AB05', 62.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('iopromide', 'V08AB05', 77.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('iothalamate meglumine', 'V08AA04', 172.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('iothalamate meglumine', 'V08AA04', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('iothalamate meglumine', 'V08AA04', 430.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('iothalamate meglumine', 'V08AA04', 600.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ioversol', 'V08AB07', 51.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ioversol', 'V08AB07', 64.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ioversol', 'V08AB07', 68.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ioversol', 'V08AB07', 74.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ioxaglate meglumine', NULL, 246.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ioxaglate meglumine', NULL, 393.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ioxaglate sodium', NULL, 123.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ioxaglate sodium', NULL, 196.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ipratropium bromide', 'R03BB01', 0.025, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ipratropium bromide', 'R03BB01', 0.03, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ipratropium bromide', 'R03BB01', 0.06, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ipratropium bromide', 'R03BB01', 0.125, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ipratropium bromide', 'R03BB01', 0.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ipratropium bromide', 'R03BB01', 0.3, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ipratropium bromide', 'R03BB01', 0.5, 'mg/2.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ipratropium bromide', 'R03BB01', 20.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ipratropium bromide', 'R03BB01', 21.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ipratropium bromide', 'R03BB01', 42.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ipratropium bromide', 'R03BB01', 125.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ipratropium bromide', 'R03BB01', 250.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ipratropium bromide (ipratropium bromide monohydrate)', NULL, 0.2, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ipratropium bromide (ipratropium bromide monohydrate)', NULL, 0.5, 'mg/2.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('irbesartan', 'C09CA04', 75.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('irbesartan', 'C09CA04', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('irbesartan', 'C09CA04', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('irinotecan hydrochloride', 'L01XX19', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('iron (ferrous fumarate)', NULL, 35.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('iron (iron dextran complex)', 'B03AC06', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('iron (iron sucrose)', 'B03AC02', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('iron (sodium ferric gluconate complex in sucrose injection)', 'B03AC07', 12.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isoeugenol', NULL, 0.015, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isoflurane', 'N01AB06', 99.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isoleucine', NULL, 1.08, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isoleucine', NULL, 1.38, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isoleucine', NULL, 85.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isoleucine', NULL, 462.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isoleucine', NULL, 480.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isoleucine', NULL, 560.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isoleucine', NULL, 590.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isoleucine', NULL, 600.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isoleucine', NULL, 620.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isoniazid', 'J04AC01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isoniazid', 'J04AC01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isoniazid', 'J04AC01', 50.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isoniazid', 'J04AC01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isoniazid', 'J04AC01', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isoniazid', 'J04AC01', 500.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isopropyl alcohol', 'V07AV', 1.18, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isopropyl alcohol', 'V07AV', 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isopropyl alcohol', 'V07AV', 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isopropyl alcohol', 'V07AV', 5.54, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isopropyl alcohol', 'V07AV', 8.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isopropyl alcohol', 'V07AV', 14.85, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isopropyl alcohol', 'V07AV', 15.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isopropyl alcohol', 'V07AV', 15.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isopropyl alcohol', 'V07AV', 17.2, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isopropyl alcohol', 'V07AV', 20.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isopropyl alcohol', 'V07AV', 21.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isopropyl alcohol', 'V07AV', 45.6, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isopropyl alcohol', 'V07AV', 53.41, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isopropyl alcohol', 'V07AV', 70.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isopropyl myristate', 'P03AX', 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isopropyl myristate', 'P03AX', 50.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isoproterenol hydrochloride', 'C01CA02', 0.2, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isosorbide dinitrate', 'C01DA08', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isosorbide dinitrate', 'C01DA08', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isosorbide dinitrate', 'C01DA08', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isosorbide-5-mononitrate', 'C01DA14', 60.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isotretinoin', 'D10BA01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('isotretinoin', 'D10BA01', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('itraconazole', 'J02AC02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('itraconazole', 'J02AC02', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lamivudine', 'J05AF05', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('japanese encephalitis virus vaccine inactivated', NULL, 1.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('juniper tar', NULL, 0.09, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('juniper tar', NULL, 0.16, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('juniper tar', NULL, 0.166, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('juniper tar', NULL, 0.33, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('kentucky blue/june', 'V01AA02', 100000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('kentucky bluegrass', 'V01AA02', 10000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('kentucky bluegrass', 'V01AA02', 100000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ketamine (ketamine hydrochloride)', 'N01AX03', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ketamine (ketamine hydrochloride)', 'N01AX03', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ketoconazole', 'J02AB02', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ketoconazole', 'J02AB02', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ketoprofen', 'M01AE03', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ketoprofen', 'M01AE03', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ketoprofen', 'M01AE03', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ketorolac tromethamine', 'S01BC05', 0.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ketorolac tromethamine', 'S01BC05', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ketorolac tromethamine', 'S01BC05', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ketorolac tromethamine', 'S01BC05', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ketotifen (ketotifen fumarate)', 'S01GX08', 0.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ketotifen (ketotifen fumarate)', 'S01GX08', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ketotifen (ketotifen fumarate)', 'S01GX08', 1.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ketotifen fumarate', 'R06AX17', 1.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-alanine', NULL, 1.04, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-alanine', NULL, 1.1, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-alanine', NULL, 1.28, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-alanine', NULL, 1.49, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-alanine', NULL, 2.07, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-alanine', NULL, 2.08, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-alanine', NULL, 348.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-alanine', NULL, 422.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-alanine', NULL, 490.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-alanine', NULL, 496.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-alanine', NULL, 520.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-alanine', NULL, 560.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-alanine', NULL, 640.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-alanine', NULL, 695.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-alanine', NULL, 698.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-alanine', NULL, 800.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-alanine', NULL, 844.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-alanine', NULL, 880.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-alanine', NULL, 900.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-alanine', NULL, 993.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-alanine', NULL, 1040.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-arginine', NULL, 1.018, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-arginine', NULL, 1.227, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-arginine', NULL, 1.527, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-arginine', NULL, 260.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-arginine', NULL, 290.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-arginine', NULL, 356.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-arginine', NULL, 432.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-arginine', NULL, 440.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-arginine', NULL, 489.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-arginine', NULL, 490.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-arginine', NULL, 509.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-arginine', NULL, 520.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-arginine', NULL, 575.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-arginine', NULL, 630.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-arginine', NULL, 690.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-arginine', NULL, 713.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-arginine', NULL, 840.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-arginine', NULL, 850.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-arginine', NULL, 861.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-arginine', NULL, 865.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-arginine', NULL, 980.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-aspartic acid', NULL, 1.05, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-aspartic acid', NULL, 245.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-aspartic acid', NULL, 298.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-aspartic acid', NULL, 330.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-aspartic acid', NULL, 370.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-aspartic acid', NULL, 490.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-aspartic acid', NULL, 527.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-aspartic acid', NULL, 595.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-aspartic acid', NULL, 600.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-aspartic acid', NULL, 700.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-cysteine', NULL, 189.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-cysteine (l-cysteine hydrochloride)', NULL, 13.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-cysteine (l-cysteine hydrochloride)', NULL, 13.9, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-ephedrine hydrochloride', NULL, 7.5, 'mg/30ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-isoleucine', NULL, 120.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-isoleucine', NULL, 150.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-isoleucine', NULL, 203.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-isoleucine', NULL, 231.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-isoleucine', NULL, 240.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-isoleucine', NULL, 255.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-isoleucine', NULL, 280.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-isoleucine', NULL, 300.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-isoleucine', NULL, 330.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-isoleucine', NULL, 360.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-isoleucine', NULL, 462.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-isoleucine', NULL, 500.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-isoleucine', NULL, 510.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-isoleucine', NULL, 534.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-isoleucine', NULL, 561.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-isoleucine', NULL, 620.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-isoleucine', NULL, 660.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-isoleucine', NULL, 670.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-isoleucine', NULL, 720.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-isoleucine', NULL, 760.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-isoleucine', NULL, 990.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-leucine', NULL, 1.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-leucine', NULL, 1.2, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-leucine', NULL, 1.5, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-leucine', NULL, 182.5, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-leucine', NULL, 310.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-leucine', NULL, 350.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-leucine', NULL, 365.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-leucine', NULL, 425.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-leucine', NULL, 470.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-leucine', NULL, 500.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-leucine', NULL, 600.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-leucine', NULL, 660.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-leucine', NULL, 700.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-leucine', NULL, 810.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-leucine', NULL, 831.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-leucine', NULL, 850.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-leucine', NULL, 940.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-leucine hydrochloride', NULL, 155.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-leucine hydrochloride', NULL, 263.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-leucine hydrochloride', NULL, 310.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-lysine', NULL, 1.1, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-lysine (l-lysine acetate)', NULL, 1.05, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-lysine (l-lysine acetate)', NULL, 360.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-lysine (l-lysine acetate)', NULL, 368.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-lysine (l-lysine acetate)', NULL, 446.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-lysine (l-lysine acetate)', NULL, 475.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-lysine (l-lysine acetate)', NULL, 510.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-lysine (l-lysine acetate)', NULL, 525.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-lysine (l-lysine acetate)', NULL, 624.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-lysine (l-lysine acetate)', NULL, 677.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-lysine (l-lysine acetate)', NULL, 720.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-lysine (l-lysine acetate)', NULL, 735.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-lysine (l-lysine acetate)', NULL, 893.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-lysine (l-lysine hydrochloride)', NULL, 145.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-lysine (l-lysine hydrochloride)', NULL, 290.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-lysine (l-lysine hydrochloride)', NULL, 580.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-lysine (lysine acetate)', NULL, 1.575, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-lysine (lysine acetate)', NULL, 446.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-lysine hydrochloride', NULL, 145.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-lysine hydrochloride', NULL, 246.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-lysine hydrochloride', NULL, 290.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-lysine hydrochloride', NULL, 450.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-lysine hydrochloride', NULL, 580.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-menthol', NULL, 1.0, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-menthol', NULL, 4.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-menthol', NULL, 5.67, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-methionine', NULL, 60.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-methionine', NULL, 73.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-methionine', NULL, 85.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-methionine', NULL, 100.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-methionine', NULL, 120.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-methionine', NULL, 125.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-methionine', NULL, 145.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-methionine', NULL, 146.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-methionine', NULL, 170.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-methionine', NULL, 172.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-methionine', NULL, 180.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-methionine', NULL, 200.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-methionine', NULL, 240.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-methionine', NULL, 246.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-methionine', NULL, 258.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-methionine', NULL, 280.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-methionine', NULL, 290.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-methionine', NULL, 340.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-methionine', NULL, 400.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-methionine', NULL, 500.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-methionine', NULL, 580.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-methionine', NULL, 726.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-ornithine dihydrochloride', NULL, 318.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-phenylalanine', NULL, 104.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-phenylalanine', NULL, 126.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-phenylalanine', NULL, 140.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-phenylalanine', NULL, 149.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-phenylalanine', NULL, 209.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-phenylalanine', NULL, 220.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-phenylalanine', NULL, 238.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-phenylalanine', NULL, 253.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-phenylalanine', NULL, 280.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-phenylalanine', NULL, 298.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-phenylalanine', NULL, 300.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-phenylalanine', NULL, 310.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-phenylalanine', NULL, 380.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-phenylalanine', NULL, 420.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-phenylalanine', NULL, 427.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-phenylalanine', NULL, 440.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-phenylalanine', NULL, 447.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-phenylalanine', NULL, 490.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-phenylalanine hydrochloride', NULL, 155.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-phenylalanine hydrochloride', NULL, 263.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-phenylalanine hydrochloride', NULL, 310.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-proline', NULL, 1.083, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-proline', NULL, 105.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-proline', NULL, 170.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-proline', NULL, 178.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-proline', NULL, 210.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-proline', NULL, 252.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-proline', NULL, 289.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-proline', NULL, 300.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-proline', NULL, 307.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-proline', NULL, 340.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-proline', NULL, 350.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-proline', NULL, 361.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-proline', NULL, 430.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-proline', NULL, 505.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-proline', NULL, 570.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-proline', NULL, 610.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-proline', NULL, 614.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-proline', NULL, 722.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-proline', NULL, 750.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-proline', NULL, 812.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-proline', NULL, 860.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-threonine', NULL, 105.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-threonine', NULL, 140.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-threonine', NULL, 170.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-threonine', NULL, 178.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-threonine', NULL, 178.5, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-threonine', NULL, 200.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-threonine', NULL, 210.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-threonine', NULL, 260.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-threonine', NULL, 280.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-threonine', NULL, 340.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-threonine', NULL, 360.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-threonine', NULL, 370.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-threonine', NULL, 380.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-threonine', NULL, 400.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-threonine', NULL, 460.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-threonine', NULL, 512.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-threonine', NULL, 520.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-threonine', NULL, 600.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-tyrosine', NULL, 10.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-tyrosine', NULL, 17.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-tyrosine', NULL, 20.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-tyrosine', NULL, 40.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-tyrosine', NULL, 44.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-tyrosine', NULL, 45.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-valine', NULL, 115.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-valine', NULL, 145.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-valine', NULL, 175.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-valine', NULL, 195.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-valine', NULL, 212.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-valine', NULL, 230.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-valine', NULL, 246.5, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-valine', NULL, 290.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-valine', NULL, 350.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-valine', NULL, 400.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-valine', NULL, 425.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-valine', NULL, 452.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-valine', NULL, 500.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-valine', NULL, 560.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-valine', NULL, 673.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-valine', NULL, 680.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-valine', NULL, 750.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-valine', NULL, 760.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-valine', NULL, 800.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('l-valine', NULL, 820.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('labetalol hydrochloride', 'C07AG01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('labetalol hydrochloride', 'C07AG01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('labetalol hydrochloride', 'C07AG01', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lacosamide', 'N03AX18', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lacosamide', 'N03AX18', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lacosamide', 'N03AX18', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lacosamide', 'N03AX18', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lactic acid', 'V07AV', 0.18, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lactic acid', 'V07AV', 0.284, 'g/1000ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lactic acid', 'V07AV', 5.4, '00g/1000ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lactic acid', 'V07AV', 5.4, 'g/1000ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lactulose', 'A06AD11', 667.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lamivudine', 'J05AF05', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lamivudine', 'J05AF05', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lamivudine', 'J05AF05', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lamivudine', 'J05AF05', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lamotrigine', 'N03AX09', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lamotrigine', 'N03AX09', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lamotrigine', 'N03AX09', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lamotrigine', 'N03AX09', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lamotrigine', 'N03AX09', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lanolin', NULL, 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lanolin', NULL, 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lanolin', NULL, 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lanolin', NULL, 9.88, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lanolin', NULL, 15.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lanreotide (lanreotide acetate)', 'H01CB03', 60.0, 'mg/0.3ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lanreotide (lanreotide acetate)', 'H01CB03', 90.0, 'mg/0.3ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lanreotide (lanreotide acetate)', 'H01CB03', 120.0, 'mg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lansoprazole', 'A02BC03', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lansoprazole', 'A02BC03', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lanthanum (lanthanum carbonate hydrate)', 'V03AE03', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lanthanum (lanthanum carbonate hydrate)', 'V03AE03', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lanthanum (lanthanum carbonate hydrate)', 'V03AE03', 750.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lanthanum (lanthanum carbonate hydrate)', 'V03AE03', 1000.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lapatinib (lapatinib ditosylate monohydrate)', 'L01XE07', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('laronidase', 'A16AB05', 0.58, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('latanoprost', 'S01EE01', 50.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('leflunomide', 'L04AA13', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('leflunomide', 'L04AA13', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('leflunomide', 'L04AA13', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lenalidomide', 'L04AX04', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lenalidomide', 'L04AX04', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lenalidomide', 'L04AX04', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lenalidomide', 'L04AX04', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lepirudin', 'B01AE02', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('letrozole', 'L02BG04', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('leucine', NULL, 1.08, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('leucine', NULL, 1.38, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('leucine', NULL, 102.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('leucine', NULL, 620.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('leucine', NULL, 726.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('leucine', NULL, 730.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('leucine', NULL, 770.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('leucine', NULL, 810.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('leucine', NULL, 880.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('leucovorin (leucovorin calcium)', 'V03AF03', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('leucovorin (leucovorin calcium)', 'V03AF03', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('leuprolide acetate', 'L02AE02', 3.75, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('leuprolide acetate', 'L02AE02', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('leuprolide acetate', 'L02AE02', 7.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('leuprolide acetate', 'L02AE02', 10.2, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('leuprolide acetate', 'L02AE02', 11.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('leuprolide acetate', 'L02AE02', 22.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('leuprolide acetate', 'L02AE02', 28.2, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('leuprolide acetate', 'L02AE02', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('leuprolide acetate', 'L02AE02', 35.8, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('leuprolide acetate', 'L02AE02', 58.2, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levetiracetam', 'N03AX14', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levetiracetam', 'N03AX14', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levetiracetam', 'N03AX14', 750.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levobunolol hydrochloride', 'S01ED03', 0.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levobunolol hydrochloride', 'S01ED03', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levobunolol hydrochloride', 'S01ED03', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levocabastine (levocabastine hydrochloride)', 'S01GX02', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levocarnitine', 'A16AA01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levocarnitine', 'A16AA01', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levocarnitine', 'A16AA01', 330.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levodopa', 'N04BA01', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levodopa', 'N04BA01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levodopa', 'N04BA01', 75.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levodopa', 'N04BA01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levodopa', 'N04BA01', 125.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levodopa', 'N04BA01', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levodopa', 'N04BA01', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levodopa', 'N04BA01', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levofloxacin', 'J01MA12', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levofloxacin', 'J01MA12', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levofloxacin', 'J01MA12', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levofloxacin', 'J01MA12', 750.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levofloxacin (levofloxacin hemihydrate)', 'J01MA12', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levofloxacin (levofloxacin hemihydrate)', 'J01MA12', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levofloxacin (levofloxacin hemihydrate)', 'J01MA12', 750.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levonorgestrel', 'G03AC03', 0.15, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levonorgestrel', 'G03AC03', 0.75, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levonorgestrel', 'G03AC03', 1.39, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levonorgestrel', 'G03AC03', 50.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levonorgestrel', 'G03AC03', 52.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levonorgestrel', 'G03AC03', 75.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levonorgestrel', 'G03AC03', 100.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levonorgestrel', 'G03AC03', 125.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levonorgestrel', 'G03AC03', 150.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levothyroxine sodium', 'H03AA01', 25.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levothyroxine sodium', 'H03AA01', 50.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levothyroxine sodium', 'H03AA01', 75.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levothyroxine sodium', 'H03AA01', 88.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levothyroxine sodium', 'H03AA01', 100.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levothyroxine sodium', 'H03AA01', 112.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levothyroxine sodium', 'H03AA01', 125.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levothyroxine sodium', 'H03AA01', 137.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levothyroxine sodium', 'H03AA01', 150.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levothyroxine sodium', 'H03AA01', 175.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levothyroxine sodium', 'H03AA01', 200.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levothyroxine sodium', 'H03AA01', 300.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('levothyroxine sodium', 'H03AA01', 500.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine', 'N01BB02', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine', 'N01BB02', 0.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine', 'N01BB02', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine', 'N01BB02', 2.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine', 'N01BB02', 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine', 'N01BB02', 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine', 'N01BB02', 5.0, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine', 'N01BB02', 9.6, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine', 'N01BB02', 15.0, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine', 'N01BB02', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine', 'N01BB02', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine (lidocaine hydrochloride)', 'R02AD02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine (lidocaine hydrochloride)', 'R02AD02', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine hydrochloride', 'N01BB02', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine hydrochloride', 'N01BB02', 0.7, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine hydrochloride', 'N01BB02', 0.72, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine hydrochloride', 'N01BB02', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine hydrochloride', 'N01BB02', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine hydrochloride', 'N01BB02', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine hydrochloride', 'N01BB02', 2.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine hydrochloride', 'N01BB02', 2.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine hydrochloride', 'N01BB02', 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine hydrochloride', 'N01BB02', 4.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine hydrochloride', 'N01BB02', 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine hydrochloride', 'N01BB02', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine hydrochloride', 'N01BB02', 8.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine hydrochloride', 'N01BB02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine hydrochloride', 'N01BB02', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine hydrochloride', 'N01BB02', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine hydrochloride', 'N01BB02', 36.0, 'mg/1.8ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine hydrochloride', 'N01BB02', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine hydrochloride', 'N01BB02', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine hydrochloride', 'N01BB02', 100.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine hydrochloride', 'N01BB02', 200.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine hydrochloride', 'N01BB02', 400.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine hydrochloride', 'N01BB02', 800.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lidocaine hydrochloride (lidocaine hydrochloride monohydrate)', NULL, 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lincomycin (lincomycin hydrochloride)', 'J01FF02', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lindane', 'P03AB02', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('linezolid', 'J01XX08', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('linezolid', 'J01XX08', 3.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('linezolid', 'J01XX08', 600.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('liothyronine', 'H03AA02', 5.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('liothyronine', 'H03AA02', 25.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lipase', NULL, 4000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lipase', NULL, 4500.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lipase', NULL, 5000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lipase', NULL, 8000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lipase', NULL, 10000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lipase', NULL, 12000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lipase', NULL, 16000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lipase', NULL, 16640.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lipase', NULL, 20000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lipase', NULL, 25000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('liraglutide', 'A10BX07', 6.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lisdexamfetamine dimesylate', 'N06BA12', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lisdexamfetamine dimesylate', 'N06BA12', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lisdexamfetamine dimesylate', 'N06BA12', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lisdexamfetamine dimesylate', 'N06BA12', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lisdexamfetamine dimesylate', 'N06BA12', 60.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lisinopril', 'C09AA03', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lisinopril', 'C09AA03', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lisinopril', 'C09AA03', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lisinopril', 'C09AA03', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lisinopril (lisinopril dihydrate)', 'C09AA03', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lisinopril (lisinopril dihydrate)', 'C09AA03', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lisinopril (lisinopril dihydrate)', 'C09AA03', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lithium (lithium citrate)', 'N05AN01', 8.0, 'mmo/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lithium carbonate', 'N05AN01', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lithium carbonate', 'N05AN01', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lithium carbonate', 'N05AN01', 600.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lodoxamide (lodoxamide tromethamine)', 'S01GX05', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lomustine', 'L01AD02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lomustine', 'L01AD02', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lomustine', 'L01AD02', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('loperamide hydrochloride', 'A07DA03', 0.2, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('loperamide hydrochloride', 'A07DA03', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('loperamide hydrochloride', 'A07DA03', 2.0, 'mg/15ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lopinavir', 'J05AE06', 80.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lopinavir', 'J05AE06', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lopinavir', 'J05AE06', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('loratadine', 'R06AX13', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('loratadine', 'R06AX13', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('loratadine', 'R06AX13', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lorazepam', 'N05BA06', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lorazepam', 'N05BA06', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lorazepam', 'N05BA06', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lorazepam', 'N05BA06', 4.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('losartan potassium', 'C09CA01', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('losartan potassium', 'C09CA01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('losartan potassium', 'C09CA01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('loteprednol etabonate', 'S01BA14', 0.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('loteprednol etabonate', 'S01BA14', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lovastatin', 'C10AA02', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lovastatin', 'C10AA02', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('loxapine (loxapine hydrochloride)', 'N05AH01', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('loxapine (loxapine hydrochloride)', 'N05AH01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('loxapine (loxapine succinate)', 'N05AH01', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('loxapine (loxapine succinate)', 'N05AH01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('loxapine (loxapine succinate)', 'N05AH01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('loxapine (loxapine succinate)', 'N05AH01', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('loxapine (loxapine succinate)', 'N05AH01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lutropin alfa', 'G03GA07', 75.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lymphocyte immune globulin anti-thymocyte globulin (equine)', 'L04AA03', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lysine (l-lysine hydrochloride)', NULL, 246.5, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lysine (l-lysine hydrochloride)', NULL, 290.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lysine (lysine acetate)', NULL, 1.35, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lysine (lysine acetate)', NULL, 446.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lysine (lysine acetate)', NULL, 535.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lysine (lysine acetate)', NULL, 620.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lysine (lysine acetate)', NULL, 624.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lysine (lysine acetate)', NULL, 640.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('lysine (lysine monohydrochloride)', NULL, 95.5, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('macrogol', 'A06AD15', 15.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('macrogol', 'A06AD15', 59.55, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('macrogol', 'A06AD15', 152.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('macrogol', 'A06AD15', 160.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('macrogol', 'A06AD15', 236.0, 'g/4l');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('macrogol', 'A06AD15', 238.18, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium (magnesium hydroxide)', NULL, 56.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium (magnesium oxide)', NULL, 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium (magnesium oxide)', NULL, 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium acetate', NULL, 0.21, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium acetate', NULL, 32.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium acetate', NULL, 860.0, 'mg/25ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium carbonate', 'A02AA01', 34.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium carbonate', 'A02AA01', 52.3, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 0.02, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 0.03, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 0.054, 'g/1000ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 0.1017, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 0.108, 'g/1000ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 0.116, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 0.136, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 0.14, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 0.14, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 0.152, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 0.3, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 1.61, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 2.033, 'g/1000ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 2.06, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 2.12, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 2.14, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 3.21, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 3.253, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 3.43, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 4.07, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 4.57, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 5.08, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 5.1, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 6.86, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 6.861, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 15.2, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 20.5, 'g/4.5l');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 25.4, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 25.5, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 30.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 31.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 51.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 51.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 102.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 169.6, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium chloride', 'B05ZA', 510.0, 'mg/20ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium hydroxide', 'A02AA04', 60.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium hydroxide', 'A02AA04', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium hydroxide', 'A02AA04', 100.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium hydroxide', 'A02AA04', 165.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium hydroxide', 'A02AA04', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium hydroxide', 'A02AA04', 200.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium hydroxide', 'A02AA04', 400.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium oxide', 'A02AA02', 1.9, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium oxide', 'A02AA02', 3.5, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium oxide', 'A02AA02', 3.8, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium oxide', 'A02AA02', 63.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium oxide', 'A02AA02', 96.9, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium oxide', 'A02AA02', 380.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium sulfate', 'B05XA05', 1.0, 'g/2ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium sulfate', 'B05XA05', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium sulfate', 'B05XA05', 20.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium sulfate', 'B05XA05', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('magnesium sulfate', 'B05XA05', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('manganese (manganese gluconate)', NULL, 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('manganese (manganese sulfate)', 'A12CX', 0.1, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('manganese (manganese sulfate)', 'A12CX', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('manganese chloride', NULL, 0.37, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mannitol', 'B05CX04', 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mannitol', 'B05CX04', 5.4, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mannitol', 'B05CX04', 10.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mannitol', 'B05CX04', 20.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mannitol', 'B05CX04', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mannitol', 'B05CX04', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mannitol', 'B05CX04', 500.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('maprotiline hydrochloride', 'N06AA21', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('maprotiline hydrochloride', 'N06AA21', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('maprotiline hydrochloride', 'N06AA21', 75.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('maraviroc', 'J05AX09', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('maraviroc', 'J05AX09', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('measles virus vaccine live attenuated', NULL, 1.0, 'dose');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('measles virus vaccine live attenuated', NULL, 1000.0, 'unit/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mebendazole', 'P02CA01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mechlorethamine hydrochloride', 'L01AA05', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meclizine hydrochloride', 'R06AE05', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('medroxyprogesterone acetate', 'G03DA02', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('medroxyprogesterone acetate', 'G03DA02', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('medroxyprogesterone acetate', 'G03DA02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('medroxyprogesterone acetate', 'G03DA02', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('medroxyprogesterone acetate', 'G03DA02', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('medroxyprogesterone acetate', 'G03DA02', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('medrysone', 'S01BA08', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mefenamic acid', 'M01AG01', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mefloquine (mefloquine hydrochloride)', 'P01BC02', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('megestrol acetate', 'L02AB01', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('megestrol acetate', 'L02AB01', 160.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meglumine iodipamide', 'V08AC04', 26.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meglumine iodipamide', 'V08AC04', 52.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meglumine ioxitalamate', NULL, 513.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meloxicam', 'M01AC06', 7.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meloxicam', 'M01AC06', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('melphalan', 'L01AA03', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('melphalan (melphalan hydrochloride)', NULL, 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('memantine hydrochloride', 'N06DX01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meningococcal group a oligosaccharide', NULL, 10.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meningococcal group c oligosaccharide', NULL, 5.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meningococcal group c oligosaccharide', NULL, 10.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meningococcal group w-135 oligosaccharide', NULL, 5.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meningococcal group y oligosaccharide', NULL, 5.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meningococcal polysaccharide antigen group a', NULL, 50.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meningococcal polysaccharide antigen group a', NULL, 500.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meningococcal polysaccharide antigen group c', NULL, 50.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meningococcal polysaccharide antigen group c', NULL, 500.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meningococcal polysaccharide antigen group w-135', NULL, 50.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meningococcal polysaccharide antigen group w-135', NULL, 500.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meningococcal polysaccharide antigen group y', NULL, 50.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meningococcal polysaccharide antigen group y', NULL, 500.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meningococcal polysaccharide vaccine grp c', NULL, 10.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meningococcal polysaccharide-diphtheria toxoid conjugate, group a', NULL, 4.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meningococcal polysaccharide-diphtheria toxoid conjugate, group c', NULL, 4.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meningococcal polysaccharide-diphtheria toxoid conjugate, group w 135', NULL, 4.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meningococcal polysaccharide-diphtheria toxoid conjugate, group y', NULL, 4.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('menotropins', 'G03GA02', 75.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('menthol', NULL, 0.15, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('menthol', NULL, 0.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('menthol', NULL, 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('menthol', NULL, 0.6, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('menthol', NULL, 0.97, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('menthol', NULL, 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('menthol', NULL, 1.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('menthol', NULL, 1.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('menthol', NULL, 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('menthol', NULL, 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('menthol', NULL, 6.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('menthol', NULL, 8.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('menthol', NULL, 10.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('menthol', NULL, 15.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('menthol', NULL, 20.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('menthol', NULL, 22.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('menthol', NULL, 200.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meperidine (meperidine hydrochloride)', 'N02AB02', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meperidine (meperidine hydrochloride)', 'N02AB02', 75.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meperidine (meperidine hydrochloride)', 'N02AB02', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meperidine hydrochloride', 'N02AB02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meperidine hydrochloride', 'N02AB02', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meperidine hydrochloride', 'N02AB02', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meperidine hydrochloride', 'N02AB02', 75.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meperidine hydrochloride', 'N02AB02', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mepivacaine hydrochloride', 'N01BB03', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mepivacaine hydrochloride', 'N01BB03', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mepivacaine hydrochloride', 'N01BB03', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meprobamate', 'N05BC01', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mequinol', 'D11AX06', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meradimate', NULL, 2.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meradimate', NULL, 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meradimate', NULL, 4.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meradimate', NULL, 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mercaptobenzothiazole', NULL, 0.061, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mercaptopurine', 'L01BB02', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meropenem', 'J01DH02', 1.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('meropenem', 'J01DH02', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mesalazine', 'A07EC02', 1.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mesalazine', 'A07EC02', 1.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mesalazine', 'A07EC02', 1.2, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mesalazine', 'A07EC02', 2.0, 'g/60g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mesalazine', 'A07EC02', 4.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mesalazine', 'A07EC02', 4.0, 'g/60g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mesalazine', 'A07EC02', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mesalazine', 'A07EC02', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mesalazine', 'A07EC02', 800.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mesalazine', 'A07EC02', 1000.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mesna', 'V03AF01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('metformin hydrochloride', 'A10BA02', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('metformin hydrochloride', 'A10BA02', 850.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('metformin hydrochloride', 'A10BA02', 1000.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methacholine chloride', 'V04CX', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methacholine chloride', 'V04CX', 160.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methacholine chloride', 'V04CX', 320.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methacholine chloride', 'V04CX', 480.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methacholine chloride', 'V04CX', 1280.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methacholine chloride', 'V04CX', 1600.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methadone hydrochloride', 'N07BC02', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methadone hydrochloride', 'N07BC02', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methadone hydrochloride', 'N07BC02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methadone hydrochloride', 'N07BC02', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methazolamide', 'S01EC05', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methenamine', 'J01XX05', 0.5, 'g/2tsp');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methenamine mandelate', 'J01XX05', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methocarbamol', 'M03BA03', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methocarbamol', 'M03BA03', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methocarbamol', 'M03BA03', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methocarbamol', 'M03BA03', 750.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methotrexate', 'L01BA01', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methotrexate', 'L01BA01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methotrexate (methotrexate sodium)', 'L01BA01', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methotrexate (methotrexate sodium)', 'L01BA01', 7.5, 'mg/0.75ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methotrexate (methotrexate sodium)', 'L01BA01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methotrexate (methotrexate sodium)', 'L01BA01', 15.0, 'mg/1.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methotrexate (methotrexate sodium)', 'L01BA01', 20.0, 'mg/2ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methotrexate (methotrexate sodium)', 'L01BA01', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methotrexate (methotrexate sodium)', 'L01BA01', 25.0, 'mg/2.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methotrimeprazine (methotrimeprazine hydrochloride)', 'N05AA02', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methotrimeprazine (methotrimeprazine maleate)', 'N05AA02', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methotrimeprazine (methotrimeprazine maleate)', 'N05AA02', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methotrimeprazine (methotrimeprazine maleate)', 'N05AA02', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methotrimeprazine (methotrimeprazine maleate)', 'N05AA02', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methoxsalen', 'D05BA02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methsuximide', 'N03AD03', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methyl aminolevulinate (methyl aminolevulinate hydrochloride)', 'L01XD03', 168.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methyl dodecyl benzyl trimethyl ammonium chloride', NULL, 16.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methyl heptyl colamino formylmethyl pyridinium chl', NULL, 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methyl nicotinate', NULL, 0.75, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methyl salicylate', NULL, 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methyl salicylate', NULL, 2.5, 'ml/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methyl salicylate', NULL, 6.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methylchloroisothiazolinone', NULL, 0.0032, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methyldopa', 'C02AB02', 125.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methyldopa', 'C02AB02', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methyldopa', 'C02AB02', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methylene blue', 'V04CG05', 0.2, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methylene blue', 'V04CG05', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methylene blue', 'V04CG05', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methylene blue', 'V04CG05', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methylnaltrexone bromide', 'A06AH01', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methylparaben', NULL, 0.16, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methylphenidate hydrochloride', 'N06BA04', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methylphenidate hydrochloride', 'N06BA04', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methylphenidate hydrochloride', 'N06BA04', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methylphenidate hydrochloride', 'N06BA04', 18.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methylphenidate hydrochloride', 'N06BA04', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('morphine sulfate', 'N02AA01', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methylphenidate hydrochloride', 'N06BA04', 27.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methylphenidate hydrochloride', 'N06BA04', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methylphenidate hydrochloride', 'N06BA04', 36.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methylphenidate hydrochloride', 'N06BA04', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methylphenidate hydrochloride', 'N06BA04', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methylphenidate hydrochloride', 'N06BA04', 54.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methylphenidate hydrochloride', 'N06BA04', 60.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methylphenidate hydrochloride', 'N06BA04', 80.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methylprednisolone', 'H02AB04', 1.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methylprednisolone', 'H02AB04', 4.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methylprednisolone', 'H02AB04', 16.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methylprednisolone', 'H02AB04', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methylprednisolone (methylprednisolone sodium succinate)', 'H02AB04', 1.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methylprednisolone (methylprednisolone sodium succinate)', 'H02AB04', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methylprednisolone (methylprednisolone sodium succinate)', 'H02AB04', 125.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methylprednisolone (methylprednisolone sodium succinate)', 'H02AB04', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methylprednisolone (methylprednisolone sodium succinate)', 'H02AB04', 1000.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methylprednisolone acetate', 'H02AB04', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methylprednisolone acetate', 'H02AB04', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methylprednisolone acetate', 'H02AB04', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('methylprednisolone acetate', 'H02AB04', 80.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('metoclopramide hydrochloride', 'A03FA01', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('metoclopramide hydrochloride', 'A03FA01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('metoclopramide hydrochloride', 'A03FA01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('metolazone', 'C03BA08', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('metoprolol tartrate', 'C07AB02', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('metoprolol tartrate', 'C07AB02', 1.0, 'mg/1ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('metoprolol tartrate', 'C07AB02', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('metoprolol tartrate', 'C07AB02', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('metoprolol tartrate', 'C07AB02', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('metoprolol tartrate', 'C07AB02', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('metronidazole', 'P01AB01', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('metronidazole', 'P01AB01', 0.75, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('metronidazole', 'P01AB01', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('metronidazole', 'P01AB01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('metronidazole', 'P01AB01', 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('metronidazole', 'P01AB01', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('metronidazole', 'P01AB01', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('metronidazole', 'P01AB01', 500.0, 'mg/4.5g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('metronidazole', 'P01AB01', 750.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mexiletine hydrochloride', 'C01BB02', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mexiletine hydrochloride', 'C01BB02', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('micafungin sodium', 'J02AX05', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('micafungin sodium', 'J02AX05', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('miconazole nitrate', 'G01AF04', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('miconazole nitrate', 'G01AF04', 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('miconazole nitrate', 'G01AF04', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('miconazole nitrate', 'G01AF04', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('miconazole nitrate', 'G01AF04', 1200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('midazolam', 'N05CD08', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('midazolam', 'N05CD08', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('midazolam (midazolam hydrochloride)', 'N05CD08', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('midazolam (midazolam hydrochloride)', 'N05CD08', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('midodrine hydrochloride', 'C01CA17', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('midodrine hydrochloride', 'C01CA17', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('miglustat', 'A16AX06', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('milrinone (milrinone lactate)', 'C01CE02', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mineral oil', 'D02AC', 0.25, 'ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mineral oil', 'D02AC', 1.6, 'ml/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mineral oil', 'D02AC', 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mineral oil', 'D02AC', 7.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mineral oil', 'D02AC', 12.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mineral oil', 'D02AC', 15.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mineral oil', 'D02AC', 20.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mineral oil', 'D02AC', 42.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mineral oil', 'D02AC', 63.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mineral oil', 'D02AC', 64.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mineral oil', 'D02AC', 78.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mineral oil', 'D02AC', 80.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mineral oil', 'D02AC', 91.7, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mineral oil', 'D02AC', 100.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mineral oil light', 'D02AC', 100.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('minocycline (minocycline hydrochloride)', 'J01AA08', 1.0, 'mg/4mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('minocycline (minocycline hydrochloride)', 'J01AA08', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('minocycline (minocycline hydrochloride)', 'J01AA08', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('minoxidil', 'D11AX01', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('minoxidil', 'D11AX01', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('minoxidil', 'D11AX01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('minoxidil', 'D11AX01', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mirtazapine', 'N06AX11', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mirtazapine', 'N06AX11', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mirtazapine', 'N06AX11', 45.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('misoprostol', 'A02BB01', 0.1, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('misoprostol', 'A02BB01', 0.2, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('misoprostol', 'A02BB01', 100.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('misoprostol', 'A02BB01', 200.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mitomycin', 'L01DC03', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mitomycin', 'L01DC03', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mitotane', 'L01XX23', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mitoxantrone (mitoxantrone hydrochloride)', 'L01DB07', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('moclobemide', 'N06AG02', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('moclobemide', 'N06AG02', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('moclobemide', 'N06AG02', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('modafinil', 'N06BA07', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('modified ragweed tyrosine adsorbate', NULL, 210.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('modified ragweed tyrosine adsorbate', NULL, 500.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('modified ragweed tyrosine adsorbate', NULL, 1400.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('modified ragweed tyrosine adsorbate', NULL, 4300.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mometasone furoate', 'R01AD09', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mometasone furoate', 'R01AD09', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mometasone furoate', 'R01AD09', 50.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('monobenzone', 'D11AX13', 20.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('montelukast (montelukast sodium)', 'R03DC03', 4.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('montelukast (montelukast sodium)', 'R03DC03', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('montelukast (montelukast sodium)', 'R03DC03', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('moroctocog alfa', 'B02BD02', 250.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('moroctocog alfa', 'B02BD02', 500.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('moroctocog alfa', 'B02BD02', 1000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('moroctocog alfa', 'B02BD02', 2000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('morphine hydrochloride', 'N02AA01', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('morphine hydrochloride', 'N02AA01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('morphine hydrochloride', 'N02AA01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('morphine hydrochloride', 'N02AA01', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('morphine hydrochloride', 'N02AA01', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('morphine hydrochloride', 'N02AA01', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('morphine hydrochloride', 'N02AA01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('morphine hydrochloride', 'N02AA01', 60.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('morphine sulfate', 'N02AA01', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('morphine sulfate', 'N02AA01', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('morphine sulfate', 'N02AA01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('morphine sulfate', 'N02AA01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('morphine sulfate', 'N02AA01', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('morphine sulfate', 'N02AA01', 15.0, 'mg/1ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('morphine sulfate', 'N02AA01', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('morphine sulfate', 'N02AA01', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('morphine sulfate', 'N02AA01', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('morphine sulfate', 'N02AA01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('morphine sulfate', 'N02AA01', 60.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('morphine sulfate', 'N02AA01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('morphine sulfate', 'N02AA01', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('moxifloxacin (moxifloxacin hydrochloride)', 'S01AX22', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('moxifloxacin (moxifloxacin hydrochloride)', 'S01AX22', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('moxifloxacin (moxifloxacin hydrochloride)', 'S01AX22', 400.0, 'mg/250ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mumps virus vaccine live attenuated jeryl lynn strain', NULL, 5000.0, 'unit/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mumps virus vaccine live attenuated jeryl lynn strain', NULL, 10000.0, 'unit/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mumps virus vaccine live attenuated jeryl lynn strain', NULL, 25118.9, 'unit/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mupirocin', 'D06AX09', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mupirocin (mupirocin calcium dihydrate)', 'D06AX09', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mycophenolate mofetil', 'L04AA06', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mycophenolate mofetil', 'L04AA06', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mycophenolate mofetil', 'L04AA06', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mycophenolate mofetil (mycophenolate mofetil hydrochloride)', 'L04AA06', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mycophenolic acid (mycophenolate sodium)', 'L04AA06', 180.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('mycophenolic acid (mycophenolate sodium)', 'L04AA06', 360.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('myristamidopropyl dimethylamine', NULL, 0.0005, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('myroxylon balsamum', NULL, 4.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('n,n''-diphenyl-para-phenylenediamine', NULL, 0.025, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('n-acetyl-l-tyrosine', NULL, 94.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('n-acetyl-l-tyrosine', NULL, 115.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('n-acetyl-l-tyrosine', NULL, 135.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('n-acetyl-l-tyrosine', NULL, 189.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('n-acetyl-l-tyrosine', NULL, 230.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('n-acetyl-l-tyrosine', NULL, 270.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('n-acetyl-l-tyrosine', NULL, 405.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('n-cyclohexyl-2-benzothiazolesulfenamide', NULL, 0.02, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('n-cyclohexyl-n''-phenyl-para-phenylenediamine', NULL, 0.025, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('n-hydroxymethylsuccinimide', NULL, 0.15, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('n-isopropyl-n''-phenyl-para-phenylenediamine', NULL, 0.01, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nabilone', 'A04AD11', 0.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nabilone', 'A04AD11', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nabilone', 'A04AD11', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nabumetone', 'M01AX01', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nabumetone', 'M01AX01', 750.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nadolol', 'C07AA12', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nadolol', 'C07AA12', 80.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nadolol', 'C07AA12', 160.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nadroparin calcium', 'B01AB06', 9500.0, 'unit/1.0ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nadroparin calcium', 'B01AB06', 19000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nafarelin (nafarelin acetate)', 'H01CA02', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('naftifine hydrochloride', 'D01AE22', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nalbuphine hydrochloride', 'N02AF02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nalbuphine hydrochloride', 'N02AF02', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('naloxone (naloxone hydrochloride dihydrate)', NULL, 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('naloxone (naloxone hydrochloride dihydrate)', NULL, 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('naloxone hydrochloride', 'V03AB15', 0.4, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('naloxone hydrochloride', 'V03AB15', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('naloxone hydrochloride', 'V03AB15', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('naloxone hydrochloride', 'V03AB15', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('naloxone hydrochloride', 'V03AB15', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('naltrexone hydrochloride', 'N07BB04', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('naphazoline hydrochloride', 'S01GA01', 0.012, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('naphazoline hydrochloride', 'S01GA01', 0.025, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('naphazoline hydrochloride', 'S01GA01', 0.02675, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('naphazoline hydrochloride', 'S01GA01', 0.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('naphazoline hydrochloride', 'S01GA01', 0.051, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('naphazoline hydrochloride', 'S01GA01', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('naphazoline hydrochloride', 'S01GA01', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('naphazoline nitrate', 'S01GA01', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('naproxen', 'M01AE02', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('naproxen', 'M01AE02', 125.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('naproxen', 'M01AE02', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('naproxen', 'M01AE02', 375.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('naproxen', 'M01AE02', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('naproxen', 'M01AE02', 750.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('naproxen (naproxen sodium)', 'M01AE02', 375.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('naproxen (naproxen sodium)', 'M01AE02', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('naproxen sodium', 'M01AE02', 220.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('naproxen sodium', 'M01AE02', 275.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('naproxen sodium', 'M01AE02', 550.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('naratriptan (naratriptan hydrochloride)', 'N02CC02', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('naratriptan (naratriptan hydrochloride)', 'N02CC02', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('natalizumab', 'L04AA23', 300.0, 'mg/15ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nateglinide', 'A10BX03', 60.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nateglinide', 'A10BX03', 120.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nedocromil sodium', 'S01GX04', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('neisseria meningitidis outer membrane protein complex', NULL, 125.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nelarabine', 'L01BB07', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nelfinavir (nelfinavir mesylate)', 'J05AE04', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nelfinavir (nelfinavir mesylate)', 'J05AE04', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nelfinavir (nelfinavir mesylate)', 'J05AE04', 625.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('neomycin (neomycin sulfate)', NULL, 1.75, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('neomycin (neomycin sulfate)', NULL, 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('neomycin (neomycin sulfate)', NULL, 3.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('neomycin (neomycin sulfate)', NULL, 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('neomycin (neomycin sulfate)', NULL, 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('neomycin sulfate', NULL, 0.19, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('neomycin sulfate', NULL, 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('neomycin sulfate', NULL, 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('neomycin sulfate', NULL, 3.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('neon', NULL, 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('neostigmine bromide', 'N07AA01', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('neostigmine methylsulfate', 'N07AA01', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('neostigmine methylsulfate', 'N07AA01', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('neostigmine methylsulfate', 'N07AA01', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nepafenac', 'S01BC10', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nesiritide', 'C01DX19', 1.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nevirapine', 'J05AG01', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nickel sulfate', NULL, 0.16, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nicotinamide', 'A11HA01', 1.111, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nicotinamide', 'A11HA01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nicotinamide', 'A11HA01', 8.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nicotinamide', 'A11HA01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nicotinamide', 'A11HA01', 17.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nicotinamide', 'A11HA01', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nicotinamide', 'A11HA01', 75.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nicotinamide', 'A11HA01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nicotine', 'N07BA01', 30.0, 'mg/7sq cm');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nicotinic acid', 'C10AD02', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nicotinic acid', 'C10AD02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nicotinic acid', 'C10AD02', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nicotinic acid', 'C10AD02', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nicotinic acid', 'C10AD02', 750.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nicotinic acid', 'C10AD02', 800.0, 'mg/1.25ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nicotinic acid', 'C10AD02', 1000.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nifedipine', 'C08CA05', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nifedipine', 'C08CA05', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nifedipine', 'C08CA05', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nifedipine', 'C08CA05', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nifedipine', 'C08CA05', 60.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nilotinib (nilotinib hydrochloride monohydrate)', 'L01XE08', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nilutamide', 'L02BB02', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nimodipine', 'C08CA06', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitrazepam', 'N05CD02', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitrazepam', 'N05CD02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitric oxide', 'R07AX01', 100.0, 'ppm');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitric oxide', 'R07AX01', 800.0, 'ppm');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitrofurantoin', 'J01XE01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitrofurantoin', 'J01XE01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitrogen', 'V03AN04', 50.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitrogen', 'V03AN04', 67.7, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitrogen', 'V03AN04', 68.7, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitrogen', 'V03AN04', 68.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitrogen', 'V03AN04', 76.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitrogen', 'V03AN04', 78.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitrogen', 'V03AN04', 80.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitrogen', 'V03AN04', 99.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitrogen', 'V03AN04', 99.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitrogen', 'V03AN04', 100.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitroglycerin', 'C01DA02', 0.3, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitroglycerin', 'C01DA02', 0.4, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitroglycerin', 'C01DA02', 0.6, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitroglycerin', 'C01DA02', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitroglycerin', 'C01DA02', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitroglycerin', 'C01DA02', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitroglycerin', 'C01DA02', 10.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitroglycerin', 'C01DA02', 18.0, 'mg/6.7sq cm');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitroglycerin', 'C01DA02', 20.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitroglycerin', 'C01DA02', 22.4, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitroglycerin', 'C01DA02', 25.0, 'mg/10sq cm');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitroglycerin', 'C01DA02', 36.0, 'mg/13.3sq cm');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitroglycerin', 'C01DA02', 40.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitroglycerin', 'C01DA02', 40.0, 'mg/10sq cm');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitroglycerin', 'C01DA02', 44.8, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitroglycerin', 'C01DA02', 50.0, 'mg/20sq cm');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitroglycerin', 'C01DA02', 54.0, 'mg/20sq cm');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitroglycerin', 'C01DA02', 67.2, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitroglycerin', 'C01DA02', 75.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitroglycerin', 'C01DA02', 80.0, 'mg/20sq cm');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitroglycerin', 'C01DA02', 120.0, 'mg/30sq cm');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitroglycerin', 'C01DA02', 160.0, 'mg/40sq cm');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitrous oxide', 'N01AX13', 50.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitrous oxide', 'N01AX13', 99.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nitrous oxide', 'N01AX13', 100.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nizatidine', 'A02BA04', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nizatidine', 'A02BA04', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('non pollen', 'V01AA20', 0.0, 'nil');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('non pollen', 'V01AA20', 500.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('non pollen', 'V01AA20', 100000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nonyl phenoxypoly ethoxy ethanol-iodine', 'V07AV', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nonyl phenoxypoly ethoxy ethanol-iodine', 'V07AV', 3.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nonyl phenoxypoly ethoxy ethanol-iodine', 'V07AV', 6.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nonyl phenoxypoly ethoxy ethanol-iodine', 'V07AV', 10.59, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nonyl phenoxypoly ethoxy ethanol-iodine', 'V07AV', 18.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nonyl phenoxypoly ethoxy ethanol-iodine complex', NULL, 8.74, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nonylphenoxypoly(ethyleneoxy)ethanol-iodine complex', 'V07AV', 7.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('norelgestromin', NULL, 6.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('norepinephrine (norepinephrine bitartrate)', 'C01CA03', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('norethindrone', 'G03AC01', 0.35, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('norethindrone', 'G03AC01', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('norethindrone', 'G03AC01', 0.75, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('norethindrone', 'G03AC01', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('norethindrone acetate', 'G03DC02', 0.1, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('norethindrone acetate', 'G03DC02', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('norethindrone acetate', 'G03DC02', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('norethindrone acetate', 'G03DC02', 1.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('norethindrone acetate', 'G03DC02', 2.7, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('norethindrone acetate', 'G03DC02', 4.8, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('norethindrone acetate', 'G03DC02', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('norfloxacin', 'J01MA06', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('norgestimate', NULL, 0.18, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('norgestimate', NULL, 0.215, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('norgestimate', NULL, 0.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('norgestrel', NULL, 300.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('normethadone hydrochloride', NULL, 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nortriptyline (nortriptyline hydrochloride)', 'N06AA10', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nortriptyline (nortriptyline hydrochloride)', 'N06AA10', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nortriptyline hydrochloride', 'N06AA10', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nortriptyline hydrochloride', 'N06AA10', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nylidrin hydrochloride', 'C04AA02', 6.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nystatin', 'G01AA01', 100.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nystatin', 'G01AA01', 25000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nystatin', 'G01AA01', 100000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nystatin', 'G01AA01', 100000.0, 'unit/4.5g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('nystatin', 'G01AA01', 500000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('o-phenylphenol', 'V07AV', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('o-phenylphenol', 'V07AV', 0.14, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('o-phenylphenol', 'V07AV', 0.176, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('o-phenylphenol', 'V07AV', 0.199, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('o-phenylphenol', 'V07AV', 0.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('o-phenylphenol', 'V07AV', 0.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('o-phenylphenol', 'V07AV', 0.28, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('o-phenylphenol', 'V07AV', 0.41, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('o-phenylphenol', 'V07AV', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('o-phenylphenol', 'V07AV', 1.11, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('o-phenylphenol', 'V07AV', 1.47, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('o-phenylphenol', 'V07AV', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('o-phenylphenol', 'V07AV', 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('o-phenylphenol', 'V07AV', 3.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('o-phenylphenol', 'V07AV', 3.55, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('o-phenylphenol', 'V07AV', 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('o-phenylphenol', 'V07AV', 4.6, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('o-phenylphenol', 'V07AV', 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('o-phenylphenol', 'V07AV', 7.7, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('o-phenylphenol', 'V07AV', 7.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('o-phenylphenol', 'V07AV', 9.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('o-phenylphenol', 'V07AV', 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('o-phenylphenol', 'V07AV', 12.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('o-phenylphenol', 'V07AV', 12.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oak moss', NULL, 0.07, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octanoic acid', 'V07AV', 0.138, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octanoic acid', 'V07AV', 3.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 1.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 1.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 1.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 1.7, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 2.23, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 2.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 2.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 3.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 3.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 3.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 4.0, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 4.09, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 4.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 4.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 4.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 4.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 4.996, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 5.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 5.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 5.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 5.994, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 6.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 6.0, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 6.32, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 6.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 6.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 6.5, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 6.5, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 6.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 7.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 7.0, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 7.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 7.11, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 7.12, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 7.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 7.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 7.3, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 7.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 7.49, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 7.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 7.5, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 7.5, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 7.505, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 7.511, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 7.75, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 7.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 8.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 8.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 60.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octinoxate', 'D02BA02', 75.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octisalate', NULL, 0.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octisalate', NULL, 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octisalate', NULL, 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octisalate', NULL, 1.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octisalate', NULL, 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octisalate', NULL, 2.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octisalate', NULL, 2.6, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octisalate', NULL, 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octisalate', NULL, 3.0, '%/50ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octisalate', NULL, 3.0, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octisalate', NULL, 3.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octisalate', NULL, 3.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octisalate', NULL, 3.5, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octisalate', NULL, 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octisalate', NULL, 4.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octisalate', NULL, 4.5, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octisalate', NULL, 4.75, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octisalate', NULL, 4.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octisalate', NULL, 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octisalate', NULL, 5.0, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octisalate', NULL, 6.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octisalate', NULL, 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octisalate', NULL, 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 0.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 1.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 1.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 1.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 1.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 1.7, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 1.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 1.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 2.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 2.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 2.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 2.35, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 2.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 2.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 2.6, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 2.7, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 2.7, '%/50ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 2.75, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 2.79, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 2.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 3.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 3.55, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 4.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 4.6, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 5.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 6.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 6.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 7.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 7.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 7.7, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 8.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 8.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 9.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 10.0, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octocrylene', NULL, 12.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octreotide (octreotide acetate)', 'H01CB02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octreotide (octreotide acetate)', 'H01CB02', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octreotide (octreotide acetate)', 'H01CB02', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octreotide (octreotide acetate)', 'H01CB02', 50.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octreotide (octreotide acetate)', 'H01CB02', 100.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octreotide (octreotide acetate)', 'H01CB02', 200.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octreotide (octreotide acetate)', 'H01CB02', 500.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 0.005, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 0.0225, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 0.025, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 0.026, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 0.03, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 0.0399, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 0.054, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 0.08625, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 0.15, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 0.189, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 0.26, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 0.48, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 0.54, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 0.75, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 0.814, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 0.93, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 1.14, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 1.14, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 1.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 1.627, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 1.63, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 1.65, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 1.65, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 1.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 2.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 2.1, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 2.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 2.295, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 2.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 2.4, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 2.64, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 3.075, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 3.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 3.254, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 3.255, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 3.75, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 4.224, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 4.6, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 4.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 6.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 6.51, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 6.51, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('octyl decyl dimethyl ammonium chloride', NULL, 6.912, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ofloxacin', 'S01AX11', 0.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ofloxacin', 'S01AX11', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ofloxacin', 'S01AX11', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ofloxacin', 'S01AX11', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oil of turpentine', NULL, 1.1, 'ml/11ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('olanzapine', 'N05AH03', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('olanzapine', 'N05AH03', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('olanzapine', 'N05AH03', 7.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('olanzapine', 'N05AH03', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('olanzapine', 'N05AH03', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('olanzapine', 'N05AH03', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('olanzapine (olanzapine tartrate)', 'N05AH03', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('olmesartan  medoxomil', 'C09CA08', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('olmesartan  medoxomil', 'C09CA08', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('olopatadine (olopatadine hydrochloride)', 'S01GX09', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('olsalazine sodium', 'A07EC03', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('omalizumab', 'R03DX05', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('omeprazole', 'A02BC01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('omeprazole', 'A02BC01', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('omeprazole (omeprazole magnesium)', 'A02BC01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('omeprazole (omeprazole magnesium)', 'A02BC01', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ondansetron', 'A04AA01', 4.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ondansetron', 'A04AA01', 8.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 4.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 4.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ondansetron (ondansetron hydrochloride dihydrate)', 'A04AA01', 8.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ondansetron (ondansetron hydrochloride)', 'A04AA01', 4.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ondansetron (ondansetron hydrochloride)', 'A04AA01', 8.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('opium', 'A07DA02', 65.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('orciprenaline sulfate', 'R03CB03', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('orlistat', 'A08AB01', 120.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('orphenadrine citrate', 'M03BC01', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('orphenadrine citrate', 'M03BC01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ortho-phthalaldehyde', 'V07AV', 0.55, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ortho-phthalaldehyde', 'V07AV', 5.75, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oseltamivir (oseltamivir phosphate)', 'J05AH02', 12.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oseltamivir (oseltamivir phosphate)', 'J05AH02', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oseltamivir (oseltamivir phosphate)', 'J05AH02', 45.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oseltamivir (oseltamivir phosphate)', 'J05AH02', 75.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxaliplatin', 'L01XA03', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxaliplatin', 'L01XA03', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxaliplatin', 'L01XA03', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxaprozin', 'M01AE12', 600.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxazepam', 'N05BA04', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxazepam', 'N05BA04', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxazepam', 'N05BA04', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxcarbazepine', 'N03AF02', 60.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxcarbazepine', 'N03AF02', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxcarbazepine', 'N03AF02', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxcarbazepine', 'N03AF02', 600.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxetacaine', 'C05AD06', 10.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxtriphylline', 'R03DA02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxtriphylline', 'R03DA02', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxtriphylline', 'R03DA02', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxtriphylline', 'R03DA02', 100.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxtriphylline', 'R03DA02', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxtriphylline', 'R03DA02', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybenzone', NULL, 0.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybenzone', NULL, 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybenzone', NULL, 0.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybenzone', NULL, 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybenzone', NULL, 1.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybenzone', NULL, 1.4, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybenzone', NULL, 1.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybenzone', NULL, 1.75, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybenzone', NULL, 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybenzone', NULL, 2.0, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybenzone', NULL, 2.1, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybenzone', NULL, 2.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybenzone', NULL, 2.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybenzone', NULL, 2.7, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybenzone', NULL, 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybenzone', NULL, 3.0, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybenzone', NULL, 3.002, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybenzone', NULL, 3.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybenzone', NULL, 3.677, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybenzone', NULL, 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybenzone', NULL, 4.0, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybenzone', NULL, 4.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybenzone', NULL, 4.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybenzone', NULL, 4.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybenzone', NULL, 4.5, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybenzone', NULL, 4.7, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybenzone', NULL, 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybenzone', NULL, 5.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybenzone', NULL, 5.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybenzone', NULL, 5.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybenzone', NULL, 5.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybenzone', NULL, 5.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybenzone', NULL, 6.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybutynin', 'G04BD04', 36.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybutynin chloride', 'G04BD04', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybutynin chloride', 'G04BD04', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybutynin chloride', 'G04BD04', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybutynin chloride', 'G04BD04', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxybutynin chloride', 'G04BD04', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxycodone (oxycodone hydrochloride)', NULL, 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxycodone hydrochloride', 'N02AA05', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxycodone hydrochloride', 'N02AA05', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxycodone hydrochloride', 'N02AA05', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxycodone hydrochloride', 'N02AA05', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxycodone hydrochloride', 'N02AA05', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxycodone hydrochloride', 'N02AA05', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxycodone hydrochloride', 'N02AA05', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxycodone hydrochloride', 'N02AA05', 60.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxycodone hydrochloride', 'N02AA05', 80.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxygen', 'V03AN01', 19.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxygen', 'V03AN01', 20.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxygen', 'V03AN01', 21.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxygen', 'V03AN01', 21.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxygen', 'V03AN01', 23.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxygen', 'V03AN01', 24.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxygen', 'V03AN01', 50.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxygen', 'V03AN01', 77.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxygen', 'V03AN01', 88.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxygen', 'V03AN01', 93.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxygen', 'V03AN01', 95.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxygen', 'V03AN01', 99.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxygen', 'V03AN01', 99.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxygen', 'V03AN01', 99.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxygen', 'V03AN01', 99.99, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxygen', 'V03AN01', 100.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxymetazoline hydrochloride', 'S01GA04', 0.025, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxymetazoline hydrochloride', 'S01GA04', 0.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxymetazoline hydrochloride', 'S01GA04', 0.0525, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxymetazoline hydrochloride', 'S01GA04', 0.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxyquinoline sulfate', NULL, 100.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('oxytocin', 'H01BB02', 10.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('p-hydroxyephedrine hydrochloride', NULL, 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('p-phenylenediamine', NULL, 0.073, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('p-tert-butylphenol formaldehyde resin', NULL, 0.041, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('p-tert-pentylphenol', NULL, 0.03, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('p-tert-pentylphenol', NULL, 0.045, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('p-tert-pentylphenol', NULL, 0.046, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('p-tert-pentylphenol', NULL, 0.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('p-tert-pentylphenol', NULL, 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('p-tert-pentylphenol', NULL, 1.7, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('p-tert-pentylphenol', NULL, 1.75, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('p-tert-pentylphenol', NULL, 1.81, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('p-tert-pentylphenol', NULL, 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('p-tert-pentylphenol', NULL, 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('p-tert-pentylphenol', NULL, 4.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('p-tert-pentylphenol', NULL, 7.6, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('p-tert-pentylphenol', NULL, 7.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('paclitaxel', 'L01CD01', 6.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('paclitaxel', 'L01CD01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('paclitaxel (taxus canadensis)', 'L01CD01', 6.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('padimate o', NULL, 1.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('padimate o', NULL, 3.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('padimate o', NULL, 6.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('padimate o', NULL, 6.6, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('padimate o', NULL, 7.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('padimate o', NULL, 8.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('palifermin', 'V03AF08', 6.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('paliperidone', 'N05AX13', 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('paliperidone', 'N05AX13', 6.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('paliperidone', 'N05AX13', 9.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('paliperidone (paliperidone palmitate)', 'N05AX13', 50.0, 'mg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('paliperidone (paliperidone palmitate)', 'N05AX13', 75.0, 'mg/0.75ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('paliperidone (paliperidone palmitate)', 'N05AX13', 100.0, 'mg/1ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('paliperidone (paliperidone palmitate)', 'N05AX13', 150.0, 'mg/1.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('palivizumab', 'J06BB16', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('palivizumab', 'J06BB16', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pamabrom', 'C03BD', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pamabrom', 'C03BD', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pamidronate disodium', 'M05BA03', 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pamidronate disodium', 'M05BA03', 6.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pamidronate disodium', 'M05BA03', 9.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pamidronate disodium', 'M05BA03', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pamidronate disodium', 'M05BA03', 90.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pancreatin', 'A09AA02', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pancreatin', 'A09AA02', 325.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pancuronium bromide', 'M03AC01', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pancuronium bromide', 'M03AC01', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('panitumumab', 'L01XC08', 100.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pantoprazole (pantoprazole magnesium)', 'A02BC02', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pantoprazole (pantoprazole sodium sesquihydrate)', 'A02BC02', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pantoprazole (pantoprazole sodium sesquihydrate)', 'A02BC02', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pantoprazole (pantoprazole sodium)', 'A02BC02', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pantoprazole (pantoprazole sodium)', 'A02BC02', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('papaverine hydrochloride', 'A03AD01', 65.0, 'mg/2ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('parachlorophenol', NULL, 35.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('parachlorophenol', NULL, 300.0, 'mg/1g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('paraformaldehyde', NULL, 2.2, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('paraldehyde', 'N05CC05', 100.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('paromomycin (paromomycin sulfate)', 'A07AA06', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('paroxetine (paroxetine hydrochloride acetone solvate)', 'N06AB05', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('paroxetine (paroxetine hydrochloride acetone solvate)', 'N06AB05', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('paroxetine (paroxetine hydrochloride acetone solvate)', 'N06AB05', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('paroxetine (paroxetine hydrochloride)', 'N06AB05', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('paroxetine (paroxetine hydrochloride)', 'N06AB05', 12.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('paroxetine (paroxetine hydrochloride)', 'N06AB05', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('paroxetine (paroxetine hydrochloride)', 'N06AB05', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('paroxetine (paroxetine hydrochloride)', 'N06AB05', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('paroxetine (paroxetine hydrochloride)', 'N06AB05', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('paroxetine (paroxetine hydrochloride, isopropyl solvate)', 'N06AB05', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('paroxetine (paroxetine hydrochloride, isopropyl solvate)', 'N06AB05', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('paroxetine (paroxetine hydrochloride, isopropyl solvate)', 'N06AB05', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('patent blue sodium', 'V04CX', 50.0, 'mg/2ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pectin', 'A07BC01', 13.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pectin', 'A07BC01', 274.0, 'mg/28.4ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pegaptanib', 'S01LA03', 0.3, 'mg/90µl');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pegfilgrastim', 'L03AA13', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('peginterferon alfa-2a', 'L03AB11', 180.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('peginterferon alfa-2a', 'L03AB11', 180.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('peginterferon alfa-2b', 'L03AB10', 50.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('peginterferon alfa-2b', 'L03AB10', 74.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('peginterferon alfa-2b', 'L03AB10', 80.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('peginterferon alfa-2b', 'L03AB10', 100.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('peginterferon alfa-2b', 'L03AB10', 118.4, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('peginterferon alfa-2b', 'L03AB10', 120.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('peginterferon alfa-2b', 'L03AB10', 150.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('peginterferon alfa-2b', 'L03AB10', 177.6, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('peginterferon alfa-2b', 'L03AB10', 222.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pegvisomant', 'H01AX01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pegvisomant', 'H01AX01', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pegvisomant', 'H01AX01', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pemetrexed (pemetrexed disodium)', 'L01BA04', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pemetrexed (pemetrexed disodium)', 'L01BA04', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('penciclovir', 'D06BB06', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('penghawar', NULL, 3.5, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('penicillin g (penicillin g sodium)', 'J01CE01', 1000000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('penicillin g (penicillin g sodium)', 'J01CE01', 5000000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('penicillin g (penicillin g sodium)', 'J01CE01', 10000000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('penicillin g benzathine', 'J01CE08', 1200000.0, 'unit/2ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('penicillin g sodium', 'J01CE01', 1000000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('penicillin g sodium', 'J01CE01', 5000000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('penicillin g sodium', 'J01CE01', 10000000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('penicillin v (penicillin v potassium)', 'J01CE02', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('penicillin v potassium', 'J01CE02', 200000.0, 'unit/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('penicillin v potassium', 'J01CE02', 500000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('penicillin v potassium', 'J01CE02', 500000.0, 'unit/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pentastarch', 'B05AA07', 10.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pentazocine (pentazocine hydrochloride)', 'N02AD01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pentazocine (pentazocine lactate)', 'N02AD01', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pentosan polysulfate sodium', 'C05BA04', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pentoxifylline', 'C04AD03', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('peracetic acid', 'V07AV', 0.06, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('peracetic acid', 'V07AV', 0.08, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('peracetic acid', 'V07AV', 0.23, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('peracetic acid', 'V07AV', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('peracetic acid', 'V07AV', 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('peracetic acid', 'V07AV', 4.5, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('peracetic acid', 'V07AV', 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('peracetic acid', 'V07AV', 35.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('perflutren', 'V08DA04', 150.0, 'µl');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('periciazine', 'N05AC01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('periciazine', 'N05AC01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('periciazine', 'N05AC01', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('perindopril erbumine', 'C09AA04', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('perindopril erbumine', 'C09AA04', 4.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('perindopril erbumine', 'C09AA04', 8.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('permethrin', 'P03AC04', 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('perphenazine', 'N05AB03', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('perphenazine', 'N05AB03', 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('perphenazine', 'N05AB03', 3.2, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('perphenazine', 'N05AB03', 4.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('perphenazine', 'N05AB03', 8.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('perphenazine', 'N05AB03', 16.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pertactin', NULL, 2.5, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pertactin', NULL, 3.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pertactin', NULL, 8.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pertactin adsorbed', NULL, 2.5, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pertussis toxoid', NULL, 2.5, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pertussis toxoid', NULL, 8.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pertussis toxoid', NULL, 20.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pertussis toxoid', NULL, 25.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pertussis toxoid adsorbed', NULL, 8.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('peruvian balsam', NULL, 0.65, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('petrolatum', 'D02AC', 6.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('petrolatum', 'D02AC', 9.88, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('petrolatum', 'D02AC', 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('petrolatum', 'D02AC', 30.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('petrolatum', 'D02AC', 43.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('petrolatum', 'D02AC', 45.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('petrolatum', 'D02AC', 45.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('petrolatum', 'D02AC', 50.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('petrolatum', 'D02AC', 53.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('petrolatum', 'D02AC', 55.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('petrolatum', 'D02AC', 67.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('petrolatum', 'D02AC', 80.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('petrolatum', 'D02AC', 85.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('petrolatum', 'D02AC', 94.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('petrolatum', 'D02AC', 95.96, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('petrolatum', 'D02AC', 98.79, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('petrolatum', 'D02AC', 100.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('petrolatum', 'D02AC', 1000.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenazopyridine hydrochloride', 'G04BX06', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenazopyridine hydrochloride', 'G04BX06', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenelzine (phenelzine sulfate)', 'N06AF03', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pheniramine maleate', NULL, 0.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pheniramine maleate', NULL, 0.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pheniramine maleate', NULL, 0.315, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pheniramine maleate', NULL, 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pheniramine maleate', NULL, 5.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pheniramine maleate', NULL, 7.5, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pheniramine maleate', NULL, 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pheniramine maleate', NULL, 20.0, 'mg/22g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pheniramine maleate', NULL, 20.0, 'mg/22mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pheniramine maleate', NULL, 20.0, 'mg/23g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenobarbital', 'N03AA02', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenobarbital', 'N03AA02', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenobarbital', 'N03AA02', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenobarbital', 'N03AA02', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenobarbital', 'N03AA02', 60.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenobarbital', 'N03AA02', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenobarbital sodium', 'N03AA02', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenobarbital sodium', 'N03AA02', 120.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenol', 'N01BX03', 0.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenol', 'N01BX03', 0.44, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenol', 'N01BX03', 0.45, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenol', 'N01BX03', 0.48, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenol', 'N01BX03', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenol', 'N01BX03', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenol', 'N01BX03', 6.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenoxyisopropanol', NULL, 0.84, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phentolamine mesylate', 'C04AB01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phentolamine mesylate', 'C04AB01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenyl salicylate', 'G04BX12', 29.0, 'mg/28.4ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenylalanine', NULL, 1.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenylalanine', NULL, 57.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenylalanine', NULL, 380.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenylalanine', NULL, 480.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenylalanine', NULL, 560.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenylalanine', NULL, 620.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenylalanine', NULL, 726.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenylalanine', NULL, 880.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenylephrine (phenylephrine hydrochloride)', 'C01CA06', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenylephrine hydrochloride', 'S01GA05', 0.12, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenylephrine hydrochloride', 'S01GA05', 0.125, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenylephrine hydrochloride', 'S01GA05', 0.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenylephrine hydrochloride', 'S01GA05', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenylephrine hydrochloride', 'S01GA05', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenylephrine hydrochloride', 'S01GA05', 1.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenylephrine hydrochloride', 'S01GA05', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenylephrine hydrochloride', 'S01GA05', 2.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenylephrine hydrochloride', 'S01GA05', 2.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenylephrine hydrochloride', 'S01GA05', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenylephrine hydrochloride', 'S01GA05', 2.5, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenylephrine hydrochloride', 'S01GA05', 3.75, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenylephrine hydrochloride', 'S01GA05', 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenylephrine hydrochloride', 'S01GA05', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenylephrine hydrochloride', 'S01GA05', 5.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenylephrine hydrochloride', 'S01GA05', 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenylephrine hydrochloride', 'S01GA05', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenylephrine hydrochloride', 'S01GA05', 10.0, 'mg/15ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenylephrine hydrochloride', 'S01GA05', 10.0, 'mg/1ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenylephrine hydrochloride', 'S01GA05', 10.0, 'mg/22g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenylephrine hydrochloride', 'S01GA05', 10.0, 'mg/22mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenylephrine hydrochloride', 'S01GA05', 10.0, 'mg/23g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenylephrine hydrochloride', 'S01GA05', 10.0, 'mg/30ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenylephrine hydrochloride', 'S01GA05', 10.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenylephrine hydrochloride', 'S01GA05', 20.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenyltoloxamine', 'Z01AA26', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenyltoloxamine', 'Z01AA26', 10.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenytoin', 'N03AB02', 30.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenytoin', 'N03AB02', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenytoin', 'N03AB02', 125.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenytoin sodium', 'N03AB02', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenytoin sodium', 'N03AB02', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phenytoin sodium', 'N03AB02', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phosphate-buffered saline (diluent)', NULL, 3.0, 'ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phospholipid', NULL, 27.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phosphoric acid', NULL, 6.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phosphoric acid', NULL, 16.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phosphoric acid', NULL, 17.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phosphoric acid', NULL, 20.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phosphoric acid', NULL, 21.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('phosphoric acid', NULL, 30.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pilocarpine hydrochloride', 'S01EB01', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pilocarpine hydrochloride', 'S01EB01', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pilocarpine hydrochloride', 'S01EB01', 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pilocarpine hydrochloride', 'S01EB01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pilocarpine hydrochloride', 'S01EB01', 6.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pilocarpine hydrochloride', 'S01EB01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pilocarpine hydrochloride', 'S01EB01', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pilocarpine hydrochloride', 'S01EB01', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pilocarpine nitrate', 'S01EB01', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pimecrolimus', 'D11AH02', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pimozide', 'N05AG02', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pimozide', 'N05AG02', 4.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pinaverium bromide', 'A03AX04', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pinaverium bromide', 'A03AX04', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pindolol', 'C07AA03', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pindolol', 'C07AA03', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pindolol', 'C07AA03', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pine oil', 'V07AV', 1.87, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pine oil', 'V07AV', 2.5, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pine oil', 'V07AV', 8.7, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pine oil', 'V07AV', 15.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pine tar', NULL, 0.09, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pine tar', NULL, 0.16, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pine tar', NULL, 0.166, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pine tar', NULL, 0.33, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pioglitazone (pioglitazone hydrochloride)', 'A10BG03', 45.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('piperacillin (piperacillin sodium)', 'J01CA12', 2.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('piperacillin (piperacillin sodium)', 'J01CA12', 3.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('piperacillin (piperacillin sodium)', 'J01CA12', 4.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('piperacillin (piperacillin sodium)', 'J01CA12', 12.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('piperazine', 'P02CB01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('piperonyl butoxide', NULL, 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('piperonyl butoxide', NULL, 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pipotiazine palmitate', 'N05AC04', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pipotiazine palmitate', 'N05AC04', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pipradrol hydrochloride', NULL, 0.044, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('piroxicam', 'M01AC01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('piroxicam', 'M01AC01', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pitcher plant', 'M02AX10', 100.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pivmecillinam (pivmecillinam hydrochloride)', 'J01CA08', 185.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pizotifen (pizotifen malate)', 'N02CX01', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pizotifen (pizotifen malate)', 'N02CX01', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('plasmafibronectin (cig)', NULL, 9.0, 'mg/1ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('plasmafibronectin (cig)', NULL, 18.0, 'mg/2ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('plasmafibronectin (cig)', NULL, 45.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('plasminogen', NULL, 120.0, 'µg/1ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('plasminogen', NULL, 240.0, 'µg/2ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('plasminogen', NULL, 600.0, 'µg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pneumococcal polysacc. serot. 18c conjug. to tetanus toxoid carrier prot.', NULL, 3.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pneumococcal polysaccharid serot. 19f conjug. to diphtheria toxoid carrier prot.', NULL, 3.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pneumococcal polysaccharide serotyp 19a', NULL, 2.2, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pneumococcal polysaccharide serotype 1', NULL, 2.2, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pneumococcal polysaccharide serotype 1 conjugated to protein d carrier protein', NULL, 1.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pneumococcal polysaccharide serotype 14', NULL, 2.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pneumococcal polysaccharide serotype 14', NULL, 2.2, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pneumococcal polysaccharide serotype 14 conjugated to protein d carrier protein', NULL, 1.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pneumococcal polysaccharide serotype 18c', NULL, 2.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pneumococcal polysaccharide serotype 18c', NULL, 2.2, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pneumococcal polysaccharide serotype 19f', NULL, 2.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pneumococcal polysaccharide serotype 19f', NULL, 2.2, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pneumococcal polysaccharide serotype 23f', NULL, 2.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pneumococcal polysaccharide serotype 23f', NULL, 2.2, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pneumococcal polysaccharide serotype 23f conjugated to protein d carrier protein', NULL, 1.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pneumococcal polysaccharide serotype 3', NULL, 2.2, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pneumococcal polysaccharide serotype 4', NULL, 2.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pneumococcal polysaccharide serotype 4', NULL, 2.2, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pneumococcal polysaccharide serotype 4 conjugated to protein d carrier protein', NULL, 3.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pneumococcal polysaccharide serotype 5', NULL, 2.2, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pneumococcal polysaccharide serotype 5 conjugated to protein d carrier protein', NULL, 1.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pneumococcal polysaccharide serotype 6a', NULL, 2.2, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pneumococcal polysaccharide serotype 6b', NULL, 4.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pneumococcal polysaccharide serotype 6b', NULL, 4.4, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pneumococcal polysaccharide serotype 6b conjugated to protein d carrier protein', NULL, 1.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pneumococcal polysaccharide serotype 7f', NULL, 2.2, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pneumococcal polysaccharide serotype 7f conjugated to protein d carrier protein', NULL, 1.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pneumococcal polysaccharide serotype 9v', NULL, 2.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pneumococcal polysaccharide serotype 9v', NULL, 2.2, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pneumococcal polysaccharide serotype 9v conjugated to protein d carrier protein', NULL, 1.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pneumococcal vaccine polyvalent', 'J07AL02', 25.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('podophyllin', 'D06BB04', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('podophyllin', 'D06BB04', 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('podophyllin', 'D06BB04', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('podophyllotoxin', 'D06BB04', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('podophyllotoxin', 'D06BB04', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('polistes spp venom protein extract', 'V01AA07', 1.1, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('polistes spp venom protein extract', 'V01AA07', 120.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('polistes spp venom protein extract', 'V01AA07', 1300.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pollen', 'V01AA20', 40000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pollen', 'V01AA20', 100000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pollen and non pollen', 'V01AA20', 20000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('polyaminopropyl biguanide', NULL, 0.000050, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('polyaminopropyl biguanide', NULL, 0.0001, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('polyaminopropyl biguanide', NULL, 0.0005, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('polycarbophil (calcium polycarbophil)', 'A06AC08', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('polyethoxy polypropoxy polyethoxy ethanol - iodine complex', 'V07AV', 9.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('polyethoxy polypropoxy polyethoxy ethanol - iodine complex', 'V07AV', 11.06, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('polyethoxy polypropoxy polyethoxy ethanol - iodine complex', 'V07AV', 25.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('polyethylene glycol 3350', 'A06AD15', 1.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('polyethylene glycol 3350', 'A06AD15', 59.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('polyethylene glycol 3350', 'A06AD15', 59.55, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('polyethylene glycol 3350', 'A06AD15', 100.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('polyethylene glycol 3350', 'A06AD15', 857.69, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('polyethylene glycol 400', NULL, 0.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('polyethylene glycol 400', NULL, 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('polyethylene glycol p-isooctylphenyl ether', NULL, 3.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('polyhexanide', 'S01XA20', 0.0001, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('polymyxin b (polymyxin b sulfate)', NULL, 5000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('polymyxin b (polymyxin b sulfate)', NULL, 10000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('polymyxin b (polymyxin b sulfate)', NULL, 200000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('polymyxin b sulfate', NULL, 6000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('polymyxin b sulfate', NULL, 10000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('polyquaternium-1', NULL, 0.001, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('polysorbate 80', 'S01XA20', 0.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('polysorbate 80', 'S01XA20', 4.86, 'mg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('polyvinyl alcohol', 'S01XA20', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('polyvinyl alcohol', 'S01XA20', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('polyvinyl alcohol', 'S01XA20', 1.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('polyvinyl alcohol', 'S01XA20', 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('polyvinyl alcohol', 'S01XA20', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('porfimer sodium', 'L01XD01', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('porfimer sodium', 'L01XD01', 75.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('posaconazole', 'J02AC04', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium (potassium chloride, potassium citrate)', NULL, 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium acetate', 'B05XA17', 1.28, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium acetate', 'B05XA17', 1.96, 'g/20ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium acetate', 'B05XA17', 128.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium acetate', 'B05XA17', 392.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium acetate', 'B05XA17', 690.0, 'mg/25ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 0.038, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 0.075, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 0.149, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 0.15, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 0.157, 'g/1000ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 0.298, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 0.3, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 0.3, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 0.314, 'g/1000ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 0.37, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 0.398, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 0.74, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 0.75, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 0.76, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 1.193, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 1.49, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 1.5, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 2.0, 'meq');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 2.46, 'g/25ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 2.97, 'g/4l');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 2.98, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 3.05, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 3.35, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 3.355, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 3.36, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 5.02, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 5.03, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 6.7, '0g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 6.7, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 6.71, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 7.46, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 7.46, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 8.39, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 10.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 10.05, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 10.06, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 10.064, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 10.1, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 10.65, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 13.42, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 13.47, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 14.9, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 15.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 20.0, 'meq/10ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 22.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 22.4, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 29.8, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 30.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 37.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 40.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 45.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 74.55, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 75.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 97.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 120.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 149.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 150.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 179.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 205.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 224.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 239.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 251.6, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 300.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 328.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 600.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium chloride', 'B05ZA', 760.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium citrate', 'A12BA02', 540.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium dichromate', NULL, 0.019, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium hydroxide', NULL, 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium iodide', 'R05CA02', 16.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium p-aminobenzoate', 'V03AX', 2.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium p-aminobenzoate', 'V03AX', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium peroxymonosulfate', 'V07AV', 21.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium peroxymonosulfate', 'V07AV', 23.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium peroxymonosulfate', 'V07AV', 34.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium phosphate dibasic', NULL, 130.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium phosphate dibasic', NULL, 130.5, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium phosphate dibasic', NULL, 236.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium phosphate dibasic', NULL, 261.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium phosphate dibasic', NULL, 418.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium phosphate dibasic', NULL, 522.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium phosphate monobasic', 'B05XA06', 6.25, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium phosphate monobasic', 'B05XA06', 34.3905, 'kg/576l');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium phosphate monobasic', 'B05XA06', 100.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium phosphate monobasic', 'B05XA06', 176.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium phosphate monobasic', 'B05XA06', 224.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('potassium phosphate monobasic', 'B05XA06', 820.0, 'µg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('povidone', NULL, 0.6, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('povidone', NULL, 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('povidone', NULL, 6.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 0.125, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 0.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pseudoephedrine hydrochloride', NULL, 120.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pramipexole dihydrochloride monohydrate', 'N04BC05', 1.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pramoxine hydrochloride', 'D04AB07', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pramoxine hydrochloride', 'D04AB07', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pramoxine hydrochloride', 'D04AB07', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pravastatin sodium', 'C10AA03', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pravastatin sodium', 'C10AA03', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pravastatin sodium', 'C10AA03', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('prazosin (prazosin hydrochloride)', 'C02CA01', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('prazosin (prazosin hydrochloride)', 'C02CA01', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('prazosin (prazosin hydrochloride)', 'C02CA01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('prazosin hydrochloride', 'C02CA01', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('prazosin hydrochloride', 'C02CA01', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('prazosin hydrochloride', 'C02CA01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('prednicarbate', 'D07AC18', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('prednisolone (prednisolone sodium phosphate)', 'H02AB06', 5.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('prednisolone acetate', 'S01BA04', 0.12, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('prednisolone acetate', 'S01BA04', 0.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('prednisolone acetate', 'S01BA04', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('prednisolone acetate', 'S01BA04', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('prednisolone acetate', 'S01BA04', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('prednisolone sodium phosphate', 'S01BA04', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('prednisolone sodium phosphate', 'S01BA04', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('prednisone', 'H02AB07', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('prednisone', 'H02AB07', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('prednisone', 'H02AB07', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pregabalin', 'N03AX16', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pregabalin', 'N03AX16', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pregabalin', 'N03AX16', 75.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pregabalin', 'N03AX16', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pregabalin', 'N03AX16', 225.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pregabalin', 'N03AX16', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('prilocaine', 'N01BB04', 2.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('prilocaine', 'N01BB04', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('prilocaine hydrochloride', 'N01BB04', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('primaquine phosphate', 'P01BA03', 26.3, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('primidone', 'N03AA03', 125.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('primidone', 'N03AA03', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('probenecid', 'M04AB01', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('procainamide hydrochloride', 'C01BA02', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('procainamide hydrochloride', 'C01BA02', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('procainamide hydrochloride', 'C01BA02', 375.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('procainamide hydrochloride', 'C01BA02', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('procainamide hydrochloride', 'C01BA02', 750.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('procaine hydrochloride', 'N01BA02', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('procarbazine (procarbazine hydrochloride)', 'L01XB01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('prochlorperazine', 'N05AB04', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('prochlorperazine (prochlorperazine maleate)', 'N05AB04', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('prochlorperazine (prochlorperazine maleate)', 'N05AB04', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('prochlorperazine (prochlorperazine mesylate)', 'N05AB04', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('procyclidine hydrochloride', 'N04AA04', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('procyclidine hydrochloride', 'N04AA04', 2.5, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('procyclidine hydrochloride', 'N04AA04', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('progesterone', 'G03DA04', 8.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('progesterone', 'G03DA04', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('progesterone', 'G03DA04', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('proguanil hydrochloride', NULL, 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('proguanil hydrochloride', NULL, 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('proline', NULL, 1.34, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('proline', NULL, 59.5, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('proline', NULL, 420.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('proline', NULL, 680.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('proline', NULL, 750.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('proline', NULL, 950.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('promethazine (promethazine hydrochloride)', 'R06AD02', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('promethazine hydrochloride', 'R06AD02', 10.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('promethazine hydrochloride', 'R06AD02', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('promethazine hydrochloride', 'R06AD02', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('propafenone hydrochloride', 'C01BC03', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('propafenone hydrochloride', 'C01BC03', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('propofol', 'N01AX10', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('propofol', 'N01AX10', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('propranolol hydrochloride', 'C07AA05', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('propranolol hydrochloride', 'C07AA05', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('propranolol hydrochloride', 'C07AA05', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('propranolol hydrochloride', 'C07AA05', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('propranolol hydrochloride', 'C07AA05', 60.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('propranolol hydrochloride', 'C07AA05', 80.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('propranolol hydrochloride', 'C07AA05', 120.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('propranolol hydrochloride', 'C07AA05', 160.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('propyl alcohol', NULL, 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('propyl alcohol', NULL, 15.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('propyl alcohol', NULL, 32.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('propylene glycol', NULL, 0.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('propylene glycol', NULL, 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('propylene glycol', NULL, 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('propylene glycol', NULL, 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('propylene glycol', NULL, 5.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('propylene glycol', NULL, 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('propylene glycol', NULL, 20.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('propylene glycol', NULL, 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('propylene glycol', NULL, 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('propylparaben', NULL, 0.16, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('propylthiouracil', 'H03BA02', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('propylthiouracil', 'H03BA02', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('protamine sulfate', 'V03AB14', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('protease', NULL, 11000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('protease', NULL, 18750.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('protease', NULL, 25000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('protease', NULL, 30000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('protease', NULL, 37500.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('protease', NULL, 39000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('protease', NULL, 55000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('protease', NULL, 60000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('protease', NULL, 62500.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('protease', NULL, 65000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('protease', NULL, 75000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('protease', NULL, 104000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('protein c', 'B01AD12', 620.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('protein s', NULL, 640.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('protirelin', 'V04CJ02', 200.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('proxymetacaine hydrochloride', 'S01HA04', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pseudoephedrine hydrochloride', NULL, 7.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pseudoephedrine hydrochloride', NULL, 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pseudoephedrine hydrochloride', NULL, 15.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pseudoephedrine hydrochloride', NULL, 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pseudoephedrine hydrochloride', NULL, 30.0, 'mg/15ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pseudoephedrine hydrochloride', NULL, 30.0, 'mg/30ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pseudoephedrine hydrochloride', NULL, 30.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pseudoephedrine hydrochloride', NULL, 60.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pseudoephedrine hydrochloride', NULL, 60.0, 'mg/20ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pseudoephedrine hydrochloride', NULL, 60.0, 'mg/24g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pseudoephedrine hydrochloride', NULL, 60.0, 'mg/30ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pseudoephedrine sulfate', NULL, 30.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pseudoephedrine sulfate', NULL, 60.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pseudoephedrine sulfate', NULL, 120.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pseudoephedrine sulfate', NULL, 240.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('purified protein derivative of tuberculin', 'V04CF01', 5.0, 'tub/0.1ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pyrantel (pyrantel pamoate)', 'P02CC01', 35.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pyrantel (pyrantel pamoate)', 'P02CC01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pyrantel (pyrantel pamoate)', 'P02CC01', 125.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pyrazinamide', 'J04AK01', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pyrazinamide', 'J04AK01', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pyrethrins', NULL, 0.33, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pyrethrum', 'P03AC01', 0.33, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pyridostigmine bromide', 'N07AA02', 60.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pyridostigmine bromide', 'N07AA02', 180.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pyridoxine hydrochloride', 'A11HA02', 0.042, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pyridoxine hydrochloride', 'A11HA02', 0.8, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pyridoxine hydrochloride', 'A11HA02', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pyridoxine hydrochloride', 'A11HA02', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pyridoxine hydrochloride', 'A11HA02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pyridoxine hydrochloride', 'A11HA02', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pyridoxine hydrochloride', 'A11HA02', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pyrilamine maleate', NULL, 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pyrilamine maleate', NULL, 1.2, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pyrilamine maleate', NULL, 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pyrilamine maleate', NULL, 10.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pyrilamine maleate', NULL, 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pyrimethamine', 'P01BD01', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pyrithione disulfide', NULL, 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pyrithione zinc', 'D11AX12', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pyrithione zinc', 'D11AX12', 0.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pyrithione zinc', 'D11AX12', 0.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pyrithione zinc', 'D11AX12', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pyrithione zinc', 'D11AX12', 0.95, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pyrithione zinc', 'D11AX12', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pyrithione zinc', 'D11AX12', 1.0, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pyrithione zinc', 'D11AX12', 1.008, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pyrithione zinc', 'D11AX12', 1.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pyrithione zinc', 'D11AX12', 1.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pyrithione zinc', 'D11AX12', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pyrithione zinc', 'D11AX12', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('pazopanib (pazopanib hydrochloride)', 'L01XE11', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('prasugrel (prasugrel hydrochloride)', 'B01AC22', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('quaternium-15', NULL, 0.081, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('quetiapine (quetiapine fumarate)', 'N05AH04', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('quinagolide (quinagolide hydrochloride)', 'G02CB04', 0.025, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('quinagolide (quinagolide hydrochloride)', 'G02CB04', 0.05, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('quinagolide (quinagolide hydrochloride)', 'G02CB04', 0.075, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('quinagolide (quinagolide hydrochloride)', 'G02CB04', 0.15, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('quinapril (quinapril hydrochloride)', 'C09AA06', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('quinapril (quinapril hydrochloride)', 'C09AA06', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('quinapril (quinapril hydrochloride)', 'C09AA06', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('quinapril (quinapril hydrochloride)', 'C09AA06', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('quinidine sulfate', 'C01BA01', 190.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('quinine sulfate', 'P01BC01', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('quinine sulfate', 'P01BC01', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rabeprazole sodium', 'A02BC04', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rabeprazole sodium', 'A02BC04', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rabies immune globulin human', 'J06BB05', 150.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rabies vaccine inactivated (human diploid-cell culture)', 'J07BG01', 2.5, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rabies vaccine inactivated (purified chick embryo cell culture)', 'J07BG01', 2.5, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('raloxifene hydrochloride', 'G03XC01', 60.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('raltegravir (raltegravir potassium)', 'J05AX08', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('raltitrexed (raltitrexed disodium)', 'L01BA03', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ramipril', 'C09AA05', 1.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ramipril', 'C09AA05', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ramipril', 'C09AA05', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ramipril', 'C09AA05', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ramipril', 'C09AA05', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ranibizumab', 'S01LA04', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 75.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ranitidine (ranitidine hydrochloride)', 'A02BA02', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ranitidine hydrochloride', 'A02BA02', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rasagiline (rasagiline mesylate)', 'N04BD02', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rasagiline (rasagiline mesylate)', 'N04BD02', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rasburicase', 'V03AF07', 1.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('recombinant cholera toxin b subunit', NULL, 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('recombinant human papillomavirus type 11 l1 protein', NULL, 40.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('recombinant human papillomavirus type 16 l1 protein', NULL, 20.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('recombinant human papillomavirus type 16 l1 protein', NULL, 40.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('recombinant human papillomavirus type 18 l1 protein', NULL, 20.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('recombinant human papillomavirus type 6 l1 protein', NULL, 20.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('remifentanil (remifentanil hydrochloride)', 'N01AH06', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('remifentanil (remifentanil hydrochloride)', 'N01AH06', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('remifentanil (remifentanil hydrochloride)', 'N01AH06', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('repaglinide', 'A10BX02', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('repaglinide', 'A10BX02', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('repaglinide', 'A10BX02', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('resorcinol', 'D10AX02', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('reteplase', 'B01AD07', 10.4, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rho d immune globulin human', 'J06BB01', 600.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rho d immune globulin human', 'J06BB01', 1500.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rho d immune globulin human', 'J06BB01', 5000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ribavirin', 'J05AB04', 6.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ribavirin', 'J05AB04', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rifabutin', 'J04AB04', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rifampin', 'J04AB02', 120.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rifampin', 'J04AB02', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rifampin', 'J04AB02', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('riluzole', 'N07XX02', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rimexolone', 'S01BA13', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('risedronate sodium', NULL, 35.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('risedronate sodium (risedronate sodium hemi-pentahydrate)', 'M05BA07', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('risedronate sodium (risedronate sodium hemi-pentahydrate)', 'M05BA07', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('risedronate sodium (risedronate sodium hemi-pentahydrate)', 'M05BA07', 35.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('risedronate sodium (risedronate sodium hemi-pentahydrate)', 'M05BA07', 75.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('risedronate sodium (risedronate sodium hemi-pentahydrate)', 'M05BA07', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('risedronate sodium (risedronate sodium monohydrate)', 'M05BA07', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('risedronate sodium (risedronate sodium monohydrate)', 'M05BA07', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('risedronate sodium (risedronate sodium monohydrate)', 'M05BA07', 35.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('risperidone', 'N05AX08', 0.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('risperidone', 'N05AX08', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('risperidone', 'N05AX08', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('risperidone', 'N05AX08', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('risperidone', 'N05AX08', 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('risperidone', 'N05AX08', 4.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('risperidone', 'N05AX08', 12.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('risperidone', 'N05AX08', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('risperidone', 'N05AX08', 37.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('risperidone', 'N05AX08', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('risperidone (risperidone tartrate)', 'N05AX08', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ritonavir', 'J05AE03', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ritonavir', 'J05AE03', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ritonavir', 'J05AE03', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ritonavir', 'J05AE03', 80.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ritonavir', 'J05AE03', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rituximab', 'L01XC02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rivaroxaban', 'B01AX06', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rivastigmine', 'N06DA03', 9.0, 'mg/5sq cm');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rivastigmine', 'N06DA03', 18.0, 'mg/10sq cm');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rivastigmine (rivastigmine hydrogen tartrate)', 'N06DA03', 1.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rivastigmine (rivastigmine hydrogen tartrate)', 'N06DA03', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rivastigmine (rivastigmine hydrogen tartrate)', 'N06DA03', 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rivastigmine (rivastigmine hydrogen tartrate)', 'N06DA03', 4.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rivastigmine (rivastigmine hydrogen tartrate)', 'N06DA03', 6.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rizatriptan (rizatriptan benzoate)', 'N02CC04', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rizatriptan (rizatriptan benzoate)', 'N02CC04', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rocuronium bromide', 'M03AC09', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('romiplostim', 'B02BX04', 250.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('romiplostim', 'B02BX04', 500.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ropinirole (ropinirole hydrochloride)', 'N04BC04', 0.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ropinirole (ropinirole hydrochloride)', 'N04BC04', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ropinirole (ropinirole hydrochloride)', 'N04BC04', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ropinirole (ropinirole hydrochloride)', 'N04BC04', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ropivacaine hydrochloride', 'N01BB09', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ropivacaine hydrochloride', 'N01BB09', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ropivacaine hydrochloride', 'N01BB09', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rose bengal', 'S01JA02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rosiglitazone (rosiglitazone maleate)', 'A10BG02', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rosiglitazone (rosiglitazone maleate)', 'A10BG02', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rosiglitazone (rosiglitazone maleate)', 'A10BG02', 4.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rosiglitazone (rosiglitazone maleate)', 'A10BG02', 8.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rosin', NULL, 0.69, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rosuvastatin (rosuvastatin calcium)', 'C10AA07', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rosuvastatin (rosuvastatin calcium)', 'C10AA07', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rosuvastatin (rosuvastatin calcium)', 'C10AA07', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rosuvastatin (rosuvastatin calcium)', 'C10AA07', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rotavirus vaccine (rix4414 strain), live, oral, attenuated (human)', 'J07BH01', 10000000.0, 'ccid50');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rotavirus vaccine, live, oral, type g1 (human)', NULL, 2210000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rotavirus vaccine, live, oral, type g2 (human)', NULL, 2840000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rotavirus vaccine, live, oral, type g3 (human)', NULL, 2220000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rotavirus vaccine, live, oral, type g4 (human)', NULL, 2040000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rotavirus vaccine, live, oral, type p1(8) (human)', NULL, 2290000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rubella virus vaccine live attenuated wistar ra27/3 strain', NULL, 1.0, 'dose');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('rubella virus vaccine live attenuated wistar ra27/3 strain', NULL, 1000.0, 'unit/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('safflower oil', NULL, 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('safflower oil', NULL, 5.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('safflower oil', NULL, 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('salbutamol', 'R03AC02', 2.5, 'mg/2.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('salbutamol', 'R03AC02', 100.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('salbutamol (salbutamol sulfate)', 'R03CC02', 0.4, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('salbutamol (salbutamol sulfate)', 'R03CC02', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('salbutamol (salbutamol sulfate)', 'R03CC02', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('salbutamol (salbutamol sulfate)', 'R03CC02', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('salbutamol (salbutamol sulfate)', 'R03CC02', 2.5, 'mg/2.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('salbutamol (salbutamol sulfate)', 'R03CC02', 4.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('salbutamol (salbutamol sulfate)', 'R03CC02', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('salbutamol (salbutamol sulfate)', 'R03CC02', 5.0, 'mg/2.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('salbutamol (salbutamol sulfate)', 'R03CC02', 100.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('salbutamol (salbutamol sulfate)', 'R03CC02', 200.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('salicylic acid', 'V07AV', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('salicylic acid', 'V07AV', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('salicylic acid', 'V07AV', 1.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('salicylic acid', 'V07AV', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('salicylic acid', 'V07AV', 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('salicylic acid', 'V07AV', 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('salicylic acid', 'V07AV', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('salicylic acid', 'V07AV', 30.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('salicylic acid', 'V07AV', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('salmeterol (salmeterol xinafoate)', 'R03AC12', 25.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('salmeterol (salmeterol xinafoate)', 'R03AC12', 50.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('salmonella typhi vi capsular polysaccharide vaccine', 'J07AP03', 25.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sapropterin dihydrochloride', 'A16AX07', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('saquinavir (saquinavir mesylate)', 'J05AE01', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('saquinavir (saquinavir mesylate)', 'J05AE01', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('saxagliptin (saxagliptin hydrochloride)', 'A10BH03', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('scopolamine hydrobromide', 'N05CM05', 0.4, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('scopolamine hydrobromide', 'N05CM05', 0.6, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('selegiline hydrochloride', 'N04BD01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('selenium (selenious acid)', 'A12CX', 20.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('selenium (selenious acid)', 'A12CX', 40.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('selenium (selenious acid)', 'A12CX', 60.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('selenium (selenium hvp chelate)', NULL, 25.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('senega', 'R05CA06', 0.566, 'mg/1ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('senna', NULL, 187.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sennosides', NULL, 8.6, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('serine', NULL, 1.02, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('serine', NULL, 51.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('serine', NULL, 125.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('serine', NULL, 185.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('serine', NULL, 186.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('serine', NULL, 210.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('serine', NULL, 212.5, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('serine', NULL, 225.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('serine', NULL, 250.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('serine', NULL, 265.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('serine', NULL, 300.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('serine', NULL, 347.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('serine', NULL, 370.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('serine', NULL, 371.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('serine', NULL, 400.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('serine', NULL, 420.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('serine', NULL, 450.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('serine', NULL, 495.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('serine', NULL, 500.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('serine', NULL, 530.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('serine', NULL, 795.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sertraline (sertraline hydrochloride)', 'N06AB06', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sevelamer hydrochloride', 'V03AE02', 800.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sevoflurane', 'N01AB08', 99.97, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('shark liver oil', NULL, 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sildenafil (sildenafil citrate)', 'G04BE03', 0.8, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sildenafil (sildenafil citrate)', 'G04BE03', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sildenafil (sildenafil citrate)', 'G04BE03', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sildenafil (sildenafil citrate)', 'G04BE03', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sildenafil (sildenafil citrate)', 'G04BE03', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('silicone', 'D02AA', 20.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('silver (silver gluconate)', NULL, 0.06, 'mg/2ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('silver sulfadiazine', 'D06BA01', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('simethicone', 'A03AX13', 20.0, 'mg/0.3ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('simethicone', 'A03AX13', 20.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('simethicone', 'A03AX13', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('simethicone', 'A03AX13', 25.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('simethicone', 'A03AX13', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('simethicone', 'A03AX13', 40.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('simethicone', 'A03AX13', 51.2, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('simethicone', 'A03AX13', 60.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('simethicone', 'A03AX13', 62.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('simethicone', 'A03AX13', 80.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('simethicone', 'A03AX13', 125.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('simethicone', 'A03AX13', 166.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('simethicone', 'A03AX13', 180.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('simvastatin', 'C10AA01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('simvastatin', 'C10AA01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('simvastatin', 'C10AA01', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('simvastatin', 'C10AA01', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('simvastatin', 'C10AA01', 80.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sincalide', 'V04CC03', 5.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sirolimus', 'L04AA10', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sitagliptin (sitagliptin phosphate monohydrate)', 'A10BH01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sitagliptin (sitagliptin phosphate monohydrate)', 'A10BH01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sitaxsentan sodium', 'C02KX03', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium acetate', 'B05XA08', 0.39, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium acetate', 'B05XA08', 2.22, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium acetate', 'B05XA08', 2.36, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium acetate', 'B05XA08', 2.72, 'g/25ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium acetate', 'B05XA08', 3.9, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium acetate', 'B05XA08', 13.6, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium acetate', 'B05XA08', 16.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium acetate', 'B05XA08', 121.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium acetate', 'B05XA08', 170.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium acetate', 'B05XA08', 220.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium acetate', 'B05XA08', 280.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium acetate', 'B05XA08', 295.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium acetate', 'B05XA08', 297.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium acetate', 'B05XA08', 328.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium acetate', 'B05XA08', 330.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium acetate', 'B05XA08', 340.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium acetate', 'B05XA08', 368.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium acetate', 'B05XA08', 370.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium acetate', 'B05XA08', 680.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium acetate', 'B05XA08', 680.0, 'mg/20ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium acetate trihydrate', NULL, 0.39, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium alkyl polyether sulfate', NULL, 6.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium ascorbate', 'A11GA01', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium bicarbonate', 'B05ZA', 0.21, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium bicarbonate', 'B05ZA', 1.68, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium bicarbonate', 'B05ZA', 1.69, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium bicarbonate', 'B05ZA', 1.916, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium bicarbonate', 'B05ZA', 3.09, 'g/1000ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium bicarbonate', 'B05ZA', 3.29, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium bicarbonate', 'B05ZA', 4.6, 'g/2tsp');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium bicarbonate', 'B05ZA', 5.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium bicarbonate', 'B05ZA', 6.0, 'kg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium bicarbonate', 'B05ZA', 6.74, 'g/4l');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium bicarbonate', 'B05ZA', 6.76, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium bicarbonate', 'B05ZA', 12.9, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium bicarbonate', 'B05ZA', 24.02, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium bicarbonate', 'B05ZA', 28.35, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium bicarbonate', 'B05ZA', 39.7, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium bicarbonate', 'B05ZA', 42.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium bicarbonate', 'B05ZA', 58.8, 'g/1000ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium bicarbonate', 'B05ZA', 75.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium bicarbonate', 'B05ZA', 80.7, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium bicarbonate', 'B05ZA', 81.25, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium bicarbonate', 'B05ZA', 81.3, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium bicarbonate', 'B05ZA', 84.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium bicarbonate', 'B05ZA', 650.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium bicarbonate', 'B05ZA', 650.0, 'g/8l');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium bicarbonate', 'B05ZA', 1700.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium bisulfite', NULL, 40.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium carbonate (anhydrous)', NULL, 1.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium carbonate (anhydrous)', NULL, 1.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium carbonate (anhydrous)', NULL, 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium carbonate (anhydrous)', NULL, 2.2, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium carbonate (anhydrous)', NULL, 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium carbonate (anhydrous)', NULL, 3.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium carbonate (anhydrous)', NULL, 4.3, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium carbonate (anhydrous)', NULL, 430.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium carboxymethyl cellulose', 'S01XA20', 0.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium carboxymethyl cellulose', 'S01XA20', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium carboxymethyl cellulose', 'S01XA20', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium carboxymethyl cellulose', 'S01XA20', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium carboxymethyl cellulose', 'S01XA20', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium carboxymethyl cellulose', 'S01XA20', 13.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 0.45, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 0.64, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 0.714, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 0.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 0.9, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 1.17, 'g/20ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 1.46, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 1.6, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 2.0, 'ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 2.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 2.34, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 3.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 4.4, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 4.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 5.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 5.0, 'ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 5.26, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 5.38, 'g/1000ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 5.4, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 5.64, '0g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 5.844, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 5.85, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 5.86, 'g/4l');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 5.961, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 6.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 6.4, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 6.43, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 6.449, 'g/1000ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 6.45, '0g/1000ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 6.45, 'g/1000ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 7.31, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 7.66, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 8.43, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 8.6, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 9.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 12.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 16.05, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 20.87, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 23.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 29.3, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 58.5, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 73.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 77.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 82.84, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 88.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 90.73, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 91.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 115.0, 'ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 117.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 120.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 140.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 146.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 200.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 205.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 234.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 234.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 262.98, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 262.99, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 263.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 268.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 268.24, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 273.5, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 275.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 276.1, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 289.3, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 300.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 330.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 374.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 410.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 450.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 526.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 530.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 538.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 562.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 567.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 600.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 800.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 860.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chloride', 'V07AB', 900.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chlorite', NULL, 20.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium chlorite', NULL, 30.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium citrate', 'V07AC', 0.17, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium citrate', 'V07AC', 1.32, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium citrate', 'V07AC', 1.49, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium citrate', 'V07AC', 1.66, 'g/63ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium citrate', 'V07AC', 1.7, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium citrate', 'V07AC', 2.2, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium citrate', 'V07AC', 4.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium citrate', 'V07AC', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium citrate', 'V07AC', 90.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium citrate dihydrate', NULL, 0.17, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium dichloroisocyanurate', 'V07AV', 1.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium dichloroisocyanurate', 'V07AV', 2.5, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium dichloroisocyanurate', 'V07AV', 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium dichloroisocyanurate', 'V07AV', 5.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium dichloroisocyanurate', 'V07AV', 7.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium dichloroisocyanurate', 'V07AV', 25.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium dichloroisocyanurate', 'V07AV', 26.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium dichloroisocyanurate', 'V07AV', 55.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium dichloroisocyanurate', 'V07AV', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium dodecylbenzenesulfonate', NULL, 2.028, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium dodecylbenzenesulfonate', NULL, 2.75, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium fluoride', 'A01AA01', 0.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium fluoride', 'A01AA01', 0.243, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium gluconate', NULL, 1.09, 'g/25ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium gluconate', NULL, 5.02, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium gluconate', NULL, 500.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium gluconate', NULL, 502.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium hydroxide', 'V07AV', 0.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium hydroxide', 'V07AV', 0.34, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium hypochlorite', 'V07AV', 0.025, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium hypochlorite', 'V07AV', 0.057, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium hypochlorite', 'V07AV', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium hypochlorite', 'V07AV', 0.114, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium hypochlorite', 'V07AV', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium hypochlorite', 'V07AV', 0.525, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium hypochlorite', 'V07AV', 0.55, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium hypochlorite', 'V07AV', 0.6, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium hypochlorite', 'V07AV', 0.7, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium hypochlorite', 'V07AV', 0.75, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium hypochlorite', 'V07AV', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium hypochlorite', 'V07AV', 1.15, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium hypochlorite', 'V07AV', 1.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium hypochlorite', 'V07AV', 1.45, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium hypochlorite', 'V07AV', 1.84, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium hypochlorite', 'V07AV', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium hypochlorite', 'V07AV', 2.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium hypochlorite', 'V07AV', 2.73, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium hypochlorite', 'V07AV', 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium hypochlorite', 'V07AV', 3.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium hypochlorite', 'V07AV', 5.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium hypochlorite', 'V07AV', 5.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium hypochlorite', 'V07AV', 5.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium hypochlorite', 'V07AV', 6.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium hypochlorite', 'V07AV', 6.15, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium hypochlorite', 'V07AV', 7.2, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium hypochlorite', 'V07AV', 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium hypochlorite', 'V07AV', 10.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium hypochlorite', 'V07AV', 10.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium hypochlorite', 'V07AV', 10.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium hypochlorite', 'V07AV', 10.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium hypochlorite', 'V07AV', 12.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium iodide', NULL, 90.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium ioxitalamate', NULL, 255.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium lactate', NULL, 1.6, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium lactate', NULL, 2.63, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium lactate', NULL, 3.1, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium lactate', NULL, 3.925, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium lactate', NULL, 4.483, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium lactate', NULL, 4.5, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium lactate', NULL, 4.72, 'g/1000ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium lactate', NULL, 160.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium lactate', NULL, 220.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium lactate', NULL, 310.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium lactate', NULL, 392.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium lactate', NULL, 448.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium lauryl ether sulfate', NULL, 6.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium lauryl sulfoacetate', NULL, 9.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium metasilicate', NULL, 0.58, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium metasilicate', NULL, 2.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium nitroprusside', 'C02DD01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium ortho-phenylphenate', NULL, 3.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium oxybate', 'N07XX04', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium perborate', 'A01AB19', 30.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium perborate monohydrate', NULL, 29.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium phosphate (tribasic)', 'V07AV', 1.19, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium phosphate dibasic', NULL, 0.042, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium phosphate dibasic', NULL, 7.58, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium phosphate dibasic', NULL, 8.75, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium phosphate dibasic', NULL, 12.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium phosphate dibasic', NULL, 35.69575, 'kg/576l');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium phosphate dibasic', NULL, 49.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium phosphate dibasic', NULL, 124.2, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium phosphate dibasic', NULL, 268.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium phosphate dibasic', NULL, 410.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium phosphate dibasic', NULL, 430.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium phosphate monobasic', NULL, 1.81, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium phosphate monobasic', NULL, 51.7, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium phosphate monobasic', NULL, 140.0, 'mg/63ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium phosphate monobasic', NULL, 276.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium picosulfate', 'A06AB08', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium polystyrene sulfonate', 'V03AE01', 94.3, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium polystyrene sulfonate', 'V03AE01', 100.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium polystyrene sulfonate', 'V03AE01', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium salicylate', 'N02BA04', 56.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium salicylate', 'N02BA04', 570.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium sulfate', 'A06AD13', 5.68, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium sulfate', 'A06AD13', 5.74, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium sulfate', 'A06AD13', 22.74, 'g/4l');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium sulfate', 'A06AD13', 22.96, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium sulfate', 'A06AD13', 81.2, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium tetradecyl sulfate', 'C05BB04', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium tetradecyl sulfate', 'C05BB04', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium thiosulfate', 'V03AB06', 8.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium thiosulfate', 'V03AB06', 25.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sodium tripolyphosphate', NULL, 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('solifenacin succinate', 'G04BD08', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('solifenacin succinate', 'G04BD08', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('somatostatin (somatostatin acetate)', 'H01CB01', 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('somatostatin (somatostatin acetate)', 'H01CB01', 250.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('somatropin', 'H01AC01', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('somatropin', 'H01AC01', 3.3, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('somatropin', 'H01AC01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('somatropin', 'H01AC01', 5.0, 'mg/1.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('somatropin', 'H01AC01', 6.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('somatropin', 'H01AC01', 8.8, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('somatropin', 'H01AC01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('somatropin', 'H01AC01', 10.0, 'mg/1.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('somatropin', 'H01AC01', 10.0, 'mg/2ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('somatropin', 'H01AC01', 12.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('somatropin', 'H01AC01', 15.0, 'mg/1.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('somatropin', 'H01AC01', 24.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sorafenib (sorafenib tosylate)', 'L01XE05', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sorbitol', 'A06AD18', 2.5, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sorbitol', 'A06AD18', 27.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sorbitol', 'A06AD18', 625.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sotalol hydrochloride', 'C07AA07', 80.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sotalol hydrochloride', 'C07AA07', 160.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sotalol hydrochloride', 'C07AA07', 240.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('soybean oil', NULL, 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('soybean oil', NULL, 5.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('soybean oil', NULL, 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('soybean oil', NULL, 10.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('soybean oil', NULL, 20.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('soybean oil', NULL, 30.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('spiramycin', 'J01FA02', 750000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('spiramycin', 'J01FA02', 1500000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('spironolactone', 'C03DA01', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('spironolactone', 'C03DA01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('spironolactone', 'C03DA01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('squalene', NULL, 10.69, 'mg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('squill', NULL, 0.566, 'mg/1ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('standardized cat hair acetone precipitated', 'V01AA11', 10000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('standardized cat pelt', 'V01AA11', 10000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('standardized cat pelt acetone precipitated', 'V01AA11', 10000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('standardized june grass pollen', 'V01AA02', 20000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('standardized june grass pollen', 'V01AA02', 100000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('standardized meadow fescue grass pollen', 'V01AA02', 10000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('standardized meadow fescue grass pollen', 'V01AA02', 100000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('standardized orchard grass pollen', 'V01AA02', 10000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('standardized orchard grass pollen', 'V01AA02', 20000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('standardized orchard grass pollen', 'V01AA02', 100000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('standardized perennial rye grass pollen', 'V01AA02', 10000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('standardized perennial rye grass pollen', 'V01AA02', 100000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('standardized redtop grass pollen', 'V01AA02', 10000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('standardized redtop grass pollen', 'V01AA02', 20000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('standardized redtop grass pollen', 'V01AA02', 100000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('standardized sweet vernal grass pollen', 'V01AA02', 20000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('standardized sweet vernal grass pollen', 'V01AA02', 100000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('standardized timothy grass pollen', 'V01AA02', 10000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('standardized timothy grass pollen', 'V01AA02', 20000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('standardized timothy grass pollen', 'V01AA02', 100000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('stavudine', 'J05AF04', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('stavudine', 'J05AF04', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('stavudine', 'J05AF04', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('stavudine', 'J05AF04', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('storax', NULL, 8.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('streptokinase', 'B01AD01', 250000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('streptokinase', 'B01AD01', 750000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('streptokinase', 'B01AD01', 1500000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('streptomycin (streptomycin sulfate)', 'J01GA01', 1.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('streptozocin', 'L01AD04', 1.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('substituted phenols', NULL, 6.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('succinylcholine chloride', 'M03AB01', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('succinylcholine chloride', 'M03AB01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sucralfate', 'A02BX02', 1.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sucralfate', 'A02BX02', 1.0, 'g/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sucralfate', 'A02BX02', 1000.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sufentanil (sufentanil citrate)', 'N01AH03', 50.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sulfacetamide sodium', 'S01AB04', 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sulfacetamide sodium', 'S01AB04', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sulfacetamide sodium', 'S01AB04', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sulfamethoxazole', 'J01EC01', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sulfamethoxazole', 'J01EC01', 80.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sulfamethoxazole', 'J01EC01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sulfamethoxazole', 'J01EC01', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sulfamethoxazole', 'J01EC01', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sulfamethoxazole', 'J01EC01', 800.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sulfasalazine', 'A07EC01', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sulfated oils', 'D10AX30', 6.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sulfinpyrazone', 'M04AB02', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sulfisoxazole', 'J01EB05', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sulfisoxazole (sulfisoxazole acetyl)', NULL, 600.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sulfur', 'D10AB02', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sulfur', 'D10AB02', 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sulfur', 'D10AB02', 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sulfur', 'D10AB02', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sulindac', 'M01AB02', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sulindac', 'M01AB02', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sulisobenzone', NULL, 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sumatriptan (sumatriptan hemisulfate)', 'N02CC01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sumatriptan (sumatriptan hemisulfate)', 'N02CC01', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 12.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sumatriptan (sumatriptan succinate)', 'N02CC01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sunitinib (sunitinib malate)', 'L01XE04', 12.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sunitinib (sunitinib malate)', 'L01XE04', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sunitinib (sunitinib malate)', 'L01XE04', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('surfactant-associated proteins sp-b and sp-c', NULL, 500.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sweet vernal grass', 'V01AA02', 10000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sweet vernal grass', 'V01AA02', 100000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('sevelamer carbonate', 'V03AE02', 800.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tacrolimus', 'L04AD02', 0.03, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tacrolimus', 'L04AD02', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tacrolimus', 'L04AD02', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tacrolimus', 'L04AD02', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tacrolimus', 'L04AD02', 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tacrolimus', 'L04AD02', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tadalafil', 'G04BE08', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tadalafil', 'G04BE08', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tadalafil', 'G04BE08', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tadalafil', 'G04BE08', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tamoxifen (tamoxifen citrate)', 'L02BA01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tamoxifen (tamoxifen citrate)', 'L02BA01', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tamsulosin hydrochloride', 'G04CA02', 0.4, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tannic acid', NULL, 6.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tartaric acid', NULL, 3.8, 'g/2tsp');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('taurine', NULL, 50.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('taurine', NULL, 60.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('taurine', NULL, 70.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tazarotene', 'D05AX05', 0.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tazarotene', 'D05AX05', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tazobactam (tazobactam sodium)', NULL, 0.25, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tazobactam (tazobactam sodium)', NULL, 0.375, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tazobactam (tazobactam sodium)', NULL, 0.5, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tazobactam (tazobactam sodium)', NULL, 1.5, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tazobactam (tazobactam sodium)', NULL, 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tazobactam (tazobactam sodium)', NULL, 375.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tazobactam (tazobactam sodium)', NULL, 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('telbivudine', 'J05AF11', 600.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('telithromycin', 'J01FA15', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('telmisartan', 'C09CA07', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('telmisartan', 'C09CA07', 80.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('temazepam', 'N05CD07', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('temazepam', 'N05CD07', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('temozolomide', 'L01AX03', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('temozolomide', 'L01AX03', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('temozolomide', 'L01AX03', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('temozolomide', 'L01AX03', 140.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('temozolomide', 'L01AX03', 180.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('temozolomide', 'L01AX03', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('temsirolimus', 'L01XE09', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tenecteplase', 'B01AD11', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('teniposide', 'L01CB02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tenofovir disoproxil fumarate', 'J05AF07', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tenoxicam', 'M01AC02', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('terazosin (terazosin hydrochloride)', 'G04CA03', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('terazosin hydrochloride', 'G04CA03', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('terazosin hydrochloride', 'G04CA03', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('terazosin hydrochloride', 'G04CA03', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('terazosin hydrochloride', 'G04CA03', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('terbinafine (terbinafine hydrochloride)', 'D01BA02', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('terbinafine hydrochloride', 'D01AE15', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('terbinafine hydrochloride', 'D01AE15', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('terbutaline sulfate', 'R03AC03', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('terconazole', 'G01AG02', 0.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('terconazole', 'G01AG02', 0.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('terconazole', 'G01AG02', 4.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('terconazole', 'G01AG02', 80.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 0.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 0.53, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 1.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 1.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 1.5, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('terephthalylidene dicamphor sulfonic acid', NULL, 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('teriparatide', 'H05AA02', 250.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('testosterone', 'G03BA03', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('testosterone', 'G03BA03', 12.2, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('testosterone', 'G03BA03', 24.3, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('testosterone cypionate', 'G03BA03', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('testosterone enanthate', 'G03BA03', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('testosterone propionate', 'G03BA03', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('testosterone undecanoate', 'G03BA03', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tetanus immune globulin (human)', 'J06BB02', 250.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tetanus protein', NULL, 20.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tetanus toxoid', 'J07AM01', 5.0, 'lf/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tetanus toxoid', 'J07AM01', 10.0, 'lf/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tetanus toxoid', 'J07AM01', 20.0, 'unit/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tetanus toxoid', 'J07AM01', 20.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tetanus toxoid adsorbed', NULL, 5.0, 'lf/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tetanus toxoid adsorbed', NULL, 40.0, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tetrabenazine', 'N07XX06', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tetracaine (tetracaine hydrochloride)', 'D04AB06', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tetracaine hydrochloride', 'S01HA03', 0.073, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tetracaine hydrochloride', 'S01HA03', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tetracaine hydrochloride', 'S01HA03', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tetracaine hydrochloride', 'S01HA03', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tetracaine hydrochloride', 'S01HA03', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tetracaine hydrochloride', 'S01HA03', 20.0, 'mg/2ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tetracycline hydrochloride', 'S01AA09', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tetracycline hydrochloride', 'S01AA09', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tetrahydrozoline hydrochloride', 'S01XA20', 0.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tetrahydrozoline hydrochloride', 'S01XA20', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tetramethylthiuram monosulfide', NULL, 0.005, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thalidomide', 'L04AX02', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('theophylline', 'R03DA04', 0.8, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('theophylline', 'R03DA04', 7.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('theophylline', 'R03DA04', 80.0, 'mg/15ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('theophylline', 'R03DA04', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('theophylline', 'R03DA04', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('theophylline', 'R03DA04', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('theophylline', 'R03DA04', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('theophylline', 'R03DA04', 600.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thiamazole', 'H03BB02', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thiamazole', 'H03BB02', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thiamine hydrochloride', 'A11DA01', 0.222, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thiamine hydrochloride', 'A11DA01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thimerosal', NULL, 0.0065, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thioguanine', 'L01BB03', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thiopental sodium', 'N01AF03', 1.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thiopental sodium', 'N01AF03', 5.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thiopental sodium', 'N01AF03', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thiopental sodium', 'N01AF03', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thiopental sodium', 'N01AF03', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thioproperazine (thioproperazine mesylate)', 'N05AB08', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thiothixene', 'N05AF04', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thiothixene', 'N05AF04', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thiothixene', 'N05AF04', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thiram', 'P03AA05', 0.005, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('threonine', NULL, 64.6, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('threonine', NULL, 330.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('threonine', NULL, 340.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('threonine', NULL, 400.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('threonine', NULL, 420.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('threonine', NULL, 460.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('threonine', NULL, 980.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thrombin (human)', NULL, 4.0, 'unit/1ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thrombin (human)', NULL, 8.0, 'unit/2ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thrombin (human)', NULL, 20.0, 'unit/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thrombin (human)', NULL, 500.0, 'unit/1ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thrombin (human)', NULL, 1000.0, 'unit/2ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thrombin (human)', NULL, 2500.0, 'unit/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thrombin alfa', 'B02BD30', 6000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thymol', 'V07AV', 0.18, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thymol', 'V07AV', 0.23, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thymol', 'V07AV', 0.36, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thymol', 'V07AV', 18.02, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thymol', 'V07AV', 50.0, 'mg/1g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thymol (thyme oil)', 'V07AV', 0.092, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thymol (thyme oil)', 'V07AV', 0.23, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thymol iodide', NULL, 25.0, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thyroid', 'H03AA05', 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thyroid', 'H03AA05', 60.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thyroid', 'H03AA05', 125.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('thyrotropin alfa', 'V04CJ01', 0.9, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tiaprofenic acid', 'M01AE11', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tiaprofenic acid', 'M01AE11', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ticarcillin (ticarcillin disodium)', NULL, 3.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ticarcillin (ticarcillin disodium)', NULL, 30.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tick-borne encephalitis vaccine (inactivated)', 'J07BA01', 2.4, 'µg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ticlopidine hydrochloride', 'B01AC05', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tigecycline', 'J01AA12', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('timolol (timolol maleate)', 'S01ED01', 0.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('timolol (timolol maleate)', 'S01ED01', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('timolol (timolol maleate)', 'S01ED01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('timolol maleate', 'S01ED01', 0.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('timolol maleate', 'S01ED01', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('timolol maleate', 'S01ED01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('timolol maleate', 'S01ED01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('timolol maleate', 'S01ED01', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tinzaparin sodium', 'B01AB10', 10000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tinzaparin sodium', 'B01AB10', 20000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tiotropium (tiotropium bromide monohydrate)', 'R03BB04', 18.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tipranavir', 'J05AE09', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tirofiban (tirofiban hydrochloride)', 'B01AC17', 5.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 0.66, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 0.75, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 0.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 0.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 0.95, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 0.96, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 1.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 1.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 1.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 1.6, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 1.65, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 1.7, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 1.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 1.83, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 1.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 2.0, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 2.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 2.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 2.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 2.3, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 2.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 2.4, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 2.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 2.6, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 2.66, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 2.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 2.92, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 3.16, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 3.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 3.24, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 3.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 3.32, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 3.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 3.6, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 3.75, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 3.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 4.15, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 4.19, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 4.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 4.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 4.37, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 4.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 4.6, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 4.7, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 4.79, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 4.84, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 4.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 4.95, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 5.0, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 5.02, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 5.08, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 5.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 5.12, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 5.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 5.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 5.5, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 5.6, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 5.65, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 5.7, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 5.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 5.81, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 5.85, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 6.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 6.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 6.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 6.6, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 7.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 7.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 7.7, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 7.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 8.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 8.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 9.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 9.37, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 10.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 11.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 11.7, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 13.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 13.75, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 15.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 15.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 18.08, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 18.84, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('titanium dioxide', NULL, 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tizanidine (tizanidine hydrochloride)', 'M03BX02', 4.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tobramycin', 'S01AA12', 0.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tobramycin', 'S01AA12', 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tobramycin (tobramycin sulfate)', 'J01GB01', 1.2, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tobramycin (tobramycin sulfate)', 'J01GB01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tobramycin (tobramycin sulfate)', 'J01GB01', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tobramycin (tobramycin sulfate)', 'J01GB01', 300.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tocilizumab', 'L04AC07', 80.0, 'mg/4ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tocilizumab', 'L04AC07', 200.0, 'mg/10ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tocilizumab', 'L04AC07', 400.0, 'mg/20ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tolbutamide', 'A10BB03', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tolnaftate', 'D01AE18', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tolnaftate', 'D01AE18', 1.0, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tolnaftate', 'D01AE18', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tolterodine l-tartrate', 'G04BD07', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tolterodine l-tartrate', 'G04BD07', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tolterodine l-tartrate', 'G04BD07', 4.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('topiramate', 'N03AX11', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('topiramate', 'N03AX11', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('topiramate', 'N03AX11', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('topiramate', 'N03AX11', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('topiramate', 'N03AX11', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('topotecan (topotecan hydrochloride)', 'L01XX17', 4.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tositumomab', 'V10XA53', 14.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('total protein', NULL, 130.0, 'mg/1ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('total protein', NULL, 260.0, 'mg/2ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('total protein', NULL, 650.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trabectedin', 'L01CX01', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tramadol hydrochloride', 'N02AX02', 37.5, '0mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tramadol hydrochloride', 'N02AX02', 37.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tramadol hydrochloride', 'N02AX02', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tramadol hydrochloride', 'N02AX02', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tramadol hydrochloride', 'N02AX02', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tramadol hydrochloride', 'N02AX02', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tramadol hydrochloride', 'N02AX02', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tramadol hydrochloride', 'N02AX02', 400.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trandolapril', 'C09AA10', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trandolapril', 'C09AA10', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trandolapril', 'C09AA10', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trandolapril', 'C09AA10', 4.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tranexamic acid', 'B02AA02', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tranexamic acid', 'B02AA02', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tranylcypromine (tranylcypromine sulfate)', 'N06AF04', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trastuzumab', 'L01XC03', 440.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('travoprost', 'S01EE04', 0.004, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trazodone (trazodone hydrochloride)', 'N06AX05', 68.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trazodone hydrochloride', 'N06AX05', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trazodone hydrochloride', 'N06AX05', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trazodone hydrochloride', 'N06AX05', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('treprostinil (treprostinil sodium)', 'B01AC21', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('treprostinil (treprostinil sodium)', 'B01AC21', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('treprostinil (treprostinil sodium)', 'B01AC21', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('treprostinil (treprostinil sodium)', 'B01AC21', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tretinoin', 'L01XX14', 0.01, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tretinoin', 'L01XX14', 0.025, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tretinoin', 'L01XX14', 0.04, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tretinoin', 'L01XX14', 0.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tretinoin', 'L01XX14', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tretinoin', 'L01XX14', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triamcinolone acetonide', 'R01AD11', 0.025, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triamcinolone acetonide', 'R01AD11', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triamcinolone acetonide', 'R01AD11', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triamcinolone acetonide', 'R01AD11', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triamcinolone acetonide', 'R01AD11', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triamcinolone acetonide', 'R01AD11', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triamcinolone acetonide', 'R01AD11', 55.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triamcinolone acetonide', 'R01AD11', 100.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triamcinolone diacetate', 'H02AB08', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triamcinolone hexacetonide', 'H02AB08', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triamterene', 'C03DB02', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triazolam', 'N05CD05', 0.125, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triazolam', 'N05CD05', 0.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triclosan', 'D08AE04', 0.02, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triclosan', 'D08AE04', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triclosan', 'D08AE04', 0.15, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triclosan', 'D08AE04', 0.19, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triclosan', 'D08AE04', 0.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triclosan', 'D08AE04', 0.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triclosan', 'D08AE04', 0.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triclosan', 'D08AE04', 0.32, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triclosan', 'D08AE04', 0.375, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triclosan', 'D08AE04', 0.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triclosan', 'D08AE04', 0.46, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triclosan', 'D08AE04', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triclosan', 'D08AE04', 0.55, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triclosan', 'D08AE04', 0.58, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triclosan', 'D08AE04', 0.6, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triclosan', 'D08AE04', 0.745, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triclosan', 'D08AE04', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triclosan', 'D08AE04', 1.0, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triethanolamine polypeptide cocoate condensate', NULL, 12.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triethanolamine stearate', NULL, 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triethylene glycol', NULL, 4.66, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trifluoperazine (trifluoperazine hydrochloride)', 'N05AB06', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trifluoperazine (trifluoperazine hydrochloride)', 'N05AB06', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trifluoperazine (trifluoperazine hydrochloride)', 'N05AB06', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trifluoperazine (trifluoperazine hydrochloride)', 'N05AB06', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trifluoperazine (trifluoperazine hydrochloride)', 'N05AB06', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trifluoperazine hydrochloride', 'N05AB06', 2.36, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trifluoperazine hydrochloride', 'N05AB06', 5.9, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trifluoperazine hydrochloride', 'N05AB06', 11.8, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trifluridine', 'S01AD02', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trihexyphenidyl hydrochloride', 'N04AA01', 0.4, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trihexyphenidyl hydrochloride', 'N04AA01', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trihexyphenidyl hydrochloride', 'N04AA01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trimebutine maleate', 'A03AA05', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trimebutine maleate', 'A03AA05', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trimeprazine (trimeprazine tartrate)', 'R06AD01', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trimeprazine (trimeprazine tartrate)', 'R06AD01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trimethoprim', 'J01EA01', 8.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trimethoprim', 'J01EA01', 16.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trimethoprim', 'J01EA01', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trimethoprim', 'J01EA01', 80.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trimethoprim', 'J01EA01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trimethoprim', 'J01EA01', 160.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trimethoprim', 'J01EA01', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trimethoprim (trimethoprim sulfate)', NULL, 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trimipramine (trimipramine maleate)', 'N06AA06', 12.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trimipramine (trimipramine maleate)', 'N06AA06', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trimipramine (trimipramine maleate)', 'N06AA06', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trimipramine (trimipramine maleate)', 'N06AA06', 75.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trimipramine (trimipramine maleate)', 'N06AA06', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tripelennamine hydrochloride', 'D04AA04', 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triprolidine hydrochloride', NULL, 2.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triprolidine hydrochloride', NULL, 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triprolidine hydrochloride', NULL, 4.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triptorelin (triptorelin pamoate)', 'L02AE04', 3.75, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('triptorelin (triptorelin pamoate)', 'L02AE04', 11.25, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tris hydroxymethyl nitromethane', NULL, 19.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tris hydroxymethyl nitromethane', NULL, 19.56, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trisodium edetate', NULL, 0.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trolamine salicylate', 'M02AC', 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trolamine salicylate', 'M02AC', 12.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trolamine salicylate', 'M02AC', 13.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trolamine salicylate', 'M02AC', 15.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trolamine salicylate', 'M02AC', 20.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tromethamine', 'B05XX02', 36.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tropicamide', 'S01FA06', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tropicamide', 'S01FA06', 0.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tropicamide', 'S01FA06', 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trospium chloride', 'G04BD09', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trospium chloride', 'G04BD09', 60.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('trypan blue', 'S01KX02', 0.06, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tryptophan', 'N06AX02', 1.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tryptophan', 'N06AX02', 27.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tryptophan', 'N06AX02', 45.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tryptophan', 'N06AX02', 70.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tryptophan', 'N06AX02', 76.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tryptophan', 'N06AX02', 76.5, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tryptophan', 'N06AX02', 80.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tryptophan', 'N06AX02', 85.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tryptophan', 'N06AX02', 90.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tryptophan', 'N06AX02', 100.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tryptophan', 'N06AX02', 120.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tryptophan', 'N06AX02', 125.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tryptophan', 'N06AX02', 130.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tryptophan', 'N06AX02', 140.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tryptophan', 'N06AX02', 150.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tryptophan', 'N06AX02', 160.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tryptophan', 'N06AX02', 165.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tryptophan', 'N06AX02', 170.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tryptophan', 'N06AX02', 180.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tryptophan', 'N06AX02', 200.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tryptophan', 'N06AX02', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tryptophan', 'N06AX02', 300.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tryptophan', 'N06AX02', 320.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tryptophan', 'N06AX02', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tryptophan', 'N06AX02', 750.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('typhoid vaccine (salmonella typhi ty21a)', 'J07AP01', 10.0, 'b');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tyrosine', NULL, 30.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tyrosine', NULL, 40.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tyrosine', NULL, 44.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tyrosine', NULL, 50.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('tyrothricin', 'D06AX08', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('urea', NULL, 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('urea', NULL, 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('urea', NULL, 25.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('urofollitropin', 'G03GA04', 75.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ursodiol', 'A05AA02', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ursodiol', 'A05AA02', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ustekinumab', 'L04AC05', 45.0, 'mg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('valacyclovir (valacyclovir hydrochloride)', 'J05AB11', 1.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('valacyclovir (valacyclovir hydrochloride)', 'J05AB11', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('valacyclovir (valacyclovir hydrochloride)', 'J05AB11', 1000.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('valganciclovir (valganciclovir hydrochloride)', 'J05AB14', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('valganciclovir (valganciclovir hydrochloride)', 'J05AB14', 450.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('valine', NULL, 1.24, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('valine', NULL, 1.44, 'g/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('valine', NULL, 139.3, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('valine', NULL, 460.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('valine', NULL, 528.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('valine', NULL, 560.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('valine', NULL, 580.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('valine', NULL, 640.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('valine', NULL, 680.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('valproic acid', 'N03AG01', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('valproic acid', 'N03AG01', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('valproic acid (divalproex sodium)', 'N03AG01', 125.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('valproic acid (divalproex sodium)', 'N03AG01', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('valproic acid (divalproex sodium)', 'N03AG01', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('valproic acid (sodium valproate)', 'N03AG01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('valproic acid (sodium valproate)', 'N03AG01', 250.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('valrubicin', 'L01DB09', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('valsartan', 'C09CA03', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('valsartan', 'C09CA03', 80.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('valsartan', 'C09CA03', 160.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('valsartan', 'C09CA03', 320.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vancomycin (vancomycin hydrochloride)', 'J01XA01', 1.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vancomycin (vancomycin hydrochloride)', 'J01XA01', 5.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vancomycin (vancomycin hydrochloride)', 'J01XA01', 10.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vancomycin (vancomycin hydrochloride)', 'J01XA01', 125.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vancomycin (vancomycin hydrochloride)', 'J01XA01', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vancomycin (vancomycin hydrochloride)', 'J01XA01', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vancomycin (vancomycin hydrochloride)', 'J01XA01', 1000.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vardenafil (vardenafil hydrochloride)', 'G04BE09', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vardenafil (vardenafil hydrochloride)', 'G04BE09', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vardenafil (vardenafil hydrochloride)', 'G04BE09', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('varenicline (varenicline tartrate)', 'N07BA03', 0.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('varenicline (varenicline tartrate)', 'N07BA03', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('varicella zoster immune globulin human', 'J06BB03', 125.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('varicella-zoster virus vaccine live attenuated (oka/merck strain)', 'J07BK02', 1350.0, 'unit/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('varicella-zoster virus vaccine live attenuated (oka/merck strain)', 'J07BK02', 1995.2623, 'unit/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('varicella-zoster virus vaccine live attenuated (oka/merck strain)', 'J07BK02', 2000.0, 'unit/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('varicella-zoster virus vaccine live attenuated (oka/merck strain)', 'J07BK02', 19400.0, 'pfu/0.65ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vasopressin', 'H01BA01', 20.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vasopressin (arginine vasopressin)', 'H01BA01', 20.0, 'unit/1ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vecuronium bromide', 'M03AC03', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vecuronium bromide', 'M03AC03', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('venlafaxine (venlafaxine hydrochloride)', 'N06AX16', 37.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('venlafaxine (venlafaxine hydrochloride)', 'N06AX16', 75.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('venlafaxine (venlafaxine hydrochloride)', 'N06AX16', 150.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('verapamil hydrochloride', 'C08DA01', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('verapamil hydrochloride', 'C08DA01', 80.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('verapamil hydrochloride', 'C08DA01', 120.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('verapamil hydrochloride', 'C08DA01', 180.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('verapamil hydrochloride', 'C08DA01', 240.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('verteporfin', 'S01LA01', 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vespula spp venom protein extract', 'V01AA07', 1.1, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vespula spp venom protein extract', 'V01AA07', 120.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vespula spp venom protein extract', 'V01AA07', 1300.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vibrio cholerae inaba 48 classical biotype, heat inactivated', NULL, 25000000000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vibrio cholerae inaba 6973 e1 tor biotype, formalin inactivated', NULL, 25000000000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vibrio cholerae ogawa 50 classical biotype, formalin inactivated', NULL, 25000000000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vibrio cholerae ogawa 50 classical biotype, heat inactivated', NULL, 25000000000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vigabatrin', 'N03AG04', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vinblastine sulfate', 'L01CA01', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vincristine sulfate', 'L01CA02', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vinorelbine (vinorelbine tartrate)', 'L01CA04', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin a', 'A11CA01', 660.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin a', 'A11CA01', 1000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin a', 'A11CA01', 2300.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin a', 'A11CA01', 25000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin a', 'A11CA01', 50000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin a (vitamin a palmitate)', NULL, 4000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin a palmitate', NULL, 4000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin b1', NULL, 1.2, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin b1', NULL, 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin b1 (thiamine hydrochloride)', NULL, 0.6, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin b1 (thiamine hydrochloride)', NULL, 1.2, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin b1 (thiamine hydrochloride)', NULL, 4.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin b1 (thiamine hydrochloride)', NULL, 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin b1 (thiamine mononitrate)', NULL, 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin b12', 'B03BA01', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin b12', 'B03BA01', 12.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin b12', 'B03BA01', 100.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin b12', 'B03BA01', 1000.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin b12 (cyanocobalamin)', 'B03BA01', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin b12 (cyanocobalamin)', 'B03BA01', 1.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zidovudine', 'J05AF01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin b12 (cyanocobalamin)', 'B03BA01', 12.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin b12 (cyanocobalamin)', 'B03BA01', 25.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin b12 (cyanocobalamin)', 'B03BA01', 100.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin b12 (vitamin b12)', NULL, 1.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin b2', NULL, 0.111, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin b2', NULL, 0.72, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin b2', NULL, 1.3, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin b2 (riboflavin 5''-phosphate sodium)', 'A11HA04', 7.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin b2 (riboflavin 5''-phosphate sodium)', 'A11HA04', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin b2 (riboflavin 5''-phosphate sodium)', 'A11HA04', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin b2 (riboflavin)', NULL, 3.4, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin b2 (riboflavin)', NULL, 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin b2 (riboflavin-5-phosphate)', NULL, 0.72, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin b2 (riboflavin-5-phosphate)', NULL, 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin b2 (riboflavin-5-phosphate)', NULL, 1.4, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin b6', NULL, 1.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin b6 (pyridoxine hydrochloride)', NULL, 1.2, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin b6 (pyridoxine hydrochloride)', NULL, 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin b6 (pyridoxine hydrochloride)', NULL, 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin c', 'A11GA01', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin c', 'A11GA01', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin c', 'A11GA01', 50.0, 'mg/22mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin c', 'A11GA01', 50.0, 'mg/23g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin c', 'A11GA01', 60.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin c', 'A11GA01', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin c', 'A11GA01', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin c (ascorbic acid)', 'A11GA01', 50.0, 'mg/22g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin c (ascorbic acid)', 'A11GA01', 80.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin c (ascorbic acid)', 'A11GA01', 120.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin c (ascorbic acid)', 'A11GA01', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin c (ascorbic acid)', 'A11GA01', 500.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin c (calcium ascorbate)', NULL, 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin c (sodium ascorbate)', 'A11GA01', 250.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin d', 'ZXX0158', 40.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin d', 'ZXX0158', 100.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin d', 'ZXX0158', 400.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin d (vitamin d3)', 'A11CC05', 10000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin d2', 'A11CC01', 50000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin d3', NULL, 400.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin d3 (cholecalciferol)', 'A11CC05', 250.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin d3 (cholecalciferol)', 'A11CC05', 2800.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin d3 (cholecalciferol)', 'A11CC05', 5600.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin d3 (cholecalciferol)', 'A11CC05', 10000.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin e', NULL, 2.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin e (d-alpha tocopheryl acetate)', NULL, 65.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin e (dl-alpha tocopherol)', NULL, 11.86, 'mg/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin e (dl-alpha tocopheryl acetate)', 'A11HA03', 1.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin e (dl-alpha tocopheryl acetate)', 'A11HA03', 2.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin e (dl-alpha tocopheryl acetate)', 'A11HA03', 7.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin e (dl-alpha tocopheryl acetate)', 'A11HA03', 30.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin e (dl-alpha tocopheryl acetate)', 'A11HA03', 100.0, 'unit');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin k1', 'B02BA01', 0.15, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin k1', 'B02BA01', 0.2, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin k1', 'B02BA01', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vitamin k1', 'B02BA01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('von willebrand factor (human)', NULL, 400.0, 'unit/5.0ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('von willebrand factor (human)', NULL, 800.0, 'unit/10.0ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('von willebrand factor (human)', NULL, 840.0, 'unit/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('von willebrand factor (human)', NULL, 1680.0, 'unit/10ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('von willebrand factor (human)', NULL, 3360.0, 'unit/15ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('voriconazole', 'J02AC03', 3.0, 'g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('voriconazole', 'J02AC03', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('voriconazole', 'J02AC03', 200.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('vorinostat', 'L01XX38', 100.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('warfarin sodium', 'B01AA03', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('warfarin sodium', 'B01AA03', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('warfarin sodium', 'B01AA03', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('warfarin sodium', 'B01AA03', 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('warfarin sodium', 'B01AA03', 4.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('warfarin sodium', 'B01AA03', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('warfarin sodium', 'B01AA03', 6.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('warfarin sodium', 'B01AA03', 7.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('warfarin sodium', 'B01AA03', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('wasp venom protein', 'V01AA07', 120.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('wasp venom protein', 'V01AA07', 550.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('water', 'V07AB', 0.5, 'ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('water', 'V07AB', 1.0, 'ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('water', 'V07AB', 1.3, 'ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('water', 'V07AB', 2.0, 'ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('water', 'V07AB', 5.0, 'ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('water', 'V07AB', 10.0, 'ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('water', 'V07AB', 20.0, 'ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('water', 'V07AB', 30.0, 'ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('water', 'V07AB', 50.0, 'ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('water', 'V07AB', 99.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('water', 'V07AB', 100.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('water', 'V07AB', 100.0, 'ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('white faced hornet venom protein', 'V01AA07', 1.1, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('white faced hornet venom protein', 'V01AA07', 120.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('white faced hornet venom protein', 'V01AA07', 550.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('white faced hornet venom protein', 'V01AA07', 1300.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('white petrolatum', 'D02AC', 30.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('white petrolatum', 'D02AC', 38.55, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('white petrolatum', 'D02AC', 57.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('white petrolatum', 'D02AC', 71.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('white petrolatum', 'D02AC', 80.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('white petrolatum', 'D02AC', 88.7, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('white petrolatum', 'D02AC', 99.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('white petrolatum', 'D02AC', 99.96, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('white petrolatum', 'D02AC', 100.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('wild lettuce', NULL, 1.36, 'mg/1ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('wool alcohols', NULL, 0.81, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('xylometazoline hydrochloride', 'R01AA07', 0.05, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('xylometazoline hydrochloride', 'R01AA07', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('yellow fever vaccine', 'J07BL01', 109648.0, 'pfu/0.5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('yellow hornet venom protein', 'V01AA07', 1.1, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('yellow hornet venom protein', 'V01AA07', 120.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('yellow hornet venom protein', 'V01AA07', 550.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('yellow hornet venom protein', 'V01AA07', 1300.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('yellow jacket venom protein', 'V01AA07', 1.1, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('yellow jacket venom protein', 'V01AA07', 120.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('yellow jacket venom protein', 'V01AA07', 550.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('yellow jacket venom protein', 'V01AA07', 1300.0, 'µg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('yohimbine hydrochloride', 'G04BE04', 2.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('yohimbine hydrochloride', 'G04BE04', 5.4, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('yohimbine hydrochloride', 'G04BE04', 6.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zafirlukast', 'R03DC01', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zanamivir', 'J05AH01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zidovudine', 'J05AF01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zidovudine', 'J05AF01', 50.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zidovudine', 'J05AF01', 300.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc (zinc gluconate)', NULL, 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc (zinc gluconate)', NULL, 7.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc (zinc oxide)', NULL, 15.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc (zinc sulfate)', 'A12CB01', 1.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc (zinc sulfate)', 'A12CB01', 3.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc (zinc sulfate)', 'A12CB01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc acetate', 'A16AX05', 0.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc chloride', 'B05XA12', 1.67, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc dibutyldithiocarbamate', NULL, 0.068, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc diethyldithiocarbamate', NULL, 0.068, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 0.45, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 1.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 1.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 1.7, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 1.75, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 1.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 2.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 2.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 2.2, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 2.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 2.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 2.7, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 2.85, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 2.88, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 2.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 2.94, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 3.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 3.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 3.43, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 3.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 3.7, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 3.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 3.88, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 3.92, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 4.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 4.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 4.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 5.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 5.0, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 5.04, 'g/100g');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 5.5, '0%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 6.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 6.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 6.65, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 6.7, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 6.79, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 6.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 7.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 7.35, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 7.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 7.6, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 8.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 8.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 8.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 8.8, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 9.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 9.3, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 10.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 12.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 13.4, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 13.9, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 15.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 16.1, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 19.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 30.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc oxide', NULL, 40.0, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc sulfate', 'A12CB01', 0.25, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc sulfate', 'A12CB01', 0.5, '%');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc sulfate', 'A12CB01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zinc sulfate', 'A12CB01', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ziprasidone (ziprasidone hydrochloride monohydrate)', 'N05AE04', 20.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ziprasidone (ziprasidone hydrochloride monohydrate)', 'N05AE04', 40.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ziprasidone (ziprasidone hydrochloride monohydrate)', 'N05AE04', 60.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('ziprasidone (ziprasidone hydrochloride monohydrate)', 'N05AE04', 80.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zoledronic acid', 'M05BA08', 4.0, 'mg/5ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zoledronic acid', 'M05BA08', 5.0, 'mg/100ml');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zolmitriptan', 'N02CC03', 2.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zolmitriptan', 'N02CC03', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zopiclone', 'N05CF01', 3.75, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zopiclone', 'N05CF01', 5.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zopiclone', 'N05CF01', 7.5, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zuclopenthixol (zuclopenthixol hydrochloride)', 'N05AF05', 10.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zuclopenthixol (zuclopenthixol hydrochloride)', 'N05AF05', 25.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zuclopenthixol acetate', 'N05AF05', 50.0, 'mg');
INSERT INTO consumable_substance (description, atc_code, amount, unit) VALUES ('zuclopenthixol decanoate', 'N05AF05', 200.0, 'mg');


--
-- PostgreSQL database dump complete
--



-- -----------------------------------------------------------------------------
-- ************************************************************
-- transfer from staging table into ref.consumable_substance
-- ************************************************************
-- if does not already exist, and provided amounts are >= 0
-- -----------------------------------------------------------------------------

INSERT INTO ref.consumable_substance (
	description,
	atc_code,
	amount,
	unit
)
SELECT
		description,
		atc_code,
		amount,
		unit
	FROM
		staging.consumable_substance s_cs
	WHERE
		NOT EXISTS (
			SELECT 1
			FROM
				ref.consumable_substance r_cs
			WHERE
				UPPER(r_cs.description) = UPPER(s_cs.description)
					AND
				r_cs.amount = s_cs.amount
					AND
				UPPER(r_cs.unit) = UPPER(s_cs.unit)
			LIMIT 1
		)
		AND s_cs.amount >= 0
;

drop table staging.consumable_substance
;

commit;

-- end